@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -210,6 +210,36 @@ static const fwts_acpi_table_rev acpi_63_rev[] = {
 	{NULL, 0xff}	// end of table
 };
 
+static const fwts_acpi_table_rev acpi_64_rev[] = {
+	{"APIC", 5},
+	{"BERT", 1},
+	{"BGRT", 1},
+	{"CPEP", 1},
+	{"DSDT", 2},
+	{"ECDT", 1},
+	{"EINJ", 1},
+	{"ERST", 1},
+	{"FACP", 6},
+	{"FPDT", 1},
+	{"GTDT", 3},
+	{"HEST", 1},
+	{"MSCT", 1},
+	{"MPST", 1},
+	{"NFIT", 1},
+	{"PCCT", 2},
+	{"PHAT", 1},
+	{"PMTT", 2},
+	{"RASF", 1},
+	{"RSDT", 1},
+	{"SBST", 1},
+	{"SDEV", 1},
+	{"SLIT", 1},
+	{"SRAT", 3},
+	{"SSDT", 2},
+	{"XSDT", 1},
+	{NULL, 0xff}	// end of table
+};
+
 static int acpi_table_check_test2(fwts_framework *fw)
 {
 	const fwts_acpi_table_rev *tables_rev;
@@ -230,6 +260,9 @@ static int acpi_table_check_test2(fwts_framework *fw)
 		case FWTS_ACPI_VERSION_63:
 			tables_rev = acpi_63_rev;
 			break;
+		case FWTS_ACPI_VERSION_64:
+			tables_rev = acpi_64_rev;
+			break;
 		default:
 			fwts_log_info_verbatim(fw, "This test does not support ACPI %4.4" PRIx32 ".",  version);
 			return FWTS_SKIP;
