@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016-2020 Canonical
+ * Copyright (C) 2016-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,20 +27,7 @@
 #include <string.h>
 
 static fwts_acpi_table_info *table;
-
-static int bert_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "BERT", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI BERT table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(BERT, &table)
 
 /*
  *  For BERT refer to 18.3.1 Boot Error Record Table
@@ -53,8 +40,8 @@ static int bert_test1(fwts_framework *fw)
 	size_t len;
 
 	fwts_log_info_verbatim(fw, "Boot Error Record Table:");
-	fwts_log_info_verbatim(fw, "  Error Region Length       0x%8.8" PRIx32, bert->boot_error_region_length);
-	fwts_log_info_verbatim(fw, "  Error Region              0x%16.16" PRIx64, bert->boot_error_region);
+	fwts_log_info_simp_int(fw, "  Error Region Length       ", bert->boot_error_region_length);
+	fwts_log_info_simp_int(fw, "  Error Region              ", bert->boot_error_region);
 	fwts_log_nl(fw);
 
 	/* Sanity check length */
@@ -111,14 +98,10 @@ static int bert_test1(fwts_framework *fw)
 		(region->block_status >> 3) & 1);
 	fwts_log_info_verbatim(fw, "  Block Status:  bit [13:4] 0x%" PRIx32 " (Error Data Entry Count)",
 		(region->block_status >> 4) & 0x3ff);
-	fwts_log_info_verbatim(fw, "  Raw Data Offset:          0x%8.8" PRIx32,
-		region->raw_data_offset);
-	fwts_log_info_verbatim(fw, "  Raw Data Length:          0x%8.8" PRIx32,
-		region->raw_data_length);
-	fwts_log_info_verbatim(fw, "  Data Length:              0x%8.8" PRIx32,
-		region->data_length);
-	fwts_log_info_verbatim(fw, "  Error Severity            0x%8.8" PRIx32,
-		region->error_severity);
+	fwts_log_info_simp_int(fw, "  Raw Data Offset:          ", region->raw_data_offset);
+	fwts_log_info_simp_int(fw, "  Raw Data Length:          ", region->raw_data_length);
+	fwts_log_info_simp_int(fw, "  Data Length:              ", region->data_length);
+	fwts_log_info_simp_int(fw, "  Error Severity            ", region->error_severity);
 
 	/* Sanity check raw data fields */
 	if (region->raw_data_offset >
@@ -192,7 +175,7 @@ static fwts_framework_minor_test bert_tests[] = {
 
 static fwts_framework_ops bert_ops = {
 	.description = "BERT Boot Error Record Table test.",
-	.init        = bert_init,
+	.init        = BERT_init,
 	.minor_tests = bert_tests
 };
 
