@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,19 +28,7 @@
 #include <ctype.h>
 
 static fwts_acpi_table_info *table;
-
-static int bgrt_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "BGRT", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI BGRT table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-	return FWTS_OK;
-}
+acpi_table_init(BGRT, &table)
 
 /*
  *  BGRT Boot Graphics Resource Table
@@ -51,32 +39,16 @@ static int bgrt_test1(fwts_framework *fw)
 	bool passed = true;
 
 	fwts_log_info_verbatim(fw, "BGRT Boot Graphics Resource Table:");
-	fwts_log_info_verbatim(fw, "  Version:                  0x%4.4" PRIx16, bgrt->version);
-	fwts_log_info_verbatim(fw, "  Status:                   0x%2.2" PRIx8, bgrt->status);
-	fwts_log_info_verbatim(fw, "  Image Type:               0x%2.2" PRIx8, bgrt->image_type);
-	fwts_log_info_verbatim(fw, "  Image Memory Address:     0x%16.16" PRIx64, bgrt->image_addr);
-	fwts_log_info_verbatim(fw, "  Image Offset X:           0x%8.8" PRIx32, bgrt->image_offset_x);
-	fwts_log_info_verbatim(fw, "  Image Offset Y:           0x%8.8" PRIx32, bgrt->image_offset_y);
+	fwts_log_info_simp_int(fw, "  Version:                  ", bgrt->version);
+	fwts_log_info_simp_int(fw, "  Status:                   ", bgrt->status);
+	fwts_log_info_simp_int(fw, "  Image Type:               ", bgrt->image_type);
+	fwts_log_info_simp_int(fw, "  Image Memory Address:     ", bgrt->image_addr);
+	fwts_log_info_simp_int(fw, "  Image Offset X:           ", bgrt->image_offset_x);
+	fwts_log_info_simp_int(fw, "  Image Offset Y:           ", bgrt->image_offset_y);
 
-	if (bgrt->version != 1) {
-		passed = false;
-		fwts_failed(fw, LOG_LEVEL_MEDIUM,
-			"BGRTInvalidVersion",
-			"BGRT: Version field is 0x%" PRIx8
-			" and not the expected value of 0x01",
-			bgrt->version);
-	}
-
-	fwts_acpi_reserved_bits_check(fw, "BGRT", "BGRT Status", bgrt->status, sizeof(bgrt->status), 3, 7, &passed);
-
-	if (bgrt->image_type > 0x00) {
-		passed = false;
-		fwts_failed(fw, LOG_LEVEL_MEDIUM,
-			"BGRTInvalidImageType",
-			"BGRT: Image Type field is 0x%" PRIx8
-			", the only allowed type is 0x00",
-			bgrt->image_type);
-	}
+	fwts_acpi_fixed_value_check(fw, LOG_LEVEL_MEDIUM, "BGRT", "Version", bgrt->version, 1, &passed);
+	fwts_acpi_reserved_bits_check("BGRT", "BGRT Status", bgrt->status, 3, 7, &passed);
+	fwts_acpi_fixed_value_check(fw, LOG_LEVEL_MEDIUM, "BGRT", "Image Type", bgrt->image_type, 0, &passed);
 
 	if (passed)
 		fwts_passed(fw, "No issues found in BGRT table.");
@@ -91,7 +63,7 @@ static fwts_framework_minor_test bgrt_tests[] = {
 
 static fwts_framework_ops bgrt_ops = {
 	.description = "BGRT Boot Graphics Resource Table test.",
-	.init        = bgrt_init,
+	.init        = BGRT_init,
 	.minor_tests = bgrt_tests
 };
 
