@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,19 +28,7 @@
 #include <ctype.h>
 
 static fwts_acpi_table_info *table;
-
-static int cpep_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "CPEP", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI CPEP table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-	return FWTS_OK;
-}
+acpi_table_init(CPEP, &table)
 
 /*
  *  CPEP Corrected Platform Error Polling Table
@@ -49,6 +37,7 @@ static int cpep_test1(fwts_framework *fw)
 {
 	fwts_acpi_table_cpep *cpep = (fwts_acpi_table_cpep*)table->data;
 	bool passed = true;
+	uint64_t reserved;
 	uint32_t i, n;
 
 	fwts_log_info_verbatim(fw, "CPEP Corrected Platform Error Polling Table:");
@@ -58,40 +47,27 @@ static int cpep_test1(fwts_framework *fw)
 		cpep->reserved[0], cpep->reserved[1], cpep->reserved[2], cpep->reserved[3],
 		cpep->reserved[4], cpep->reserved[4], cpep->reserved[6], cpep->reserved[7]);
 
-	if (cpep->reserved[0] | cpep->reserved[1] |
-	    cpep->reserved[2] | cpep->reserved[3] |
-	    cpep->reserved[4] | cpep->reserved[5] |
-            cpep->reserved[6] | cpep->reserved[7]) {
-		passed = false;
-		fwts_failed(fw, LOG_LEVEL_MEDIUM,
-			"CPEPNonZeroReserved",
-			"CPEP: Reserved field contains a non-zero value");
-	}
+	reserved = cpep->reserved[0] + ((uint64_t) cpep->reserved[1] << 8) +
+		   ((uint64_t) cpep->reserved[2] << 16) + ((uint64_t) cpep->reserved[3] << 24) +
+		   ((uint64_t) cpep->reserved[4] << 32) + ((uint64_t) cpep->reserved[5] << 40) +
+		   ((uint64_t) cpep->reserved[6] << 48) + ((uint64_t) cpep->reserved[7] << 56);
+	fwts_acpi_reserved_zero_check("CPEP", "Reserved", reserved, &passed);
+
 	n = (table->length - sizeof(fwts_acpi_table_cpep)) /
 		sizeof(fwts_acpi_cpep_processor_info);
 
 	for (i = 0; i < n; i++) {
 		bool cpep_passed = true;
+		char label[40];
+
 		fwts_acpi_cpep_processor_info *info = &cpep->cpep_info[i];
 
-		if (info->type != 0) {
-			cpep_passed = false;
-			fwts_failed(fw, LOG_LEVEL_HIGH,
-				"CPEPInvalidProcStructureType",
-				"CPEP: Processor Structure %" PRIu32
-				" Type field is 0x%" PRIx8
-				" and was expected to be 0x00",
-				i, info->type);
-		}
-		if (info->length != 8) {
-			cpep_passed = false;
-			fwts_failed(fw, LOG_LEVEL_MEDIUM,
-				"CPEPInvalidProcStructureType",
-				"CPEP: Processor Structure %" PRIu32
-				" Length field is 0x%" PRIx8
-				" and was expected to be 0x08",
-				i, info->length);
-		}
+		snprintf(label, 40, "Processor Structure %d Type", i);
+		fwts_acpi_fixed_value_check(fw, LOG_LEVEL_HIGH, "CPEP", label, info->type, 0, &cpep_passed);
+
+		snprintf(label, 40, "Processor Structure %d Length", i);
+		fwts_acpi_fixed_value_check(fw, LOG_LEVEL_MEDIUM, "CPEP", label, info->length, 8, &cpep_passed);
+
 		/* Should probably sanity check processor UID, EIDs at a later date */
 
 		/* Some feedback if polling interval is very short */
@@ -121,7 +97,7 @@ static fwts_framework_minor_test cpep_tests[] = {
 
 static fwts_framework_ops cpep_ops = {
 	.description = "CPEP Corrected Platform Error Polling Table test.",
-	.init        = cpep_init,
+	.init        = CPEP_init,
 	.minor_tests = cpep_tests
 };
 
