@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -154,8 +154,8 @@ static int dbg2_test1(fwts_framework *fw)
 	}
 
 	fwts_log_info_verbatim(fw, "DBG2 Table:");
-	fwts_log_info_verbatim(fw, "  Info Offset:              0x%8.8" PRIx32, dbg2->info_offset);
-	fwts_log_info_verbatim(fw, "  Info Count:               0x%8.8" PRIx32, dbg2->info_count);
+	fwts_log_info_simp_int(fw, "  Info Offset:              ", dbg2->info_offset);
+	fwts_log_info_simp_int(fw, "  Info Count:               ", dbg2->info_count);
 	fwts_log_nl(fw);
 
 	total_size = dbg2->info_offset +
@@ -244,30 +244,24 @@ static int dbg2_test1(fwts_framework *fw)
 		}
 
 		fwts_log_info_verbatim(fw, "DBG2 Info Structure %" PRIu32 ":", i);
-		fwts_log_info_verbatim(fw, "  Revision:                 0x%2.2" PRIx8, info->revision);
-		fwts_log_info_verbatim(fw, "  Length:                   0x%4.4" PRIx16, info->length);
-		fwts_log_info_verbatim(fw, "  Number of Registers       0x%2.2" PRIx8, info->number_of_regs);
-		fwts_log_info_verbatim(fw, "  Namespace String Length:  0x%4.4" PRIx16, info->namespace_length);
-		fwts_log_info_verbatim(fw, "  Namespace String Offset:  0x%4.4" PRIx16, info->namespace_offset);
-		fwts_log_info_verbatim(fw, "  OEM Data Length:          0x%4.4" PRIx16, info->oem_data_length);
-		fwts_log_info_verbatim(fw, "  OEM Data Offset:          0x%4.4" PRIx16, info->oem_data_offset);
+		fwts_log_info_simp_int(fw, "  Revision:                 ", info->revision);
+		fwts_log_info_simp_int(fw, "  Length:                   ", info->length);
+		fwts_log_info_simp_int(fw, "  Number of Registers       ", info->number_of_regs);
+		fwts_log_info_simp_int(fw, "  Namespace String Length:  ", info->namespace_length);
+		fwts_log_info_simp_int(fw, "  Namespace String Offset:  ", info->namespace_offset);
+		fwts_log_info_simp_int(fw, "  OEM Data Length:          ", info->oem_data_length);
+		fwts_log_info_simp_int(fw, "  OEM Data Offset:          ", info->oem_data_offset);
 		fwts_log_info_verbatim(fw, "  Port Type:                0x%4.4" PRIx16 " (%s)", info->port_type,
 			port ? port : "(Reserved)");
 		fwts_log_info_verbatim(fw, "  Port Subtype:             0x%4.4" PRIx16 " (%s)", info->port_subtype,
 			subport ? subport : "(Reserved)");
-		fwts_log_info_verbatim(fw, "  Reserved:                 0x%4.4" PRIx16, info->reserved);
-		fwts_log_info_verbatim(fw, "  Base Address Offset:      0x%4.4" PRIx16, info->base_address_offset);
-		fwts_log_info_verbatim(fw, "  Address Size Offset:      0x%4.4" PRIx16, info->address_size_offset);
+		fwts_log_info_simp_int(fw, "  Reserved:                 ", info->reserved);
+		fwts_log_info_simp_int(fw, "  Base Address Offset:      ", info->base_address_offset);
+		fwts_log_info_simp_int(fw, "  Address Size Offset:      ", info->address_size_offset);
 		fwts_log_nl(fw);
 
-		if (info->revision != 0) {
-			passed = false;
-			fwts_failed(fw, LOG_LEVEL_HIGH,
-				"DBG2NonZeroRevision",
-				"DBG2 Info Structure Revision is 0x%2.2" PRIx8
-				" and was expecting 0x00",
-				info->revision);
-		}
+		fwts_acpi_fixed_value_check(fw, LOG_LEVEL_HIGH, "DBG2", "Info Structure Revision", info->revision, 0, &passed);
+
 		if (port == NULL) {
 			passed = false;
 			fwts_failed(fw, LOG_LEVEL_HIGH,
@@ -285,6 +279,8 @@ static int dbg2_test1(fwts_framework *fw)
 				info->port_subtype);
 		}
 
+		fwts_acpi_reserved_zero_check("DBG2", "Info Structure Reserved", info->reserved, &passed);
+
 		length_ok = true;
 		dbg2_check_offset(fw, table->length, offset + info->length,
 			"DBG2 Info Structure Namespace Length", &length_ok);
@@ -336,11 +332,11 @@ static int dbg2_test1(fwts_framework *fw)
 			uint32_t *addrsize = (uint32_t *)(table->data + offset + info->address_size_offset);
 
 			for (j = 0; j < info->number_of_regs; j++, gas++, addrsize++) {
-				fwts_log_info_verbatim(fw, "    Address Space ID:       0x%2.2" PRIx8, gas->address_space_id);
-				fwts_log_info_verbatim(fw, "    Register Bit Width      0x%2.2" PRIx8, gas->register_bit_width);
-				fwts_log_info_verbatim(fw, "    Register Bit Offset     0x%2.2" PRIx8, gas->register_bit_offset);
-				fwts_log_info_verbatim(fw, "    Access Size             0x%2.2" PRIx8, gas->access_width);
-				fwts_log_info_verbatim(fw, "    Address                 0x%16.16" PRIx64, gas->address);
+				fwts_log_info_simp_int(fw, "    Address Space ID:       ", gas->address_space_id);
+				fwts_log_info_simp_int(fw, "    Register Bit Width      ", gas->register_bit_width);
+				fwts_log_info_simp_int(fw, "    Register Bit Offset     ", gas->register_bit_offset);
+				fwts_log_info_simp_int(fw, "    Access Size             ", gas->access_width);
+				fwts_log_info_simp_int(fw, "    Address                 ", gas->address);
 				fwts_log_nl(fw);
 
 				if (*addrsize == 0) {
