@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,7 +18,7 @@
  */
 #include "fwts.h"
 
-#if defined(FWTS_HAS_ACPI)
+#if defined(FWTS_HAS_ACPI) && !(FWTS_ARCH_AARCH64)
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -27,21 +27,7 @@
 #include <string.h>
 
 static fwts_acpi_table_info *table;
-
-static int dbgp_init(fwts_framework *fw)
-{
-
-	if (fwts_acpi_find_table(fw, "DBGP", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI DBGP table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(DBGP, &table)
 
 /*
  *  DBGP Table
@@ -49,9 +35,10 @@ static int dbgp_init(fwts_framework *fw)
  */
 static int dbgp_test1(fwts_framework *fw)
 {
-	bool passed = true;
-	char *interface_type;
 	fwts_acpi_table_dbgp *dbgp = (fwts_acpi_table_dbgp *)table->data;
+	char *interface_type;
+	bool passed = true;
+	uint32_t reserved;
 
 	if (!fwts_acpi_table_length_check(fw, "DBGP", table->length, sizeof(fwts_acpi_table_dbgp))) {
 		passed = false;
@@ -70,18 +57,19 @@ static int dbgp_test1(fwts_framework *fw)
 		break;
 	}
 
+	reserved = dbgp->reserved[0] + ((uint32_t) dbgp->reserved[1] << 8) +
+		   ((uint32_t) dbgp->reserved[2] << 16);
+
 	fwts_log_info_verbatim(fw, "DBGP Table:");
 	fwts_log_info_verbatim(fw, "  Interface Type            0x%2.2" PRIx8 " (%s)",
 		dbgp->interface_type, interface_type);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%2.2" PRIx8, dbgp->reserved1[0]);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%2.2" PRIx8, dbgp->reserved1[1]);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%2.2" PRIx8, dbgp->reserved1[2]);
+	fwts_log_info_simp_int(fw, "  Reserved:                 "	, reserved);
 	fwts_log_info_verbatim(fw, "  Base Address:");
-	fwts_log_info_verbatim(fw, "    Address Space ID:       0x%2.2" PRIx8, dbgp->base_address.address_space_id);
-	fwts_log_info_verbatim(fw, "    Register Bit Width      0x%2.2" PRIx8, dbgp->base_address.register_bit_width);
-	fwts_log_info_verbatim(fw, "    Register Bit Offset     0x%2.2" PRIx8, dbgp->base_address.register_bit_offset);
-	fwts_log_info_verbatim(fw, "    Access Size             0x%2.2" PRIx8, dbgp->base_address.access_width);
-	fwts_log_info_verbatim(fw, "    Address                 0x%16.16" PRIx64, dbgp->base_address.address);
+	fwts_log_info_simp_int(fw, "    Address Space ID:       ", dbgp->base_address.address_space_id);
+	fwts_log_info_simp_int(fw, "    Register Bit Width      ", dbgp->base_address.register_bit_width);
+	fwts_log_info_simp_int(fw, "    Register Bit Offset     ", dbgp->base_address.register_bit_offset);
+	fwts_log_info_simp_int(fw, "    Access Size             ", dbgp->base_address.access_width);
+	fwts_log_info_simp_int(fw, "    Address                 ", dbgp->base_address.address);
 	fwts_log_nl(fw);
 
 	if (dbgp->interface_type > 2) {
@@ -93,6 +81,9 @@ static int dbgp_test1(fwts_framework *fw)
 			" 0x00 (Full 16550) or 0x01 (16550 subset)",
 			dbgp->interface_type);
 	}
+
+	fwts_acpi_reserved_zero_check("DBGP", "Reserved", reserved, &passed);
+
 	if (dbgp->base_address.register_bit_width == 0) {
 		passed = false;
 		fwts_failed(fw, LOG_LEVEL_HIGH,
@@ -127,7 +118,7 @@ static fwts_framework_minor_test dbgp_tests[] = {
 
 static fwts_framework_ops dbgp_ops = {
 	.description = "DBGP (Debug Port) Table test.",
-	.init        = dbgp_init,
+	.init        = DBGP_init,
 	.minor_tests = dbgp_tests
 };
 
