@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2020 Canonical
+ * Copyright (C) 2017-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,20 +27,7 @@
 #include <string.h>
 
 static fwts_acpi_table_info *table;
-
-static int dppt_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "DPPT", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI DPPT table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(DPPT, &table)
 
 static int dppt_test1(fwts_framework *fw)
 {
@@ -64,7 +51,7 @@ static fwts_framework_minor_test dppt_tests[] = {
 
 static fwts_framework_ops dppt_ops = {
 	.description = "DPPT DMA Protection Policy Table test",
-	.init        = dppt_init,
+	.init        = DPPT_init,
 	.minor_tests = dppt_tests
 };
 
