@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016-2020 Canonical
+ * Copyright (C) 2016-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,19 +26,7 @@
 #include <ctype.h>
 
 static fwts_acpi_table_info *table;
-
-static int einj_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "EINJ", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI EINJ table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-	return FWTS_OK;
-}
+acpi_table_init(EINJ, &table)
 
 /*
  *  EINJ Error Injection Table
@@ -50,21 +38,17 @@ static int einj_test1(fwts_framework *fw)
 	uint32_t reserved, i;
 	bool passed = true;
 
-	reserved = einj->reserved[0] + (einj->reserved[1] << 4) +
-		   (einj->reserved[2] << 8);
+	reserved = einj->reserved[0] + ((uint32_t) einj->reserved[1] << 8) +
+		   ((uint32_t) einj->reserved[2] << 16);
 
 	fwts_log_info_verbatim(fw, "EINJ Error Injection Table:");
-	fwts_log_info_verbatim(fw, "  Injection Header Size: 0x%8.8" PRIx32,
-			einj->header_size);
-	fwts_log_info_verbatim(fw, "  Injection Flags:       0x%8.8" PRIx32,
-			einj->flags);
-	fwts_log_info_verbatim(fw, "  Reserved:              0x%8.8" PRIx32,
-			reserved);
-	fwts_log_info_verbatim(fw, "  Injection Entry Count: 0x%8.8" PRIx32,
-			einj->count);
+	fwts_log_info_simp_int(fw, "  Injection Header Size: ", einj->header_size);
+	fwts_log_info_simp_int(fw, "  Injection Flags:       ", einj->flags);
+	fwts_log_info_simp_int(fw, "  Reserved:              ", reserved);
+	fwts_log_info_simp_int(fw, "  Injection Entry Count: ", einj->count);
 
-	fwts_acpi_reserved_bits_check(fw, "EINJ", "Injection Flags", einj->flags, sizeof(einj->flags), 0, 31, &passed);
-	fwts_acpi_reserved_zero_check(fw, "EINJ", "Reserved", reserved, sizeof(reserved), &passed);
+	fwts_acpi_reserved_bits_check("EINJ", "Injection Flags", einj->flags, 0, 31, &passed);
+	fwts_acpi_reserved_zero_check("EINJ", "Reserved", reserved, &passed);
 
 	fwts_log_nl(fw);
 
@@ -115,17 +99,9 @@ static int einj_test1(fwts_framework *fw)
 			passed = false;
 		}
 
-		fwts_acpi_reserved_zero_check(fw, "EINJ", "Reserved", entry->reserved, sizeof(entry->reserved), &passed);
-
-		if (gas.address_space_id != ACPI_ADR_SPACE_SYSTEM_MEMORY &&
-		    gas.address_space_id != ACPI_ADR_SPACE_SYSTEM_IO) {
-			fwts_failed(fw, LOG_LEVEL_MEDIUM,
-				    "EINJBadSpaceId",
-				    "EINJ Address_Space_ID must be within 0 or "
-				    "1, got 0x%" PRIx8 " instead",
-				    gas.address_space_id);
-			passed = false;
-		}
+		fwts_acpi_reserved_zero_check("EINJ", "Reserved", entry->reserved, &passed);
+		fwts_acpi_space_id_check(fw, "EINJ", "Register Region", &passed, gas.address_space_id, 2,
+					 FWTS_GAS_ADDR_SPACE_ID_SYSTEM_MEMORY, FWTS_GAS_ADDR_SPACE_ID_SYSTEM_IO);
 
 		fwts_log_nl(fw);
 	}
@@ -143,7 +119,7 @@ static fwts_framework_minor_test einj_tests[] = {
 
 static fwts_framework_ops einj_ops = {
 	.description = "EINJ Error Injection Table test.",
-	.init        = einj_init,
+	.init        = EINJ_init,
 	.minor_tests = einj_tests
 };
 
