@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,19 +27,7 @@
 #include <string.h>
 
 static fwts_acpi_table_info *table;
-
-static int erst_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "ERST", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI ERST table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-	return FWTS_OK;
-}
+acpi_table_init(ERST, &table)
 
 /*
  *  ERST Extended System Description Table
@@ -52,11 +40,11 @@ static int erst_test1(fwts_framework *fw)
 	uint32_t i;
 
 	fwts_log_info_verbatim(fw, "ERST Error Record Serialization Table :");
-	fwts_log_info_verbatim(fw, "  Serialization Hdr. Size:  0x%8.8" PRIx32, erst->serialization_header_size);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%8.8" PRIx32, erst->reserved);
-	fwts_log_info_verbatim(fw, "  Instruction Entry Count:  0x%8.8" PRIx32, erst->instruction_entry_count);
+	fwts_log_info_simp_int(fw, "  Serialization Hdr. Size:  ", erst->serialization_header_size);
+	fwts_log_info_simp_int(fw, "  Reserved:                 ", erst->reserved);
+	fwts_log_info_simp_int(fw, "  Instruction Entry Count:  ", erst->instruction_entry_count);
 
-	fwts_acpi_reserved_zero_check(fw, "ERST", "Reserved", erst->reserved, sizeof(erst->reserved), &passed);
+	fwts_acpi_reserved_zero_check("ERST", "Reserved", erst->reserved, &passed);
 
 	if (erst->serialization_header_size > table->length) {
 		passed = false;
@@ -92,17 +80,18 @@ static int erst_test1(fwts_framework *fw)
 #if defined(ERST_DEBUG_ENTRY)
 		/*  Disable this for now, it causes the test to be too verbose */
 		fwts_log_info_verbatim(fw, "ERST Serialization Instruction Entry %" PRIu32 ":", i);
-		fwts_log_info_verbatim(fw, "  Serialization Action:     0x%8.8" PRIx8, entry->serialization_action);
-		fwts_log_info_verbatim(fw, "  Instruction:              0x%8.8" PRIx8, entry->instruction);
-		fwts_log_info_verbatim(fw, "  Flags:                    0x%8.8" PRIx8, entry->flags);
-		fwts_log_info_verbatim(fw, "  Reserved:                 0x%8.8" PRIx8, entry->reserved);
-		fwts_log_info_verbatim(fw, "  Value:                    0x%16.16" PRIx64, entry->value);
-		fwts_log_info_verbatim(fw, "  Mask:                     0x%16.16" PRIx64, entry->mask);
-		fwts_log_info_verbatim(fw, "  Address Space ID:         0x%2.2" PRIx8, entry->register_region.address_space_id);
-		fwts_log_info_verbatim(fw, "  Register Bit Width        0x%2.2" PRIx8, entry->register_region.register_bit_width);
-		fwts_log_info_verbatim(fw, "  Register Bit Offset       0x%2.2" PRIx8, entry->register_region.register_bit_offset);
-		fwts_log_info_verbatim(fw, "  Access Size               0x%2.2" PRIx8, entry->register_region.access_width);
-		fwts_log_info_verbatim(fw, "  Address                   0x%16.16" PRIx64, entry->register_region.address);
+		fwts_log_info_simp_int(fw, "  Serialization Action:     ", entry->serialization_action);
+		fwts_log_info_simp_int(fw, "  Instruction:              ", entry->instruction);
+		fwts_log_info_simp_int(fw, "  Flags:                    ", entry->flags);
+		fwts_log_info_simp_int(fw, "  Reserved:                 ", entry->reserved);
+		fwts_log_info_simp_int(fw, "  Value:                    ", entry->value);
+		fwts_log_info_simp_int(fw, "  Mask:                     ", entry->mask);
+		fwts_log_info_simp_int(fw, "  Address Space ID:         ", entry->register_region.address_space_id);
+		fwts_log_info_simp_int(fw, "  Register Bit Width        ", entry->register_region.register_bit_width);
+		fwts_log_info_simp_int(fw, "  Register Bit Offset       ", entry->register_region.register_bit_offset);
+		fwts_log_info_simp_int(fw, "  Access Size               ", entry->register_region.access_width);
+		fwts_log_info_simp_int(fw, "  Address                   ", entry->register_region.address);
+
 #endif
 
 		switch (entry->serialization_action) {
@@ -180,7 +169,7 @@ static fwts_framework_minor_test erst_tests[] = {
 
 static fwts_framework_ops erst_ops = {
 	.description = "ERST Error Record Serialization Table test.",
-	.init        = erst_init,
+	.init        = ERST_init,
 	.minor_tests = erst_tests
 };
 
