@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,19 +28,7 @@
 #include <ctype.h>
 
 static fwts_acpi_table_info *table;
-
-static int facs_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "FACS", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI FACS table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-	return FWTS_OK;
-}
+acpi_table_init(FACS, &table)
 
 /*
  *  FACS Firmware ACPI Control Structure test
@@ -49,6 +37,7 @@ static int facs_test1(fwts_framework *fw)
 {
 	fwts_acpi_table_facs *facs = (fwts_acpi_table_facs*)table->data;
 	bool passed = true;
+	uint32_t reserved;
 	int i;
 
 	if (table->length < 64) {
@@ -61,18 +50,20 @@ static int facs_test1(fwts_framework *fw)
 		goto done;
 	}
 
+	reserved = facs->reserved[0] + ((uint32_t) facs->reserved[1] << 8) +
+		   ((uint32_t) facs->reserved[2] << 16);
+
 	fwts_log_info_verbatim(fw, "FACS Firmware ACPI Control Structure:");
 	fwts_log_info_verbatim(fw, "  Signature:                '%4.4s'", facs->signature);
-	fwts_log_info_verbatim(fw, "  Length:                   0x%8.8" PRIx32, facs->length);
-	fwts_log_info_verbatim(fw, "  Hardware Signature:       0x%8.8" PRIx32, facs->hardware_signature);
-	fwts_log_info_verbatim(fw, "  Firmware Waking Vector:   0x%8.8" PRIx32, facs->firmware_waking_vector);
-	fwts_log_info_verbatim(fw, "  Global Lock:              0x%8.8" PRIx32, facs->global_lock);
-	fwts_log_info_verbatim(fw, "  Flags:                    0x%8.8" PRIx32, facs->flags);
-	fwts_log_info_verbatim(fw, "  X-Firmware Waking Vector: 0x%16.16" PRIx64, facs->x_firmware_waking_vector);
-	fwts_log_info_verbatim(fw, "  Version:                  0x%2.2" PRIx8, facs->version);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%2.2" PRIx8 " 0x%2.2" PRIx8 " 0x%2.2" PRIx8,
-		facs->reserved[0], facs->reserved[1], facs->reserved[2]);
-	fwts_log_info_verbatim(fw, "  OSPM Flags:               0x%8.8" PRIx32, facs->ospm_flags);
+	fwts_log_info_simp_int(fw, "  Length:                   ", facs->length);
+	fwts_log_info_simp_int(fw, "  Hardware Signature:       ", facs->hardware_signature);
+	fwts_log_info_simp_int(fw, "  Firmware Waking Vector:   ", facs->firmware_waking_vector);
+	fwts_log_info_simp_int(fw, "  Global Lock:              ", facs->global_lock);
+	fwts_log_info_simp_int(fw, "  Flags:                    ", facs->flags);
+	fwts_log_info_simp_int(fw, "  X-Firmware Waking Vector: ", facs->x_firmware_waking_vector);
+	fwts_log_info_simp_int(fw, "  Version:                  ", facs->version);
+	fwts_log_info_simp_int(fw, "  Reserved:                 ", reserved);
+	fwts_log_info_simp_int(fw, "  OSPM Flags:               ", facs->ospm_flags);
 	for (i = 0; i < 24; i+= 4) {
 		fwts_log_info_verbatim(fw, "  Reserved:                 "
 			"0x%2.2" PRIx8 " 0x%2.2" PRIx8 " 0x%2.2" PRIx8 " 0x%2.2" PRIx8,
@@ -122,17 +113,10 @@ static int facs_test1(fwts_framework *fw)
 			" and should be at least 64",
 			facs->length);
 	}
-	if (facs->reserved[0] |
-	    facs->reserved[1] |
-	    facs->reserved[2]) {
-		passed = false;
-		fwts_failed(fw, LOG_LEVEL_LOW,
-			"FACSInvalidReserved1",
-			"FACS: 1st Reserved field is non-zero");
-	}
 
-	fwts_acpi_reserved_bits_check(fw, "FACS", "Flags", facs->flags, sizeof(facs->flags), 2, 31, &passed);
-	fwts_acpi_reserved_bits_check(fw, "FACS", "OSPM Flags", facs->ospm_flags, sizeof(facs->ospm_flags), 1, 31, &passed);
+	fwts_acpi_reserved_zero_check("FACS", "Reserved", reserved, &passed);
+	fwts_acpi_reserved_bits_check("FACS", "Flags", facs->flags, 2, 31, &passed);
+	fwts_acpi_reserved_bits_check("FACS", "OSPM Flags", facs->ospm_flags, 1, 31, &passed);
 
 	for (i = 0; i < 24; i++) {
 		if (facs->reserved2[i]) {
@@ -157,7 +141,7 @@ static fwts_framework_minor_test facs_tests[] = {
 
 static fwts_framework_ops facs_ops = {
 	.description = "FACS Firmware ACPI Control Structure test.",
-	.init        = facs_init,
+	.init        = FACS_init,
 	.minor_tests = facs_tests
 };
 
