@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * Portions of this code original from the Linux-ready Firmware Developer Kit
  *
@@ -80,7 +80,7 @@ static int fadt_init(fwts_framework *fw)
 	 * required (5.2.10) is we are not in reduced hardware
 	 * mode
 	 */
-	if (!fwts_acpi_is_reduced_hardware(fadt)) {
+	if (!fwts_acpi_is_reduced_hardware(fw)) {
 		if (fwts_acpi_find_table(fw, "FACS", 0, &table) != FWTS_OK) {
 			fwts_log_error(fw, "Cannot read ACPI table FACS.");
 			return FWTS_ERROR;
@@ -245,7 +245,7 @@ static void acpi_table_check_fadt_firmware_ctrl(fwts_framework *fw)
 
 	/* for more recent FADTs, things get more complicated */
 	if (fadt->firmware_control == 0 && fadt->x_firmware_ctrl == 0) {
-		if (fwts_acpi_is_reduced_hardware(fadt)) {
+		if (fwts_acpi_is_reduced_hardware(fw)) {
 			fwts_passed(fw,
 				    "FADT 32 bit FIRMWARE_CONTROL and "
 				    "64 bit X_FIRMWARE_CONTROL (FACS "
@@ -425,7 +425,7 @@ static void acpi_table_check_fadt_pm_profile(fwts_framework *fw)
 {
 	fwts_log_info(fw, "FADT Preferred PM Profile: %hhu (%s)",
 		fadt->preferred_pm_profile,
-		FWTS_ACPI_FADT_PREFERRED_PM_PROFILE(fadt->preferred_pm_profile));
+		fwts_acpi_fadt_preferred_pm_profile(fadt->preferred_pm_profile));
 
 	if (fadt->preferred_pm_profile <= 8)
 		fwts_passed(fw, "FADT has a valid preferred PM profile.");
@@ -443,7 +443,7 @@ static void acpi_table_check_fadt_reduced_hardware(fwts_framework *fw)
 	static const fwts_acpi_gas null_gas;
 	uint32_t flag_mask;
 
-	rhw = fwts_acpi_is_reduced_hardware(fadt);
+	rhw = fwts_acpi_is_reduced_hardware(fw);
 	fwts_log_info(fw, "FADT indicates ACPI %s in reduced hardware mode.",
 		      rhw ? IS : IS_NOT);
 
@@ -1521,33 +1521,35 @@ static void acpi_table_check_fadt_p_lvl3_lat(fwts_framework *fw, uint64_t pblk)
 
 static void acpi_table_check_fadt_x_gpex_blk(fwts_framework *fw) {
 
-	if (fwts_acpi_is_reduced_hardware(fadt))
+	if (fwts_acpi_is_reduced_hardware(fw))
 		return;
 
 	if (fadt->x_gpe0_blk.access_width == 1)
 		fwts_passed(fw, "FADT X_GPE0_BLK has correct byte access width.");
 	else {
-		fwts_failed(fw, LOG_LEVEL_HIGH,
-			"X_GPE0_BLKBadAccessWidth",
-			"FADT X_GPE0_BLK Access width 0x%2.2" PRIx8
-			" but it should be 1 (byte access).",
-			fadt->x_gpe0_blk.access_width);
+		if (!fwts_acpi_data_zero((const void *) &fadt->x_gpe0_blk, sizeof(fwts_acpi_gas)))
+			fwts_failed(fw, LOG_LEVEL_HIGH,
+				"X_GPE0_BLKBadAccessWidth",
+				"FADT X_GPE0_BLK Access width 0x%2.2" PRIx8
+				" but it should be 1 (byte access).",
+				fadt->x_gpe0_blk.access_width);
 	}
 
 	if (fadt->x_gpe1_blk.access_width == 1)
 		fwts_passed(fw, "FADT X_GPE1_BLK has correct byte access width.");
 	else {
-		fwts_failed(fw, LOG_LEVEL_HIGH,
-			"X_GPE1_BLKBadAccessWidth",
-			"FADT X_GPE1_BLK Access width 0x%2.2" PRIx8
-			" but it should be 1 (byte access).",
-			fadt->x_gpe1_blk.access_width);
+		if (!fwts_acpi_data_zero((const void *) &fadt->x_gpe1_blk, sizeof(fwts_acpi_gas)))
+			fwts_failed(fw, LOG_LEVEL_HIGH,
+				"X_GPE1_BLKBadAccessWidth",
+				"FADT X_GPE1_BLK Access width 0x%2.2" PRIx8
+				" but it should be 1 (byte access).",
+				fadt->x_gpe1_blk.access_width);
 	}
 }
 
 static void acpi_table_check_fadt_sleep_control_reg(fwts_framework *fw)
 {
-	if (fwts_acpi_is_reduced_hardware(fadt)) {
+	if (fwts_acpi_is_reduced_hardware(fw)) {
 		if (fadt->sleep_control_reg.address == 0)
 			fwts_passed(fw, "FADT SLEEP_CONTROL_REG not in use.");
 		else {
@@ -1577,7 +1579,7 @@ static void acpi_table_check_fadt_sleep_control_reg(fwts_framework *fw)
 
 static void acpi_table_check_fadt_sleep_status_reg(fwts_framework *fw)
 {
-	if (fwts_acpi_is_reduced_hardware(fadt)) {
+	if (fwts_acpi_is_reduced_hardware(fw)) {
 		if (fadt->sleep_status_reg.address == 0)
 			fwts_passed(fw, "FADT SLEEP_STATUS_REG not in use.");
 		else {
@@ -1620,7 +1622,7 @@ static int fadt_test1(fwts_framework *fw)
 	 * there is no other info (as far as this author knows) that can be
 	 * used to verify that the value is correct.
 	 */
-	if (!fwts_acpi_is_reduced_hardware(fadt)) {
+	if (!fwts_acpi_is_reduced_hardware(fw)) {
 		fwts_log_info(fw, "FADT SCI_INT is %" PRIu8, fadt->sci_int);
 		acpi_table_check_fadt_smi_cmd(fw);
 		acpi_table_check_fadt_acpi_enable(fw);
@@ -1690,7 +1692,7 @@ static int fadt_test2(fwts_framework *fw)
 	uint32_t port, width, val32;
 	int ret = FWTS_OK;
 
-	if (fwts_acpi_is_reduced_hardware(fadt)) {
+	if (fwts_acpi_is_reduced_hardware(fw)) {
 		fwts_skipped(fw, "In reduced hardware mode, skipping test.");
 		return FWTS_OK;
 	}
@@ -1770,7 +1772,7 @@ static int fadt_test2(fwts_framework *fw)
 
 static int fadt_test3(fwts_framework *fw)
 {
-	if (fwts_acpi_is_reduced_hardware(fadt)) {
+	if (fwts_acpi_is_reduced_hardware(fw)) {
 		fwts_skipped(fw, "In reduced hardware mode, skipping test.");
 		return FWTS_OK;
 	}
