@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,21 +28,7 @@
 #include <ctype.h>
 
 static fwts_acpi_table_info *table;
-
-static int fpdt_init(fwts_framework *fw)
-{
-
-	if (fwts_acpi_find_table(fw, "FPDT", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI FPDT table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(FPDT, &table)
 
 static void fpdt_rec_header_dump(
 	fwts_framework *fw,
@@ -50,9 +36,9 @@ static void fpdt_rec_header_dump(
 	fwts_acpi_table_fpdt_header *header)
 {
 	fwts_log_info_verbatim(fw, "  %s:", type_name);
-	fwts_log_info_verbatim(fw, "    Perf Rec Type:	0x%4.4" PRIx16, header->type);
-	fwts_log_info_verbatim(fw, "    Rec Length:	0x%2.2" PRIx8, header->length);
-	fwts_log_info_verbatim(fw, "    Revision:	0x%2.2" PRIx8, header->revision);
+	fwts_log_info_simp_int(fw, "    Perf Rec Type:	", header->type);
+	fwts_log_info_simp_int(fw, "    Rec Length:	", header->length);
+	fwts_log_info_simp_int(fw, "    Revision:	", header->revision);
 }
 
 static void fpdt_dump_raw_data(
@@ -85,14 +71,7 @@ static int fpdt_test1(fwts_framework *fw)
 		goto done;
 	}
 
-	if (header->revision != 1) {
-		passed = false;
-		fwts_failed(fw, LOG_LEVEL_MEDIUM,
-			"FPDTBadRevision",
-			"FPDT revision is incorrect, expecting 0x01,"
-			" instead got 0x%2.2" PRIx8,
-			header->revision);
-	}
+	fwts_acpi_revision_check("FPDT", header->revision, 1, &passed);
 
 	ptr += sizeof(fwts_acpi_table_header);
 	while (ptr < data + table->length) {
@@ -121,8 +100,10 @@ static int fpdt_test1(fwts_framework *fw)
 					fbbpr->fpdt.length, sizeof(fwts_acpi_table_fpdt_basic_boot_perf_ptr));
 			} else {
 				fpdt_rec_header_dump(fw, "  Firmware Basic Boot Performance Pointer Record", fpdt);
-				fwts_log_info_verbatim(fw, "    Reserved:	0x%8.8" PRIx32, fbbpr->reserved);
-				fwts_log_info_verbatim(fw, "    FBPT Pointer:	0x%16.16" PRIx64, fbbpr->fbpt_addr);
+				fwts_log_info_simp_int(fw, "    Reserved:	", fbbpr->reserved);
+				fwts_log_info_simp_int(fw, "    FBPT Pointer:	", fbbpr->fbpt_addr);
+
+				fwts_acpi_reserved_zero_check("FPDT", "Reserved", fbbpr->reserved, &passed);
 
 				/*
 				 * For the moment, only dump the 64-bit processor-relative physical address
@@ -132,14 +113,8 @@ static int fpdt_test1(fwts_framework *fw)
 				fwts_log_info(fw, "Note: currently fwts does not check FBPT validity and the associated data");
 			}
 
-			if (fbbpr->fpdt.revision != 1) {
-				passed = false;
-				fwts_failed(fw, LOG_LEVEL_MEDIUM,
-					"FPDTInvalidRevision",
-					"FPDT: Revision field is 0x%" PRIx8
-					" and not the expected value of 0x01",
-					fbbpr->fpdt.revision);
-			}
+			fwts_acpi_fixed_value_check(fw, LOG_LEVEL_MEDIUM, "FPDT", "FBPT Revision", fbbpr->fpdt.revision, 1, &passed);
+
 			/* Spec doesn't mention Reserved field should be 0 or not, skip checking the reserved field */
 			break;
 		case 0x0001:	/* S3 Performance Table Pointer Record */
@@ -152,8 +127,10 @@ static int fpdt_test1(fwts_framework *fw)
 					s3ptpr->fpdt.length, sizeof(fwts_acpi_table_fpdt_s3_perf_ptr));
 			} else {
 				fpdt_rec_header_dump(fw, "S3 Performance Table Pointer Record", fpdt);
-				fwts_log_info_verbatim(fw, "    Reserved:	0x%8.8" PRIx32, s3ptpr->reserved);
-				fwts_log_info_verbatim(fw, "    S3PT Pointer:	0x%16.16" PRIx64, s3ptpr->s3pt_addr);
+				fwts_log_info_simp_int(fw, "    Reserved:	", s3ptpr->reserved);
+				fwts_log_info_simp_int(fw, "    S3PT Pointer:	", s3ptpr->s3pt_addr);
+
+				fwts_acpi_reserved_zero_check("FPDT", "Reserved", s3ptpr->reserved, &passed);
 
 				/*
 				 * For the moment, only dump 64-bit processor-relative physical
@@ -163,14 +140,8 @@ static int fpdt_test1(fwts_framework *fw)
 				fwts_log_info(fw, "Note: currently fwts does not check S3PT validity and the associated data");
 			}
 
-			if (s3ptpr->fpdt.revision != 1) {
-				passed = false;
-				fwts_failed(fw, LOG_LEVEL_MEDIUM,
-					"FPDTInvalidRevision",
-					"FPDT: Revision field is 0x%" PRIx8
-					" and not the expected value of 0x01",
-					s3ptpr->fpdt.revision);
-			}
+			fwts_acpi_fixed_value_check(fw, LOG_LEVEL_MEDIUM, "FPDT", "S3PT Revision", s3ptpr->fpdt.revision, 1, &passed);
+
 			/* Spec doesn't mention Reserved field should be 0 or not, skip checking the reserved field */
 			break;
 		case 0x0002 ... 0x0fff:
@@ -219,7 +190,7 @@ static fwts_framework_minor_test fpdt_tests[] = {
 
 static fwts_framework_ops fpdt_ops = {
 	.description = "FPDT Firmware Performance Data Table test.",
-	.init        = fpdt_init,
+	.init        = FPDT_init,
 	.minor_tests = fpdt_tests
 };
 
