@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -74,7 +74,7 @@ static int gtdt_test1(fwts_framework *fw)
 			"If not provided, this field must be 0xFFFFFFFFFFFFFFFF");
 	}
 
-	fwts_acpi_reserved_bits_check(fw, "GTDT", "Flags", gtdt->virtual_timer_flags, sizeof(gtdt->virtual_timer_flags), 3, 31, &passed);
+	fwts_acpi_reserved_bits_check("GTDT", "Flags", gtdt->virtual_timer_flags, 3, 31, &passed);
 
 	ptr = (uint8_t *)table->data + gtdt->platform_timer_offset;
 	n = gtdt->platform_timer_count;
@@ -188,16 +188,13 @@ static int gtdt_test1(fwts_framework *fw)
 				}
 
 				snprintf(field, sizeof(field), "block %" PRIu32 " physical timer flags", i);
-				fwts_acpi_reserved_bits_check(fw, "GTDT", field, block_timer->phys_timer_flags,
-					sizeof(block_timer->phys_timer_flags), 2, 31, &passed);
+				fwts_acpi_reserved_bits_check("GTDT", field, block_timer->phys_timer_flags, 2, 31, &passed);
 
 				snprintf(field, sizeof(field), "block %" PRIu32 " virtual timer flags", i);
-				fwts_acpi_reserved_bits_check(fw, "GTDT", field, block_timer->virt_timer_flags,
-					sizeof(block_timer->virt_timer_flags), 2, 31, &passed);
+				fwts_acpi_reserved_bits_check("GTDT", field, block_timer->virt_timer_flags, 2, 31, &passed);
 
 				snprintf(field, sizeof(field), "block %" PRIu32 " common flags", i);
-				fwts_acpi_reserved_bits_check(fw, "GTDT", field, block_timer->common_flags,
-					sizeof(block_timer->common_flags), 2, 31, &passed);
+				fwts_acpi_reserved_bits_check("GTDT", field, block_timer->common_flags, 2, 31, &passed);
 			}
 			ptr += block->length;
 			break;
@@ -245,8 +242,7 @@ static int gtdt_test1(fwts_framework *fw)
 			}
 
 			snprintf(field, sizeof(field), "SBSA generic watchdog timer %" PRIu32 " flags", i);
-			fwts_acpi_reserved_bits_check(fw, "GTDT", field, watchdog->watchdog_timer_flags,
-				sizeof(watchdog->watchdog_timer_flags), 3, 31, &passed);
+			fwts_acpi_reserved_bits_check("GTDT", field, watchdog->watchdog_timer_flags, 3, 31, &passed);
 
 			ptr += watchdog->length;
 			break;
