@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2020 Canonical
+ * Copyright (C) 2017-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,61 +24,53 @@
 #include <stdbool.h>
 
 static fwts_acpi_table_info *table;
-
-static int hmat_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "HMAT", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot load ACPI table");
-		return FWTS_ERROR;
-	}
-	if (table == NULL) {
-		fwts_log_error(fw, "ACPI HMAT table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(HMAT, &table)
 
 static void hmat_proximity_domain_test(fwts_framework *fw, const fwts_acpi_table_hmat_proximity_domain *entry, bool *passed)
 {
 	fwts_log_info_verbatim(fw, "  Memory Proximity Domain Attributes (Type 0):");
-	fwts_log_info_verbatim(fw, "    Type:                           0x%4.4" PRIx16, entry->header.type);
-	fwts_log_info_verbatim(fw, "    Reserved:                       0x%4.4" PRIx16, entry->header.reserved);
-	fwts_log_info_verbatim(fw, "    Length:                         0x%8.8" PRIx32, entry->header.length);
-	fwts_log_info_verbatim(fw, "    Flags:                          0x%4.4" PRIx16, entry->flags);
-	fwts_log_info_verbatim(fw, "    Reserved:                       0x%4.4" PRIx16, entry->reserved1);
-	fwts_log_info_verbatim(fw, "    Proximity Domain for Initiator: 0x%8.8" PRIx32, entry->initiator_proximity_domain);
-	fwts_log_info_verbatim(fw, "    Proximity Domain for Memory:    0x%8.8" PRIx32, entry->memory_proximity_domain);
-	fwts_log_info_verbatim(fw, "    Reserved:                       0x%8.8" PRIx32, entry->reserved2);
-	fwts_log_info_verbatim(fw, "    Reserved:                       0x%16.16" PRIx64, entry->reserved3);
-	fwts_log_info_verbatim(fw, "    Reserved:                       0x%16.16" PRIx64, entry->reserved4);
+	fwts_log_info_simp_int(fw, "    Type:                           ", entry->header.type);
+	fwts_log_info_simp_int(fw, "    Reserved:                       ", entry->header.reserved);
+	fwts_log_info_simp_int(fw, "    Length:                         ", entry->header.length);
+	fwts_log_info_simp_int(fw, "    Flags:                          ", entry->flags);
+	fwts_log_info_simp_int(fw, "    Reserved:                       ", entry->reserved1);
+	fwts_log_info_simp_int(fw, "    Proximity Domain for Initiator: ", entry->initiator_proximity_domain);
+	fwts_log_info_simp_int(fw, "    Proximity Domain for Memory:    ", entry->memory_proximity_domain);
+	fwts_log_info_simp_int(fw, "    Reserved:                       ", entry->reserved2);
+	fwts_log_info_simp_int(fw, "    Reserved:                       ", entry->reserved3);
+	fwts_log_info_simp_int(fw, "    Reserved:                       ", entry->reserved4);
 
-	fwts_acpi_reserved_zero_check(fw, "HMAT", "Reserved", entry->header.reserved, sizeof(entry->header.reserved), passed);
-	fwts_acpi_reserved_bits_check(fw, "HMAT", "Flags", entry->flags, sizeof(entry->flags), 1, 15, passed);
-	fwts_acpi_reserved_zero_check(fw, "HMAT", "Reserved", entry->reserved1, sizeof(entry->reserved1), passed);
-	fwts_acpi_reserved_zero_check(fw, "HMAT", "Reserved", entry->reserved2, sizeof(entry->reserved2), passed);
-	fwts_acpi_reserved_zero_check(fw, "HMAT", "Reserved", entry->reserved3, sizeof(entry->reserved3), passed);
-	fwts_acpi_reserved_zero_check(fw, "HMAT", "Reserved", entry->reserved4, sizeof(entry->reserved4), passed);
+	fwts_acpi_reserved_zero_check("HMAT", "Reserved", entry->header.reserved, passed);
+	fwts_acpi_reserved_bits_check("HMAT", "Flags", entry->flags, 1, 15, passed);
+	fwts_acpi_reserved_zero_check("HMAT", "Reserved", entry->reserved1, passed);
+	fwts_acpi_reserved_zero_check("HMAT", "Reserved", entry->reserved2, passed);
+	fwts_acpi_reserved_zero_check("HMAT", "Reserved", entry->reserved3, passed);
+	fwts_acpi_reserved_zero_check("HMAT", "Reserved", entry->reserved4, passed);
 }
 
 static void hmat_locality_test(fwts_framework *fw, const fwts_acpi_table_hmat_locality *entry, bool *passed)
 {
 	uint32_t pd_size;
+	uint16_t reserved1 = (entry->reserved1 << 8) + entry->min_transfer_size;
 
 	fwts_log_info_verbatim(fw, "  System Locality Latency and Bandwidth Information (Type 1):");
-	fwts_log_info_verbatim(fw, "    Type:                           0x%4.4" PRIx16, entry->header.type);
-	fwts_log_info_verbatim(fw, "    Reserved:                       0x%4.4" PRIx16, entry->header.reserved);
-	fwts_log_info_verbatim(fw, "    Length:                         0x%8.8" PRIx32, entry->header.length);
-	fwts_log_info_verbatim(fw, "    Flags:                          0x%2.2" PRIx8, entry->flags);
-	fwts_log_info_verbatim(fw, "    Data Type:                      0x%2.2" PRIx8, entry->data_type);
-	fwts_log_info_verbatim(fw, "    Reserved:                       0x%4.4" PRIx16, entry->reserved1);
-	fwts_log_info_verbatim(fw, "    Number of Initiator PDs:        0x%8.8" PRIx32, entry->num_initiator);
-	fwts_log_info_verbatim(fw, "    Number of Target PDs:           0x%8.8" PRIx32, entry->num_target);
-	fwts_log_info_verbatim(fw, "    Reserved:                       0x%8.8" PRIx32, entry->reserved2);
-	fwts_log_info_verbatim(fw, "    Entry Base Unit:                0x%16.16" PRIx64, entry->entry_base_unit);
+	fwts_log_info_simp_int(fw, "    Type:                           ", entry->header.type);
+	fwts_log_info_simp_int(fw, "    Reserved:                       ", entry->header.reserved);
+	fwts_log_info_simp_int(fw, "    Length:                         ", entry->header.length);
+	fwts_log_info_simp_int(fw, "    Flags:                          ", entry->flags);
+	fwts_log_info_simp_int(fw, "    Data Type:                      ", entry->data_type);
+	if (fwts_get_acpi_version(fw) >= FWTS_ACPI_VERSION_64) {
+		fwts_log_info_simp_int(fw, "    MinTransferSize:                ", entry->min_transfer_size);
+		fwts_log_info_simp_int(fw, "    Reserved:                       ", entry->reserved1);
+	} else
+		fwts_log_info_simp_int(fw, "    Reserved:                       ", reserved1);
+	fwts_log_info_simp_int(fw, "    Number of Initiator PDs:        ", entry->num_initiator);
+	fwts_log_info_simp_int(fw, "    Number of Target PDs:           ", entry->num_target);
+	fwts_log_info_simp_int(fw, "    Reserved:                       ", entry->reserved2);
+	fwts_log_info_simp_int(fw, "    Entry Base Unit:                ", entry->entry_base_unit);
 
-	fwts_acpi_reserved_zero_check(fw, "HMAT", "Reserved", entry->header.reserved, sizeof(entry->header.reserved), passed);
-	fwts_acpi_reserved_bits_check(fw, "HMAT", "Flags", entry->flags, sizeof(entry->flags), 4, 7, passed);
+	fwts_acpi_reserved_zero_check("HMAT", "Reserved", entry->header.reserved, passed);
+	fwts_acpi_reserved_bits_check("HMAT", "Flags", entry->flags, 6, 7, passed);
 
 	if (entry->data_type > 5) {
 		*passed = false;
@@ -88,8 +80,11 @@ static void hmat_locality_test(fwts_framework *fw, const fwts_acpi_table_hmat_lo
 			"0x%2.2" PRIx8 " instead", entry->data_type);
 	}
 
-	fwts_acpi_reserved_zero_check(fw, "HMAT", "Reserved", entry->reserved1, sizeof(entry->reserved1), passed);
-	fwts_acpi_reserved_zero_check(fw, "HMAT", "Reserved", entry->reserved2, sizeof(entry->reserved2), passed);
+	if (fwts_get_acpi_version(fw) >= FWTS_ACPI_VERSION_64)
+		fwts_acpi_reserved_zero_check("HMAT", "Reserved", entry->reserved1, passed);
+	else
+		fwts_acpi_reserved_zero_check("HMAT", "Reserved", reserved1, passed);
+	fwts_acpi_reserved_zero_check("HMAT", "Reserved", entry->reserved2, passed);
 
 	pd_size = (entry->num_initiator + entry->num_target) * 4 +
 	          (entry->num_initiator * entry->num_target * 2);
@@ -111,17 +106,17 @@ static void hmat_locality_test(fwts_framework *fw, const fwts_acpi_table_hmat_lo
 static void hmat_cache_test(fwts_framework *fw, const fwts_acpi_table_hmat_cache *entry, bool *passed)
 {
 	fwts_log_info_verbatim(fw, "  Memory Side Cache Information (Type 2):");
-	fwts_log_info_verbatim(fw, "    Type:                           0x%4.4" PRIx16, entry->header.type);
-	fwts_log_info_verbatim(fw, "    Reserved:                       0x%4.4" PRIx16, entry->header.reserved);
-	fwts_log_info_verbatim(fw, "    Length:                         0x%8.8" PRIx32, entry->header.length);
-	fwts_log_info_verbatim(fw, "    Proximity Domain for Memory:    0x%8.8" PRIx32, entry->memory_proximity_domain);
-	fwts_log_info_verbatim(fw, "    Reserved:                       0x%8.8" PRIx32, entry->reserved1);
-	fwts_log_info_verbatim(fw, "    Memory Side Cache Size:         0x%16.16" PRIx64, entry->cache_size);
-	fwts_log_info_verbatim(fw, "    Cache Attributes:               0x%8.8" PRIx32, entry->cache_attr);
-	fwts_log_info_verbatim(fw, "    Reserved:                       0x%4.4" PRIx16, entry->reserved2);
-	fwts_log_info_verbatim(fw, "    Number of SMBIOS Handles:       0x%4.4" PRIx16, entry->num_smbios);
+	fwts_log_info_simp_int(fw, "    Type:                           ", entry->header.type);
+	fwts_log_info_simp_int(fw, "    Reserved:                       ", entry->header.reserved);
+	fwts_log_info_simp_int(fw, "    Length:                         ", entry->header.length);
+	fwts_log_info_simp_int(fw, "    Proximity Domain for Memory:    ", entry->memory_proximity_domain);
+	fwts_log_info_simp_int(fw, "    Reserved:                       ", entry->reserved1);
+	fwts_log_info_simp_int(fw, "    Memory Side Cache Size:         ", entry->cache_size);
+	fwts_log_info_simp_int(fw, "    Cache Attributes:               ", entry->cache_attr);
+	fwts_log_info_simp_int(fw, "    Reserved:                       ", entry->reserved2);
+	fwts_log_info_simp_int(fw, "    Number of SMBIOS Handles:       ", entry->num_smbios);
 
-	fwts_acpi_reserved_zero_check(fw, "HMAT", "Reserved", entry->header.reserved, sizeof(entry->header.reserved), passed);
+	fwts_acpi_reserved_zero_check("HMAT", "Reserved", entry->header.reserved, passed);
 
 	if ((entry->cache_attr & 0xf) > 3 ||
 	   ((entry->cache_attr >> 4) & 0xf) > 3 ||
@@ -134,8 +129,8 @@ static void hmat_cache_test(fwts_framework *fw, const fwts_acpi_table_hmat_cache
 			"0x%8.8" PRIx32 " instead", entry->cache_attr);
 	}
 
-	fwts_acpi_reserved_zero_check(fw, "HMAT", "Reserved", entry->reserved1, sizeof(entry->reserved1), passed);
-	fwts_acpi_reserved_zero_check(fw, "HMAT", "Reserved", entry->reserved2, sizeof(entry->reserved2), passed);
+	fwts_acpi_reserved_zero_check("HMAT", "Reserved", entry->reserved1, passed);
+	fwts_acpi_reserved_zero_check("HMAT", "Reserved", entry->reserved2, passed);
 
 	if ((entry->header.length - sizeof(fwts_acpi_table_hmat_cache)) / 2 != entry->num_smbios) {
 		*passed = false;
@@ -154,10 +149,10 @@ static int hmat_test1(fwts_framework *fw)
 	uint32_t offset;
 
 	fwts_log_info_verbatim(fw, "HMAT Heterogeneous Memory Attribute Table:");
-	fwts_log_info_verbatim(fw, "  Reserved:        0x%2.2" PRIx8, hmat->reserved);
+	fwts_log_info_simp_int(fw, "  Reserved:        ", hmat->reserved);
 
 
-	fwts_acpi_reserved_zero_check(fw, "HMAT", "Reserved", hmat->reserved, sizeof(hmat->reserved), &passed);
+	fwts_acpi_reserved_zero_check("HMAT", "Reserved", hmat->reserved, &passed);
 
 	entry = (fwts_acpi_table_hmat_header *) (table->data + sizeof(fwts_acpi_table_hmat));
 	offset = sizeof(fwts_acpi_table_hmat);
@@ -231,7 +226,7 @@ static fwts_framework_minor_test hmat_tests[] = {
 
 static fwts_framework_ops hmat_ops = {
 	.description = "HMAT Heterogeneous Memory Attribute Table test.",
-	.init        = hmat_init,
+	.init        = HMAT_init,
 	.minor_tests = hmat_tests
 };
 
