@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,7 +18,7 @@
  */
 #include "fwts.h"
 
-#if defined(FWTS_HAS_ACPI)
+#if defined(FWTS_HAS_ACPI) && !(FWTS_ARCH_AARCH64)
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -27,21 +27,7 @@
 #include <string.h>
 
 static fwts_acpi_table_info *table;
-
-static int lpit_init(fwts_framework *fw)
-{
-
-	if (fwts_acpi_find_table(fw, "LPIT", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI LPIT table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(LPIT, &table)
 
 static void lpit_check_type_0(
 	fwts_framework *fw,
@@ -53,8 +39,8 @@ static void lpit_check_type_0(
 
 	/* We know table is at least long enough to access type and length.. */
 	fwts_log_info_verbatim(fw, "Native C-state based LPI structure:");
-	fwts_log_info_verbatim(fw, "  Type:                     0x%8.8" PRIx32, lpi->type);
-	fwts_log_info_verbatim(fw, "  Length:                   0x%8.8" PRIx32, lpi->length);
+	fwts_log_info_simp_int(fw, "  Type:                     ", lpi->type);
+	fwts_log_info_simp_int(fw, "  Length:                   ", lpi->length);
 
 	if (lpi->length < sizeof(fwts_acpi_table_lpit_c_state)) {
 		*passed = false;
@@ -68,34 +54,34 @@ static void lpit_check_type_0(
 		return;
 	}
 
-	fwts_log_info_verbatim(fw, "  ID:                       0x%4.4" PRIx16, lpi->id);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%4.4" PRIx16, lpi->reserved);
-	fwts_log_info_verbatim(fw, "  Flags:                    0x%8.8" PRIx32, lpi->flags);
+	fwts_log_info_simp_int(fw, "  ID:                       ", lpi->id);
+	fwts_log_info_simp_int(fw, "  Reserved:                 ", lpi->reserved);
+	fwts_log_info_simp_int(fw, "  Flags:                    ", lpi->flags);
 	fwts_log_info_verbatim(fw, "  Entry Trigger:");
-	fwts_log_info_verbatim(fw, "    Address Space ID:       0x%2.2" PRIx8, lpi->entry_trigger.address_space_id);
-	fwts_log_info_verbatim(fw, "    Register Bit Width      0x%2.2" PRIx8, lpi->entry_trigger.register_bit_width);
-	fwts_log_info_verbatim(fw, "    Register Bit Offset     0x%2.2" PRIx8, lpi->entry_trigger.register_bit_offset);
-	fwts_log_info_verbatim(fw, "    Access Size             0x%2.2" PRIx8, lpi->entry_trigger.access_width);
-	fwts_log_info_verbatim(fw, "    Address                 0x%16.16" PRIx64, lpi->entry_trigger.address);
-	fwts_log_info_verbatim(fw, "  Residency:                0x%8.8" PRIx32, lpi->residency);
-	fwts_log_info_verbatim(fw, "  Latency:                  0x%8.8" PRIx32, lpi->latency);
+	fwts_log_info_simp_int(fw, "    Address Space ID:       ", lpi->entry_trigger.address_space_id);
+	fwts_log_info_simp_int(fw, "    Register Bit Width      ", lpi->entry_trigger.register_bit_width);
+	fwts_log_info_simp_int(fw, "    Register Bit Offset     ", lpi->entry_trigger.register_bit_offset);
+	fwts_log_info_simp_int(fw, "    Access Size             ", lpi->entry_trigger.access_width);
+	fwts_log_info_simp_int(fw, "    Address                 ", lpi->entry_trigger.address);
+	fwts_log_info_simp_int(fw, "  Residency:                ", lpi->residency);
+	fwts_log_info_simp_int(fw, "  Latency:                  ", lpi->latency);
 
 	/* If flags [1] set, then counter is not available */
 	if (lpi->flags & 0x2) {
 		fwts_log_info_verbatim(fw, "  Residency Counter not available");
 	} else {
 		fwts_log_info_verbatim(fw, "  Residency Counter:");
-		fwts_log_info_verbatim(fw, "    Address Space ID:       0x%2.2" PRIx8, lpi->residency_counter.address_space_id);
-		fwts_log_info_verbatim(fw, "    Register Bit Width      0x%2.2" PRIx8, lpi->residency_counter.register_bit_width);
-		fwts_log_info_verbatim(fw, "    Register Bit Offset     0x%2.2" PRIx8, lpi->residency_counter.register_bit_offset);
-		fwts_log_info_verbatim(fw, "    Access Size             0x%2.2" PRIx8, lpi->residency_counter.access_width);
-		fwts_log_info_verbatim(fw, "    Address                 0x%16.16" PRIx64, lpi->residency_counter.address);
-		fwts_log_info_verbatim(fw, "  Residency Counter Freq:   0x%16.16" PRIx64, lpi->residency_counter_freq);
+		fwts_log_info_simp_int(fw, "    Address Space ID:       ", lpi->residency_counter.address_space_id);
+		fwts_log_info_simp_int(fw, "    Register Bit Width      ", lpi->residency_counter.register_bit_width);
+		fwts_log_info_simp_int(fw, "    Register Bit Offset     ", lpi->residency_counter.register_bit_offset);
+		fwts_log_info_simp_int(fw, "    Access Size             ", lpi->residency_counter.access_width);
+		fwts_log_info_simp_int(fw, "    Address                 ", lpi->residency_counter.address);
+		fwts_log_info_simp_int(fw, "  Residency Counter Freq:   ", lpi->residency_counter_freq);
 	}
 	fwts_log_nl(fw);
 
-	fwts_acpi_reserved_zero_check(fw, "LPIT", "Native C-state based LPI structure reserved", lpi->reserved, sizeof(lpi->reserved), passed);
-	fwts_acpi_reserved_bits_check(fw, "LPIT", "LPI structure flags", lpi->flags, sizeof(lpi->flags), 2, 31, passed);
+	fwts_acpi_reserved_zero_check("LPIT", "Native C-state based LPI structure reserved", lpi->reserved, passed);
+	fwts_acpi_reserved_bits_check("LPIT", "LPI structure flags", lpi->flags, 2, 31, passed);
 
 	/* 2.2.1.2, if FFH, then it is a MSR, check GAS fields */
 	if (((lpi->flags & 2) == 0) &&
@@ -231,7 +217,7 @@ static fwts_framework_minor_test lpit_tests[] = {
 
 static fwts_framework_ops lpit_ops = {
 	.description = "LPIT Low Power Idle Table test.",
-	.init        = lpit_init,
+	.init        = LPIT_init,
 	.minor_tests = lpit_tests
 };
 
