@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,7 +18,7 @@
  */
 #include "fwts.h"
 
-#ifdef FWTS_ARCH_INTEL
+#if defined(FWTS_HAS_ACPI)
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -29,6 +29,7 @@
 
 static fwts_list *memory_map_list;
 static fwts_acpi_table_info *mcfg_table;
+acpi_table_init(MCFG, &mcfg_table)
 
 static int compare_config_space(
 	fwts_framework *fw,
@@ -99,22 +100,6 @@ static int compare_config_space(
 	return FWTS_OK;
 }
 
-static int mcfg_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "MCFG", 0, &mcfg_table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot load ACPI table");
-		return FWTS_ERROR;
-	}
-	if (mcfg_table == NULL) {
-		fwts_log_error(fw,
-			"ACPI table MCFG not found. This table is "
-			"required to check for PCI Express*");
-		return FWTS_ERROR;
-	}
-
-	return FWTS_OK;
-}
-
 static int mcfg_deinit(fwts_framework *fw)
 {
 	FWTS_UNUSED(fw);
@@ -262,7 +247,7 @@ static fwts_framework_minor_test mcfg_tests[] = {
 
 static fwts_framework_ops mcfg_ops = {
 	.description = "MCFG PCI Express* memory mapped config space test.",
-	.init        = mcfg_init,
+	.init        = MCFG_init,
 	.deinit      = mcfg_deinit,
 	.minor_tests = mcfg_tests
 };
