@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,21 +29,7 @@
 #define DUMP_MCHI_TABLE		(1)	/* table is small and not used much, so dump it */
 
 static fwts_acpi_table_info *table;
-
-static int mchi_init(fwts_framework *fw)
-{
-
-	if (fwts_acpi_find_table(fw, "MCHI", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI MCHI table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(MCHI, &table)
 
 /*
  *  MCHI Management Controller Host Interface Table
@@ -61,8 +47,8 @@ static int mchi_test1(fwts_framework *fw)
 
 #if DUMP_MCHI_TABLE
 	fwts_log_info_verbatim(fw, "MCHI Table:");
-	fwts_log_info_verbatim(fw, "  Interface Type:           0x%2.2" PRIx8, mchi->interface_type);
-	fwts_log_info_verbatim(fw, "  Protocol Identifier       0x%2.2" PRIx8, mchi->protocol_identifier);
+	fwts_log_info_simp_int(fw, "  Interface Type:           ", mchi->interface_type);
+	fwts_log_info_simp_int(fw, "  Protocol Identifier       ", mchi->protocol_identifier);
 	fwts_log_info_verbatim(fw, "  Protocol Data:            "
 		"0x%2.2" PRIx8 " 0x%2.2" PRIx8 " 0x%2.2" PRIx8 " 0x%2.2" PRIx8,
 			mchi->protocol_data[0], mchi->protocol_data[1],
@@ -71,21 +57,21 @@ static int mchi_test1(fwts_framework *fw)
 		"0x%2.2" PRIx8 " 0x%2.2" PRIx8 " 0x%2.2" PRIx8 " 0x%2.2" PRIx8,
 			mchi->protocol_data[4], mchi->protocol_data[5],
 			mchi->protocol_data[6], mchi->protocol_data[7]);
-	fwts_log_info_verbatim(fw, "  Interrupt Type:           0x%2.2" PRIx8, mchi->interrupt_type);
-	fwts_log_info_verbatim(fw, "  GPE:                      0x%2.2" PRIx8, mchi->gpe);
-	fwts_log_info_verbatim(fw, "  PCI Device Flag:          0x%2.2" PRIx8, mchi->pci_device_flag);
-	fwts_log_info_verbatim(fw, "  Global System Interrupt:  0x%8.8" PRIx32, mchi->global_system_interrupt);
+	fwts_log_info_simp_int(fw, "  Interrupt Type:           ", mchi->interrupt_type);
+	fwts_log_info_simp_int(fw, "  GPE:                      ", mchi->gpe);
+	fwts_log_info_simp_int(fw, "  PCI Device Flag:          ", mchi->pci_device_flag);
+	fwts_log_info_simp_int(fw, "  Global System Interrupt:  ", mchi->global_system_interrupt);
 	fwts_log_info_verbatim(fw, "  Base Address:");
-	fwts_log_info_verbatim(fw, "    Address Space ID:       0x%2.2" PRIx8, mchi->base_address.address_space_id);
-	fwts_log_info_verbatim(fw, "    Register Bit Width      0x%2.2" PRIx8, mchi->base_address.register_bit_width);
-	fwts_log_info_verbatim(fw, "    Register Bit Offset     0x%2.2" PRIx8, mchi->base_address.register_bit_offset);
-	fwts_log_info_verbatim(fw, "    Access Size             0x%2.2" PRIx8, mchi->base_address.access_width);
-	fwts_log_info_verbatim(fw, "    Address                 0x%16.16" PRIx64, mchi->base_address.address);
+	fwts_log_info_simp_int(fw, "    Address Space ID:       ", mchi->base_address.address_space_id);
+	fwts_log_info_simp_int(fw, "    Register Bit Width      ", mchi->base_address.register_bit_width);
+	fwts_log_info_simp_int(fw, "    Register Bit Offset     ", mchi->base_address.register_bit_offset);
+	fwts_log_info_simp_int(fw, "    Access Size             ", mchi->base_address.access_width);
+	fwts_log_info_simp_int(fw, "    Address                 ", mchi->base_address.address);
 	if ((mchi->pci_device_flag & 1) == 1) {
-		fwts_log_info_verbatim(fw, "  PCI Segment Group:       0x%2.2" PRIx8, mchi->bytes[0]);
-		fwts_log_info_verbatim(fw, "  PCI Bus Number:          0x%2.2" PRIx8, mchi->bytes[1]);
-		fwts_log_info_verbatim(fw, "  PCI Device Number:       0x%2.2" PRIx8, mchi->bytes[2]);
-		fwts_log_info_verbatim(fw, "  PCI Function Number:     0x%2.2" PRIx8, mchi->bytes[3]);
+		fwts_log_info_simp_int(fw, "  PCI Segment Group:       ", mchi->bytes[0]);
+		fwts_log_info_simp_int(fw, "  PCI Bus Number:          ", mchi->bytes[1]);
+		fwts_log_info_simp_int(fw, "  PCI Device Number:       ", mchi->bytes[2]);
+		fwts_log_info_simp_int(fw, "  PCI Function Number:     ", mchi->bytes[3]);
 	} else {
 		/* Zero -> UIDS */
 		fwts_log_info_verbatim(fw, "  UID Bytes 1-4:            "
@@ -112,7 +98,7 @@ static int mchi_test1(fwts_framework *fw)
 			"255 (OEM defined)", mchi->protocol_identifier);
 	}
 
-	fwts_acpi_reserved_bits_check(fw, "MCHI", "Interrupt Type", mchi->interrupt_type, sizeof(mchi->interrupt_type), 2, 7, &passed);
+	fwts_acpi_reserved_bits_check("MCHI", "Interrupt Type", mchi->interrupt_type, 2, 7, &passed);
 
 	if (((mchi->interrupt_type & 0x01) == 0) &&
 	    (mchi->gpe != 0)) {
@@ -125,7 +111,7 @@ static int mchi_test1(fwts_framework *fw)
 			mchi->gpe);
 	}
 
-	fwts_acpi_reserved_bits_check(fw, "MCHI", "PCI Device Flag", mchi->pci_device_flag, sizeof(mchi->pci_device_flag), 1, 7, &passed);
+	fwts_acpi_reserved_bits_check("MCHI", "PCI Device Flag", mchi->pci_device_flag, 1, 7, &passed);
 
 	if (((mchi->interrupt_type & 0x02) == 0) &&
 	    (mchi->global_system_interrupt != 0)) {
@@ -137,19 +123,13 @@ static int mchi_test1(fwts_framework *fw)
 			mchi->global_system_interrupt);
 	}
 
-	if ((mchi->base_address.address_space_id != 0x00) &&
-	    (mchi->base_address.address_space_id != 0x01) &&
-	    (mchi->base_address.address_space_id != 0x04)) {
-		passed = false;
-		fwts_failed(fw, LOG_LEVEL_HIGH,
-			"MCHIAddrSpaceIdInvalid",
-			"MCHI Address Space ID is 0x%2.2" PRIx8 " and should be "
-			"0x00 (System Memory), 0x01 (System I/O) or 0x04 (SMBus)",
-			mchi->base_address.address_space_id);
-	}
+	fwts_acpi_space_id_check(fw, "MCHI", "Base Address", &passed, mchi->base_address.address_space_id, 3,
+				 FWTS_GAS_ADDR_SPACE_ID_SYSTEM_MEMORY,
+				 FWTS_GAS_ADDR_SPACE_ID_SYSTEM_IO,
+				 FWTS_GAS_ADDR_SPACE_ID_SMBUS);
 
 	/* SMBus specific checks */
-	if (mchi->base_address.address_space_id == 0x04) {
+	if (mchi->base_address.address_space_id == FWTS_GAS_ADDR_SPACE_ID_SMBUS) {
 		if ((mchi->pci_device_flag & 0x01) == 1) {
 			passed = false;
 			fwts_failed(fw, LOG_LEVEL_HIGH,
@@ -225,7 +205,7 @@ static fwts_framework_minor_test mchi_tests[] = {
 
 static fwts_framework_ops mchi_ops = {
 	.description = "MCHI Management Controller Host Interface Table test.",
-	.init        = mchi_init,
+	.init        = MCHI_init,
 	.minor_tests = mchi_tests
 };
 
