@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016-2020 Canonical
+ * Copyright (C) 2016-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,19 +26,7 @@
 #include <ctype.h>
 
 static fwts_acpi_table_info *table;
-
-static int msct_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "MSCT", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI MSCT table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-	return FWTS_OK;
-}
+acpi_table_init(MSCT, &table)
 
 /*
  *  MSCT Maximum System Characteristics Table
@@ -52,14 +40,10 @@ static int msct_test1(fwts_framework *fw)
 	bool passed = true;
 
 	fwts_log_info_verbatim(fw, "MSCT Max System Characteristics Table:");
-	fwts_log_info_verbatim(fw, "  Proximity Offset:      0x%8.8" PRIx32,
-			msct->proximity_offset);
-	fwts_log_info_verbatim(fw, "  Max Proximity Domains: 0x%8.8" PRIx32,
-			msct->max_proximity_domains);
-	fwts_log_info_verbatim(fw, "  Max Clock Domains:     0x%8.8" PRIx32,
-			msct->max_clock_domains);
-	fwts_log_info_verbatim(fw, "  Max Physical Address:  0x%16.16" PRIx64,
-			msct->max_address);
+	fwts_log_info_simp_int(fw, "  Proximity Offset:      ",	msct->proximity_offset);
+	fwts_log_info_simp_int(fw, "  Max Proximity Domains: ",	msct->max_proximity_domains);
+	fwts_log_info_simp_int(fw, "  Max Clock Domains:     ",	msct->max_clock_domains);
+	fwts_log_info_simp_int(fw, "  Max Physical Address:  ",	msct->max_address);
 
 	if (msct->proximity_offset < 0x38) {
 		fwts_failed(fw, LOG_LEVEL_MEDIUM,
@@ -127,7 +111,7 @@ static fwts_framework_minor_test msct_tests[] = {
 
 static fwts_framework_ops msct_ops = {
 	.description = "MSCT Maximum System Characteristics Table test.",
-	.init        = msct_init,
+	.init        = MSCT_init,
 	.minor_tests = msct_tests
 };
 
