@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -123,20 +123,20 @@ static void pcc_check_pcc_header(
 		return;
 	}
 
-	fwts_log_info_verbatim(fw, "PCC header at 0x%" PRIx64 ".", addr);
-	fwts_log_info_verbatim(fw, "  Signature:          0x%" PRIx32, hdr->signature);
-	fwts_log_info_verbatim(fw, "  Length:             0x%" PRIx16, hdr->length);
-	fwts_log_info_verbatim(fw, "  Major:              0x%" PRIx8,  hdr->major);
-	fwts_log_info_verbatim(fw, "  Minor:              0x%" PRIx8,  hdr->minor);
-	fwts_log_info_verbatim(fw, "  Features:           0x%" PRIx32, hdr->features);
-	fwts_log_info_verbatim(fw, "  Command:            0x%" PRIx16, hdr->command);
-	fwts_log_info_verbatim(fw, "  Status:             0x%" PRIx16, hdr->status);
-	fwts_log_info_verbatim(fw, "  Latency:            0x%" PRIx32, hdr->latency);
-	fwts_log_info_verbatim(fw, "  Minimum Time:       0x%" PRIx32, hdr->minimum_time);
-	fwts_log_info_verbatim(fw, "  Maximum Time:       0x%" PRIx32, hdr->maximum_time);
-	fwts_log_info_verbatim(fw, "  Nominal:            0x%" PRIx32, hdr->nominal);
-	fwts_log_info_verbatim(fw, "  Throttled Freq.:    0x%" PRIx32, hdr->throttled_frequency);
-	fwts_log_info_verbatim(fw, "  Minimum Freq.:      0x%" PRIx32, hdr->minimum_frequency);
+	fwts_log_info_simp_int(fw, "PCC header at ", addr);
+	fwts_log_info_simp_int(fw, "  Signature:          ", hdr->signature);
+	fwts_log_info_simp_int(fw, "  Length:             ", hdr->length);
+	fwts_log_info_simp_int(fw, "  Major:              ", hdr->major);
+	fwts_log_info_simp_int(fw, "  Minor:              ", hdr->minor);
+	fwts_log_info_simp_int(fw, "  Features:           ", hdr->features);
+	fwts_log_info_simp_int(fw, "  Command:            ", hdr->command);
+	fwts_log_info_simp_int(fw, "  Status:             ", hdr->status);
+	fwts_log_info_simp_int(fw, "  Latency:            ", hdr->latency);
+	fwts_log_info_simp_int(fw, "  Minimum Time:       ", hdr->minimum_time);
+	fwts_log_info_simp_int(fw, "  Maximum Time:       ", hdr->maximum_time);
+	fwts_log_info_simp_int(fw, "  Nominal:            ", hdr->nominal);
+	fwts_log_info_simp_int(fw, "  Throttled Freq.:    ", hdr->throttled_frequency);
+	fwts_log_info_simp_int(fw, "  Minimum Freq.:      ", hdr->minimum_frequency);
 
 	fwts_munmap(hdr, (size_t)length);
 	fwts_log_nl(fw);
@@ -191,15 +191,15 @@ static void pcc_check_shared_memory_region(
 	pcc_mr = (fwts_pcc_memory_resource *)pcc_obj->Buffer.Pointer;
 
 	fwts_log_info_verbatim(fw, "PCC Memory Resource (Shared Memory Region) for %s:", name);
-	fwts_log_info_verbatim(fw, "  Descriptor:         0x%" PRIx8, pcc_mr->descriptor);
-	fwts_log_info_verbatim(fw, "  Length:             0x%" PRIx8, pcc_mr->length);
-	fwts_log_info_verbatim(fw, "  Space ID:           0x%" PRIx8, pcc_mr->space_id);
-	fwts_log_info_verbatim(fw, "  Resource Usage:     0x%" PRIx8, pcc_mr->resource_usage);
-	fwts_log_info_verbatim(fw, "  Type Specific:      0x%" PRIx8, pcc_mr->type_specific);
-	fwts_log_info_verbatim(fw, "  Minimum:            0x%" PRIx64, pcc_mr->minimum);
-	fwts_log_info_verbatim(fw, "  Maximum:            0x%" PRIx64, pcc_mr->maximum);
-	fwts_log_info_verbatim(fw, "  Translation Offset: 0x%" PRIx64, pcc_mr->translation_offset);
-	fwts_log_info_verbatim(fw, "  Address Length:     0x%" PRIx64, pcc_mr->address_length);
+	fwts_log_info_simp_int(fw, "  Descriptor:         ", pcc_mr->descriptor);
+	fwts_log_info_simp_int(fw, "  Length:             ", pcc_mr->length);
+	fwts_log_info_simp_int(fw, "  Space ID:           ", pcc_mr->space_id);
+	fwts_log_info_simp_int(fw, "  Resource Usage:     ", pcc_mr->resource_usage);
+	fwts_log_info_simp_int(fw, "  Type Specific:      ", pcc_mr->type_specific);
+	fwts_log_info_simp_int(fw, "  Minimum:            ", pcc_mr->minimum);
+	fwts_log_info_simp_int(fw, "  Maximum:            ", pcc_mr->maximum);
+	fwts_log_info_simp_int(fw, "  Translation Offset: ", pcc_mr->translation_offset);
+	fwts_log_info_simp_int(fw, "  Address Length:     ", pcc_mr->address_length);
 
 	if (pcc_mr->space_id != ACPI_ADR_SPACE_SYSTEM_MEMORY) {
 		fwts_failed(fw, LOG_LEVEL_HIGH, "PCCMemoryResourceSpaceIdWrongType",
@@ -291,13 +291,13 @@ static void pcc_check_doorbell_address(
 	pcc_rr = (fwts_pcc_register_resource *)pcc_obj->Buffer.Pointer;
 
 	fwts_log_info_verbatim(fw, "PCC Register Resource (Doorbell) for %s:", name);
-	fwts_log_info_verbatim(fw, "  Descriptor:         0x%" PRIx8, pcc_rr->descriptor);
-	fwts_log_info_verbatim(fw, "  Length:             0x%" PRIx8, pcc_rr->length);
-	fwts_log_info_verbatim(fw, "  Space ID:           0x%" PRIx8, pcc_rr->space_id);
-	fwts_log_info_verbatim(fw, "  Bit Width:          0x%" PRIx8, pcc_rr->bit_width);
-	fwts_log_info_verbatim(fw, "  Bit Offset:         0x%" PRIx8, pcc_rr->bit_offset);
-	fwts_log_info_verbatim(fw, "  Access Size:        0x%" PRIx8, pcc_rr->access_size);
-	fwts_log_info_verbatim(fw, "  Address:            0x%" PRIx64, pcc_rr->address);
+	fwts_log_info_simp_int(fw, "  Descriptor:         ", pcc_rr->descriptor);
+	fwts_log_info_simp_int(fw, "  Length:             ", pcc_rr->length);
+	fwts_log_info_simp_int(fw, "  Space ID:           ", pcc_rr->space_id);
+	fwts_log_info_simp_int(fw, "  Bit Width:          ", pcc_rr->bit_width);
+	fwts_log_info_simp_int(fw, "  Bit Offset:         ", pcc_rr->bit_offset);
+	fwts_log_info_simp_int(fw, "  Access Size:        ", pcc_rr->access_size);
+	fwts_log_info_simp_int(fw, "  Address:            ", pcc_rr->address);
 
 	if (pcc_rr->space_id != ACPI_ADR_SPACE_SYSTEM_IO) {
 		fwts_failed(fw, LOG_LEVEL_HIGH, "PCCRegisterResourceSpaceIdWrongType",
@@ -340,7 +340,7 @@ static void pcc_check_doorbell_preserve_mask(
 	}
 
 	fwts_log_info_verbatim(fw, "PCC Doorbell Preserve Mask for %s:", name);
-	fwts_log_info_verbatim(fw, "  Preserve Mask:      0x%" PRIx64, pcc_obj->Integer.Value);
+	fwts_log_info_simp_int(fw, "  Preserve Mask:      ", pcc_obj->Integer.Value);
 	fwts_log_nl(fw);
 }
 
@@ -360,7 +360,7 @@ static void pcc_check_doorbell_write_mask(
 	}
 
 	fwts_log_info_verbatim(fw, "PCC Doorbell Write Mask for %s:", name);
-	fwts_log_info_verbatim(fw, "  Write Mask:         0x%" PRIx64, pcc_obj->Integer.Value);
+	fwts_log_info_simp_int(fw, "  Write Mask:         ", pcc_obj->Integer.Value);
 	fwts_log_nl(fw);
 
 	if (pcc_obj->Integer.Value == 0) {
