@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,7 +18,7 @@
  */
 #include "fwts.h"
 
-#if defined(FWTS_HAS_ACPI)
+#if defined(FWTS_HAS_ACPI) && !(FWTS_ARCH_AARCH64)
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -29,21 +29,7 @@
 #define	DUMP_SLIC	(0)	/* Disable this, just used it for debugging */
 
 static fwts_acpi_table_info *table;
-
-static int slic_init(fwts_framework *fw)
-{
-
-	if (fwts_acpi_find_table(fw, "SLIC", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI SLIC table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(SLIC, &table)
 
 /*
  *  Software Licensing Description Table
@@ -72,8 +58,8 @@ static int slic_test1(fwts_framework *fw)
 		if (hdr->length < sizeof(fwts_acpi_table_slic_header))
 			break;
 #if DUMP_SLIC
-		fwts_log_info_verbatim(fw, "  Type:                     0x%8.8" PRIx32, hdr->type);
-		fwts_log_info_verbatim(fw, "  Length:                   0x%8.8" PRIx32, hdr->length);
+		fwts_log_info_simp_int(fw, "  Type:                     ", hdr->type);
+		fwts_log_info_simp_int(fw, "  Length:                   ", hdr->length);
 #endif
 
 		switch (hdr->type) {
@@ -93,14 +79,14 @@ static int slic_test1(fwts_framework *fw)
 #if DUMP_SLIC
 
 				fwts_log_info_verbatim(fw, "  SLIC Public Key:\n");
-				fwts_log_info_verbatim(fw, "    Key Type:               0x%2.2" PRIx8, key->key_type);
-				fwts_log_info_verbatim(fw, "    Version:                0x%2.2" PRIx8, key->version);
-				fwts_log_info_verbatim(fw, "    Reserved:               0x%4.4" PRIx16, key->reserved);
-				fwts_log_info_verbatim(fw, "    Algorithm:              0x%8.8" PRIx32, key->algorithm);
+				fwts_log_info_simp_int(fw, "    Key Type:               ", key->key_type);
+				fwts_log_info_simp_int(fw, "    Version:                ", key->version);
+				fwts_log_info_simp_int(fw, "    Reserved:               ", key->reserved);
+				fwts_log_info_simp_int(fw, "    Algorithm:              ", key->algorithm);
 				fwts_log_info_verbatim(fw, "    Magic:                  '%c%c%c%c'",
 					key->magic[0], key->magic[1], key->magic[2], key->magic[3]);
-				fwts_log_info_verbatim(fw, "    Bit Length:             0x%8.8" PRIx32, key->bit_length);
-				fwts_log_info_verbatim(fw, "    Exponent:               0x%8.8" PRIx32, key->exponent);
+				fwts_log_info_simp_int(fw, "    Bit Length:             ", key->bit_length);
+				fwts_log_info_simp_int(fw, "    Exponent:               ", key->exponent);
 				/* For the moment, don't dump the modulus */
 #endif
 			}
@@ -122,11 +108,11 @@ static int slic_test1(fwts_framework *fw)
 				fwts_log_info(fw, "SLIC Windows Marker Structure has had minimal check due to proprietary nature of the table");
 #if DUMP_SLIC
 				fwts_log_info_verbatim(fw, "  SLIC Windows Marker:\n");
-				fwts_log_info_verbatim(fw, "    Version:                0x%2.2" PRIx8, marker->version);
+				fwts_log_info_simp_int(fw, "    Version:                ", marker->version);
 				fwts_log_info_verbatim(fw, "    OEM ID:                 '%6.6s'", marker->oem_id);
 				fwts_log_info_verbatim(fw, "    OEM Table ID:           '%8.8s'", marker->oem_table_id);
 				fwts_log_info_verbatim(fw, "    Windows Flag:           '%8.8s'", marker->windows_flag);
-				fwts_log_info_verbatim(fw, "    SLIC Version:           0x%4.4" PRIx32, marker->slic_version);
+				fwts_log_info_simp_int(fw, "    SLIC Version:           ", marker->slic_version);
 				fwts_log_info_verbatim(fw, "    Reserved:               "
 					"0x%2.2" PRIx8 " 0x%2.2" PRIx8 " 0x%2.2" PRIx8 " 0x%2.2" PRIx8,
 					marker->reserved[0], marker->reserved[1], marker->reserved[2], marker->reserved[3]);
@@ -170,7 +156,7 @@ static fwts_framework_minor_test slic_tests[] = {
 
 static fwts_framework_ops slic_ops = {
 	.description = "SLIC Software Licensing Description Table test.",
-	.init        = slic_init,
+	.init        = SLIC_init,
 	.minor_tests = slic_tests
 };
 
