@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -143,7 +143,7 @@ static int spcr_test1(fwts_framework *fw)
 	}
 
 	reserved1 = spcr->reserved1[0] + (spcr->reserved1[1] << 8) + (spcr->reserved1[2] << 16);
-	fwts_acpi_reserved_zero_check(fw, "SPCR", "Reserved1", reserved1, sizeof(reserved1), &passed);
+	fwts_acpi_reserved_zero_check("SPCR", "Reserved1", reserved1, &passed);
 
 	if (spcr->interrupt_type == 0) {
 		passed = false;
@@ -202,23 +202,9 @@ static int spcr_test1(fwts_framework *fw)
 			" is a reserved baud rate", spcr->baud_rate);
 	}
 
-	if (spcr->parity != 0) {
-		passed = false;
-		fwts_failed(fw, LOG_LEVEL_HIGH,
-			"SPCRReservedValueUsed",
-			"SPCR Parity field must be zero, got 0x%2.2" PRIx8 " instead",
-			spcr->parity);
-	}
-
-	if (spcr->stop_bits != 1) {
-		passed = false;
-		fwts_failed(fw, LOG_LEVEL_HIGH,
-			"SPCRReservedValueUsed",
-			"SPCR Stop field must be 1, got 0x%2.2" PRIx8 " instead",
-			spcr->stop_bits);
-	}
-
-	fwts_acpi_reserved_bits_check(fw, "SPCR", "Flow control", spcr->flow_control, sizeof(spcr->flow_control), 3, 7, &passed);
+	fwts_acpi_fixed_value_check(fw, LOG_LEVEL_HIGH, "SPCR", "Parity", spcr->parity, 0, &passed);
+	fwts_acpi_fixed_value_check(fw, LOG_LEVEL_HIGH, "SPCR", "Stop", spcr->stop_bits, 1, &passed);
+	fwts_acpi_reserved_bits_check("SPCR", "Flow control", spcr->flow_control, 3, 7, &passed);
 
 	reserved = false;
 	switch (spcr->terminal_type) {
@@ -247,7 +233,7 @@ static int spcr_test1(fwts_framework *fw)
 			" is a reserved terminal type", spcr->terminal_type);
 	}
 
-	fwts_acpi_reserved_zero_check(fw, "SPCR", "Reserved2", spcr->reserved2, sizeof(spcr->reserved2), &passed);
+	fwts_acpi_reserved_zero_check("SPCR", "Reserved2", spcr->reserved2, &passed);
 
 	/* According to the spec, these values indicate NOT a PCI device */
 	if ((spcr->pci_device_id == 0xffff) &&
@@ -285,8 +271,8 @@ static int spcr_test1(fwts_framework *fw)
 		}
 	}
 
-	fwts_acpi_reserved_bits_check(fw, "SPCR", "PCI Flags", spcr->pci_flags, sizeof(spcr->pci_flags), 1, 31, &passed);
-	fwts_acpi_reserved_zero_check(fw, "SPCR", "Reserved3", spcr->reserved3, sizeof(spcr->reserved3), &passed);
+	fwts_acpi_reserved_bits_check("SPCR", "PCI Flags", spcr->pci_flags, 1, 31, &passed);
+	fwts_acpi_reserved_zero_check("SPCR", "Reserved3", spcr->reserved3, &passed);
 
 	if (passed)
 		fwts_passed(fw, "No issues found in SPCR table.");
