@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,21 +27,7 @@
 #include <string.h>
 
 static fwts_acpi_table_info *table;
-
-static int spmi_init(fwts_framework *fw)
-{
-
-	if (fwts_acpi_find_table(fw, "SPMI", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI SPMI table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(SPMI, &table)
 
 /*
  *  SPMI Service Processor Management Interface Description Table
@@ -81,24 +67,24 @@ static int spmi_test1(fwts_framework *fw)
 	fwts_log_info_verbatim(fw, "SPMI Service Processor Management Interface Description Table:");
 	fwts_log_info_verbatim(fw, "  Interface Type:           0x%2.2" PRIx8 " (%s)",
 		spmi->interface_type, interface_type);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%2.2" PRIx8, spmi->reserved1);
-	fwts_log_info_verbatim(fw, "  Specification Revision:   0x%2.2" PRIx8, spmi->specification_revision);
-	fwts_log_info_verbatim(fw, "  Interrupt Type:           0x%2.2" PRIx8, spmi->interrupt_type);
-	fwts_log_info_verbatim(fw, "  GPE:                      0x%2.2" PRIx8, spmi->gpe);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%2.2" PRIx8, spmi->reserved2);
-	fwts_log_info_verbatim(fw, "  PCI Device Flag:          0x%2.2" PRIx8, spmi->pci_device_flag);
-	fwts_log_info_verbatim(fw, "  Global System Interrupt   0x%8.8" PRIx32, spmi->global_system_interrupt);
+	fwts_log_info_simp_int(fw, "  Reserved:                 ", spmi->reserved1);
+	fwts_log_info_simp_int(fw, "  Specification Revision:   ", spmi->specification_revision);
+	fwts_log_info_simp_int(fw, "  Interrupt Type:           ", spmi->interrupt_type);
+	fwts_log_info_simp_int(fw, "  GPE:                      ", spmi->gpe);
+	fwts_log_info_simp_int(fw, "  Reserved:                 ", spmi->reserved2);
+	fwts_log_info_simp_int(fw, "  PCI Device Flag:          ", spmi->pci_device_flag);
+	fwts_log_info_simp_int(fw, "  Global System Interrupt   ", spmi->global_system_interrupt);
 	fwts_log_info_verbatim(fw, "  Base Address:");
-	fwts_log_info_verbatim(fw, "    Address Space ID:       0x%2.2" PRIx8, spmi->base_address.address_space_id);
-	fwts_log_info_verbatim(fw, "    Register Bit Width      0x%2.2" PRIx8, spmi->base_address.register_bit_width);
-	fwts_log_info_verbatim(fw, "    Register Bit Offset     0x%2.2" PRIx8, spmi->base_address.register_bit_offset);
-	fwts_log_info_verbatim(fw, "    Access Size             0x%2.2" PRIx8, spmi->base_address.access_width);
-	fwts_log_info_verbatim(fw, "    Address                 0x%16.16" PRIx64, spmi->base_address.address);
-	fwts_log_info_verbatim(fw, "  PCI Segment Group:        0x%2.2" PRIx8, spmi->pci_segment_group_number);
-	fwts_log_info_verbatim(fw, "  PCI Bus:                  0x%2.2" PRIx8, spmi->pci_bus_number);
-	fwts_log_info_verbatim(fw, "  PCI Device:               0x%2.2" PRIx8, spmi->pci_device_number);
-	fwts_log_info_verbatim(fw, "  PCI Function:             0x%2.2" PRIx8, spmi->pci_function_number);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%2.2" PRIx8, spmi->reserved3);
+	fwts_log_info_simp_int(fw, "    Address Space ID:       ", spmi->base_address.address_space_id);
+	fwts_log_info_simp_int(fw, "    Register Bit Width      ", spmi->base_address.register_bit_width);
+	fwts_log_info_simp_int(fw, "    Register Bit Offset     ", spmi->base_address.register_bit_offset);
+	fwts_log_info_simp_int(fw, "    Access Size             ", spmi->base_address.access_width);
+	fwts_log_info_simp_int(fw, "    Address                 ", spmi->base_address.address);
+	fwts_log_info_simp_int(fw, "  PCI Segment Group:        ", spmi->pci_segment_group_number);
+	fwts_log_info_simp_int(fw, "  PCI Bus:                  ", spmi->pci_bus_number);
+	fwts_log_info_simp_int(fw, "  PCI Device:               ", spmi->pci_device_number);
+	fwts_log_info_simp_int(fw, "  PCI Function:             ", spmi->pci_function_number);
+	fwts_log_info_simp_int(fw, "  Reserved:                 ", spmi->reserved3);
 	fwts_log_nl(fw);
 
 	if (spmi->interface_type < 1 || spmi->interface_type > 4) {
@@ -110,15 +96,8 @@ static int spmi_test1(fwts_framework *fw)
 			spmi->interface_type);
 	}
 
-	if (spmi->reserved1 != 1) {
-		passed = false;
-		fwts_failed(fw, LOG_LEVEL_LOW,
-			"SPMIReserved1Not1",
-			"SPMI reserved field (offset 37) must be 0x01, got "
-			"0x%2.2" PRIx8 " instead", spmi->reserved1);
-	}
-
-	fwts_acpi_reserved_bits_check(fw, "SPMI", "Interrupt type", spmi->interrupt_type, sizeof(spmi->interrupt_type), 2, 7, &passed);
+	fwts_acpi_fixed_value_check(fw, LOG_LEVEL_MEDIUM, "SPMI", "Reserved1", spmi->reserved1, 1, &passed);
+	fwts_acpi_reserved_bits_check("SPMI", "Interrupt type", spmi->interrupt_type, 2, 7, &passed);
 
 	/* Check for zero GPE on specific condition of interrupt type */
 	if (((spmi->interrupt_type & 1) == 0) &&
@@ -130,15 +109,9 @@ static int spmi_test1(fwts_framework *fw)
 			"Type bit 0 (SCI triggered through GPE) is set to 0",
 			spmi->gpe);
 	}
-	if (spmi->reserved2 != 0) {
-		passed = false;
-		fwts_failed(fw, LOG_LEVEL_LOW,
-			"SPMIReserved1NonZero",
-			"SPMI reserved field (offset 42) must be 0x00, got "
-			"0x%2.2" PRIx8 " instead", spmi->reserved2);
-	}
 
-	fwts_acpi_reserved_bits_check(fw, "SPMI", "PCI device flag", spmi->pci_device_flag, sizeof(spmi->pci_device_flag), 1, 7, &passed);
+	fwts_acpi_reserved_zero_check("SPMI", "Reserved2", spmi->reserved2, &passed);
+	fwts_acpi_reserved_bits_check("SPMI", "PCI device flag", spmi->pci_device_flag, 1, 7, &passed);
 
 	if (((spmi->interrupt_type & 2) == 0) &&
 	    (spmi->global_system_interrupt != 0)) {
@@ -152,21 +125,11 @@ static int spmi_test1(fwts_framework *fw)
 	}
 
 	/* Base address must be one of 3 types, System Memory, System I/O or SMBUS */
-	if ((spmi->base_address.address_space_id != FWTS_GAS_ADDR_SPACE_ID_SYSTEM_MEMORY) &&
-	    (spmi->base_address.address_space_id != FWTS_GAS_ADDR_SPACE_ID_SYSTEM_IO) &&
-	    (spmi->base_address.address_space_id != FWTS_GAS_ADDR_SPACE_ID_SMBUS)) {
-		passed = false;
-		fwts_failed(fw, LOG_LEVEL_MEDIUM,
-			"SPMIBaseAddressSpaceID",
-			"SPMI Base Address Space ID is 0x%2.2" PRIx8 " but should be one of "
-			"0x%2.2" PRIx8 " (System Memory), "
-			"0x%2.2" PRIx8 " (System I/O) or "
-			"0x%2.2" PRIx8 " (SMBUS)",
-			spmi->base_address.address_space_id,
-			FWTS_GAS_ADDR_SPACE_ID_SYSTEM_MEMORY,
-			FWTS_GAS_ADDR_SPACE_ID_SYSTEM_IO,
-			FWTS_GAS_ADDR_SPACE_ID_SMBUS);
-	}
+	fwts_acpi_space_id_check(fw, "SPMI", "Base Address", &passed, spmi->base_address.address_space_id, 3,
+				 FWTS_GAS_ADDR_SPACE_ID_SYSTEM_MEMORY,
+				 FWTS_GAS_ADDR_SPACE_ID_SYSTEM_IO,
+				 FWTS_GAS_ADDR_SPACE_ID_SMBUS);
+
 	/*
 	 * For SSIF: The Address_Space_ID is SMBUS and the address field of the GAS
 	 * holds the 7-bit slave address of the BMC on the host SMBus
@@ -218,7 +181,7 @@ static fwts_framework_minor_test spmi_tests[] = {
 
 static fwts_framework_ops spmi_ops = {
 	.description = "SPMI Service Processor Management Interface Description Table test.",
-	.init        = spmi_init,
+	.init        = SPMI_init,
 	.minor_tests = spmi_tests
 };
 
