@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,21 +27,7 @@
 #include <string.h>
 
 static fwts_acpi_table_info *table;
-
-static int srat_init(fwts_framework *fw)
-{
-
-	if (fwts_acpi_find_table(fw, "SRAT", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI SRAT table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(SRAT, &table)
 
 static void srat_check_local_apic_sapic_affinity(
 	fwts_framework *fw,
@@ -69,19 +55,19 @@ static void srat_check_local_apic_sapic_affinity(
 	}
 
 	fwts_log_info_verbatim(fw, "SRAT Local APIC/SAPIC Affinity Structure:");
-	fwts_log_info_verbatim(fw, "  Type:                     0x%2.2" PRIx8, affinity->type);
-	fwts_log_info_verbatim(fw, "  Length:                   0x%2.2" PRIx8, affinity->length);
-	fwts_log_info_verbatim(fw, "  Proximity Domain:   [7:0] 0x%2.2" PRIx8, affinity->proximity_domain_0);
-	fwts_log_info_verbatim(fw, "  APIC ID:                  0x%2.2" PRIx8, affinity->apic_id);
-	fwts_log_info_verbatim(fw, "  Flags:                    0x%8.8" PRIx32, affinity->flags);
-	fwts_log_info_verbatim(fw, "  Local SAPIC EID:          0x%2.2" PRIx8, affinity->local_sapic_eid);
-	fwts_log_info_verbatim(fw, "  Proximity Domain:  [8:15] 0x%2.2" PRIx8, affinity->proximity_domain_1);
-	fwts_log_info_verbatim(fw, "  Proximity Domain: [16:23] 0x%2.2" PRIx8, affinity->proximity_domain_2);
-	fwts_log_info_verbatim(fw, "  Proximity Domain: [23:31] 0x%2.2" PRIx8, affinity->proximity_domain_3);
-	fwts_log_info_verbatim(fw, "  Clock Domain              0x%8.8" PRIx32, affinity->clock_domain);
+	fwts_log_info_simp_int(fw, "  Type:                     ", affinity->type);
+	fwts_log_info_simp_int(fw, "  Length:                   ", affinity->length);
+	fwts_log_info_simp_int(fw, "  Proximity Domain:   [7:0] ", affinity->proximity_domain_0);
+	fwts_log_info_simp_int(fw, "  APIC ID:                  ", affinity->apic_id);
+	fwts_log_info_simp_int(fw, "  Flags:                    ", affinity->flags);
+	fwts_log_info_simp_int(fw, "  Local SAPIC EID:          ", affinity->local_sapic_eid);
+	fwts_log_info_simp_int(fw, "  Proximity Domain:  [8:15] ", affinity->proximity_domain_1);
+	fwts_log_info_simp_int(fw, "  Proximity Domain: [16:23] ", affinity->proximity_domain_2);
+	fwts_log_info_simp_int(fw, "  Proximity Domain: [23:31] ", affinity->proximity_domain_3);
+	fwts_log_info_simp_int(fw, "  Clock Domain              ", affinity->clock_domain);
 	fwts_log_nl(fw);
 
-	fwts_acpi_reserved_bits_check(fw, "SRAT", "Local APIC/SPAIC Affinity Flags", affinity->flags, sizeof(affinity->flags), 1, 31, passed);
+	fwts_acpi_reserved_bits_check("SRAT", "Local APIC/SPAIC Affinity Flags", affinity->flags, 1, 31, passed);
 
 	/*
 	 * Not clear of bits 0..7 of Proximity Domain are reserved or not
@@ -123,20 +109,20 @@ static void srat_check_memory_affinity(
 	}
 
 	fwts_log_info_verbatim(fw, "SRAT Memory Affinity Structure:");
-	fwts_log_info_verbatim(fw, "  Type:                     0x%2.2" PRIx8, affinity->type);
-	fwts_log_info_verbatim(fw, "  Length:                   0x%2.2" PRIx8, affinity->length);
-	fwts_log_info_verbatim(fw, "  Proximity Domain:         0x%8.8" PRIx32, affinity->proximity_domain);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%4.4" PRIx16, affinity->reserved1);
+	fwts_log_info_simp_int(fw, "  Type:                     ", affinity->type);
+	fwts_log_info_simp_int(fw, "  Length:                   ", affinity->length);
+	fwts_log_info_simp_int(fw, "  Proximity Domain:         ", affinity->proximity_domain);
+	fwts_log_info_simp_int(fw, "  Reserved:                 ", affinity->reserved1);
 	fwts_log_info_verbatim(fw, "  Base Address:             0x%8.8" PRIx32 "%8.8" PRIx32,
 		affinity->base_addr_hi, affinity->base_addr_lo);
 	fwts_log_info_verbatim(fw, "  Length:                   0x%8.8" PRIx32 "%8.8" PRIx32,
 		affinity->length_hi, affinity->length_lo);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%8.8" PRIx32, affinity->reserved2);
-	fwts_log_info_verbatim(fw, "  Flags:                    0x%8.8" PRIx32, affinity->flags);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%16.16" PRIx64, affinity->reserved3);
+	fwts_log_info_simp_int(fw, "  Reserved:                 ", affinity->reserved2);
+	fwts_log_info_simp_int(fw, "  Flags:                    ", affinity->flags);
+	fwts_log_info_simp_int(fw, "  Reserved:                 ", affinity->reserved3);
 	fwts_log_nl(fw);
 
-	fwts_acpi_reserved_bits_check(fw, "SRAT", "Memory Affinity Flags", affinity->flags, sizeof(affinity->flags), 3, 31, passed);
+	fwts_acpi_reserved_bits_check("SRAT", "Memory Affinity Flags", affinity->flags, 3, 31, passed);
 
 done:
 	*length -= sizeof(fwts_acpi_table_memory_affinity);
@@ -169,14 +155,14 @@ static void srat_check_local_x2apic_affinity(
 	}
 
 	fwts_log_info_verbatim(fw, "SRAT Local x2APIC Affinity Structure:");
-	fwts_log_info_verbatim(fw, "  Type:                     0x%2.2" PRIx8, affinity->type);
-	fwts_log_info_verbatim(fw, "  Length:                   0x%2.2" PRIx8, affinity->length);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%4.4" PRIx16, affinity->reserved1);
-	fwts_log_info_verbatim(fw, "  Proximity Domain:         0x%4.4" PRIx16, affinity->proximity_domain);
-	fwts_log_info_verbatim(fw, "  X2APIC ID:                0x%8.8" PRIx32, affinity->x2apic_id);
-	fwts_log_info_verbatim(fw, "  Flags:                    0x%8.8" PRIx32, affinity->flags);
-	fwts_log_info_verbatim(fw, "  Clock Domain              0x%8.8" PRIx32, affinity->clock_domain);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%4.4" PRIx16, affinity->reserved2);
+	fwts_log_info_simp_int(fw, "  Type:                     ", affinity->type);
+	fwts_log_info_simp_int(fw, "  Length:                   ", affinity->length);
+	fwts_log_info_simp_int(fw, "  Reserved:                 ", affinity->reserved1);
+	fwts_log_info_simp_int(fw, "  Proximity Domain:         ", affinity->proximity_domain);
+	fwts_log_info_simp_int(fw, "  X2APIC ID:                ", affinity->x2apic_id);
+	fwts_log_info_simp_int(fw, "  Flags:                    ", affinity->flags);
+	fwts_log_info_simp_int(fw, "  Clock Domain              ", affinity->clock_domain);
+	fwts_log_info_simp_int(fw, "  Reserved:                 ", affinity->reserved2);
 	fwts_log_nl(fw);
 
 	/* Spec states 1st reserved field MUST be zero */
@@ -189,7 +175,7 @@ static void srat_check_local_x2apic_affinity(
 		*passed = false;
 	}
 
-	fwts_acpi_reserved_bits_check(fw, "SRAT", "Local x2APIC Affinity Flags", affinity->flags, sizeof(affinity->flags), 1, 31, passed);
+	fwts_acpi_reserved_bits_check("SRAT", "Local x2APIC Affinity Flags", affinity->flags, 1, 31, passed);
 
 	/*
 	 *  Clock domain probably needs deeper sanity checking, for now
@@ -227,15 +213,15 @@ static void srat_check_gicc_affinity(
 	}
 
 	fwts_log_info_verbatim(fw, "SRAT GICC Affinity Structure:");
-	fwts_log_info_verbatim(fw, "  Type:                     0x%2.2" PRIx8, affinity->type);
-	fwts_log_info_verbatim(fw, "  Length:                   0x%2.2" PRIx8, affinity->length);
-	fwts_log_info_verbatim(fw, "  Proximity Domain:         0x%8.8" PRIx32, affinity->proximity_domain);
-	fwts_log_info_verbatim(fw, "  ACPI Processor UID:       0x%8.8" PRIx32, affinity->acpi_processor_uid);
-	fwts_log_info_verbatim(fw, "  Flags:                    0x%8.8" PRIx32, affinity->flags);
-	fwts_log_info_verbatim(fw, "  Clock Domain              0x%8.8" PRIx32, affinity->clock_domain);
+	fwts_log_info_simp_int(fw, "  Type:                     ", affinity->type);
+	fwts_log_info_simp_int(fw, "  Length:                   ", affinity->length);
+	fwts_log_info_simp_int(fw, "  Proximity Domain:         ", affinity->proximity_domain);
+	fwts_log_info_simp_int(fw, "  ACPI Processor UID:       ", affinity->acpi_processor_uid);
+	fwts_log_info_simp_int(fw, "  Flags:                    ", affinity->flags);
+	fwts_log_info_simp_int(fw, "  Clock Domain              ", affinity->clock_domain);
 	fwts_log_nl(fw);
 
-	fwts_acpi_reserved_bits_check(fw, "SRAT", "GICC Affinity Flags", affinity->flags, sizeof(affinity->flags), 1, 31, passed);
+	fwts_acpi_reserved_bits_check("SRAT", "GICC Affinity Flags", affinity->flags, 1, 31, passed);
 
 	/*
 	 *  Clock domain probably needs deeper sanity checking, for now
@@ -273,14 +259,14 @@ static void srat_check_its_affinity(
 	}
 
 	fwts_log_info_verbatim(fw, "SRAT ITS Affinity Structure:");
-	fwts_log_info_verbatim(fw, "  Type:                     0x%2.2" PRIx8, affinity->type);
-	fwts_log_info_verbatim(fw, "  Length:                   0x%2.2" PRIx8, affinity->length);
-	fwts_log_info_verbatim(fw, "  Proximity Domain:         0x%8.8" PRIx32, affinity->proximity_domain);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%4.4" PRIx16, affinity->reserved);
-	fwts_log_info_verbatim(fw, "  ITS ID                    0x%8.8" PRIx32, affinity->its_id);
+	fwts_log_info_simp_int(fw, "  Type:                     ", affinity->type);
+	fwts_log_info_simp_int(fw, "  Length:                   ", affinity->length);
+	fwts_log_info_simp_int(fw, "  Proximity Domain:         ", affinity->proximity_domain);
+	fwts_log_info_simp_int(fw, "  Reserved:                 ", affinity->reserved);
+	fwts_log_info_simp_int(fw, "  ITS ID                    ", affinity->its_id);
 	fwts_log_nl(fw);
 
-	fwts_acpi_reserved_zero_check(fw, "SRAT", "ITS Affinity Reserved", affinity->reserved, sizeof(affinity->reserved), passed);
+	fwts_acpi_reserved_zero_check("SRAT", "ITS Affinity Reserved", affinity->reserved, passed);
 
 done:
 	*length -= sizeof(fwts_acpi_table_its_affinity);
@@ -316,25 +302,25 @@ static void srat_check_initiator_affinity(
 	}
 
 	fwts_log_info_verbatim(fw, "SRAT Initiator Affinity Structure:");
-	fwts_log_info_verbatim(fw, "  Type:                     0x%2.2" PRIx8, affinity->type);
-	fwts_log_info_verbatim(fw, "  Length:                   0x%2.2" PRIx8, affinity->length);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%2.2" PRIx8, affinity->reserved1);
-	fwts_log_info_verbatim(fw, "  Device Handle Type:       0x%2.2" PRIx8, affinity->device_handle_type);
-	fwts_log_info_verbatim(fw, "  Proximity Domain:         0x%8.8" PRIx32, affinity->proximity_domain);
+	fwts_log_info_simp_int(fw, "  Type:                     ", affinity->type);
+	fwts_log_info_simp_int(fw, "  Length:                   ", affinity->length);
+	fwts_log_info_simp_int(fw, "  Reserved:                 ", affinity->reserved1);
+	fwts_log_info_simp_int(fw, "  Device Handle Type:       ", affinity->device_handle_type);
+	fwts_log_info_simp_int(fw, "  Proximity Domain:         ", affinity->proximity_domain);
 	fwts_log_info_verbatim(fw, "  Device Handle:");
 	if (affinity->device_handle_type == 0) {
-		fwts_log_info_verbatim(fw, "    ACPI _HID:                0x%16.16" PRIx64, (uint64_t)affinity->device_handle[0]);
-		fwts_log_info_verbatim(fw, "    ACPI _UID:                0x%8.8" PRIx32, (uint32_t)affinity->device_handle[8]);
+		fwts_log_info_simp_int(fw, "    ACPI _HID:                ", (uint64_t)affinity->device_handle[0]);
+		fwts_log_info_simp_int(fw, "    ACPI _UID:                ", (uint32_t)affinity->device_handle[8]);
 	} else if (affinity->device_handle_type == 1) {
-		fwts_log_info_verbatim(fw, "    PCI Segment:              0x%4.4" PRIx16, (uint16_t)affinity->device_handle[0]);
-		fwts_log_info_verbatim(fw, "    PCI BDF Number:           0x%4.4" PRIx16, (uint16_t)affinity->device_handle[2]);
+		fwts_log_info_simp_int(fw, "    PCI Segment:              ", (uint16_t)affinity->device_handle[0]);
+		fwts_log_info_simp_int(fw, "    PCI BDF Number:           ", (uint16_t)affinity->device_handle[2]);
 	}
-	fwts_log_info_verbatim(fw, "  Flags:                    0x%4.4" PRIx16, affinity->flags);
-	fwts_log_info_verbatim(fw, "  Reserved:                 0x%4.4" PRIx16, affinity->reserved2);
+	fwts_log_info_simp_int(fw, "  Flags:                    ", affinity->flags);
+	fwts_log_info_simp_int(fw, "  Reserved:                 ", affinity->reserved2);
 	fwts_log_nl(fw);
 
-	fwts_acpi_reserved_zero_check(fw, "SRAT", "Initiator Affinity Reserved", affinity->reserved1, sizeof(affinity->reserved1), passed);
-	fwts_acpi_reserved_bits_check(fw, "SRAT", "Initiator Affinity Device Handle Type", affinity->device_handle_type, sizeof(affinity->device_handle_type), 1, 7, passed);
+	fwts_acpi_reserved_zero_check("SRAT", "Initiator Affinity Reserved", affinity->reserved1, passed);
+	fwts_acpi_reserved_bits_check("SRAT", "Initiator Affinity Device Handle Type", affinity->device_handle_type, 1, 7, passed);
 	if (affinity->device_handle_type == 0)
 		h_reserved = affinity->device_handle[12];
 	else if (affinity->device_handle_type == 1) {
@@ -342,9 +328,9 @@ static void srat_check_initiator_affinity(
 		for (i = 4; i < 16; i++)
 			h_reserved += affinity->device_handle[i];
 	}
-	fwts_acpi_reserved_zero_check(fw, "SRAT", "Initiator Affinity Device Handle Reserve", h_reserved, sizeof(uint32_t), passed);
-	fwts_acpi_reserved_bits_check(fw, "SRAT", "Initiator Affinity Flags", affinity->flags, sizeof(affinity->flags), 1, 15, passed);
-	fwts_acpi_reserved_zero_check(fw, "SRAT", "Initiator Affinity Reserved", affinity->reserved2, sizeof(affinity->reserved2), passed);
+	fwts_acpi_reserved_zero_check("SRAT", "Initiator Affinity Device Handle Reserve", h_reserved, passed);
+	fwts_acpi_reserved_bits_check("SRAT", "Initiator Affinity Flags", affinity->flags, 2, 31, passed);
+	fwts_acpi_reserved_zero_check("SRAT", "Initiator Affinity Reserved", affinity->reserved2, passed);
 
 done:
 	*length -= sizeof(fwts_acpi_table_initiator_affinity);
@@ -361,13 +347,7 @@ static int srat_test1(fwts_framework *fw)
 	bool passed = true;
 	ssize_t length = (ssize_t)srat->header.length;
 
-	if (srat->reserved1 != 1) {
-		fwts_failed(fw, LOG_LEVEL_MEDIUM,
-			"SRATInterfaceReserved",
-			"SRAT reserved field 1 should be 1, instead was "
-			"0x%" PRIx32, srat->reserved1);
-		passed = false;
-	}
+	fwts_acpi_fixed_value_check(fw, LOG_LEVEL_MEDIUM, "SRAT", "Revision1", srat->reserved1, 1, &passed);
 
 	data += sizeof(fwts_acpi_table_srat);
 	length -= sizeof(fwts_acpi_table_srat);
@@ -417,7 +397,7 @@ static fwts_framework_minor_test srat_tests[] = {
 
 static fwts_framework_ops srat_ops = {
 	.description = "SRAT System Resource Affinity Table test.",
-	.init        = srat_init,
+	.init        = SRAT_init,
 	.minor_tests = srat_tests
 };
 
