@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,21 +29,7 @@
 #include "fwts_acpi_object_eval.h"
 
 static fwts_acpi_table_info *table;
-
-static int stao_init(fwts_framework *fw)
-{
-
-	if (fwts_acpi_find_table(fw, "STAO", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI STAO table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(STAO, &table)
 
 /*
  *  Extract a STAO ACPI String from the raw buffer
@@ -99,7 +85,7 @@ static int stao_test1(fwts_framework *fw)
 
 	/* Now we have got some sane data, dump the STAO */
         fwts_log_info_verbatim(fw, "STAO Status Override Table:");
-        fwts_log_info_verbatim(fw, "  UART:                     0x%2.2" PRIx8, stao->uart);
+        fwts_log_info_simp_int(fw, "  UART:                     ", stao->uart);
 
 	ptr = (const char *)stao->namelist;
 	end = (const char *)table->data + stao->header.length;
@@ -154,7 +140,7 @@ static fwts_framework_minor_test stao_tests[] = {
 
 static fwts_framework_ops stao_ops = {
 	.description = "STAO Status Override Table test.",
-	.init        = stao_init,
+	.init        = STAO_init,
 	.minor_tests = stao_tests
 };
 
