@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,20 +24,7 @@
 #include <stdbool.h>
 
 static fwts_acpi_table_info *table;
-
-static int tpm2_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "TPM2", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot load ACPI table");
-		return FWTS_ERROR;
-	}
-	if (table == NULL) {
-		fwts_log_error(fw, "ACPI TPM2 table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(TPM2, &table)
 
 /*
  * TPM2 table
@@ -49,10 +36,10 @@ static int tpm2_test1(fwts_framework *fw)
 	bool passed = true;
 
 	fwts_log_info_verbatim(fw, "TPM2 Table:");
-	fwts_log_info_verbatim(fw, "  Platform Class:                  0x%4.4"   PRIx16, tpm2->platform_class);
-	fwts_log_info_verbatim(fw, "  Reserved:                        0x%4.4"   PRIx32, tpm2->reserved);
-	fwts_log_info_verbatim(fw, "  Address of Control Area:         0x%16.16" PRIx64, tpm2->address_of_control_area);
-	fwts_log_info_verbatim(fw, "  Start Method:                    0x%8.8"   PRIx32, tpm2->start_method);
+	fwts_log_info_simp_int(fw, "  Platform Class:                  ", tpm2->platform_class);
+	fwts_log_info_simp_int(fw, "  Reserved:                        ", tpm2->reserved);
+	fwts_log_info_simp_int(fw, "  Address of Control Area:         ", tpm2->address_of_control_area);
+	fwts_log_info_simp_int(fw, "  Start Method:                    ", tpm2->start_method);
 
 	if (tpm2->platform_class != 0 && tpm2->platform_class != 1) {
 		passed = false;
@@ -62,7 +49,7 @@ static int tpm2_test1(fwts_framework *fw)
 			tpm2->platform_class);
 	}
 
-	fwts_acpi_reserved_zero_check(fw, "TPM2", "Reserved", tpm2->reserved, sizeof(tpm2->reserved), &passed);
+	fwts_acpi_reserved_zero_check("TPM2", "Reserved", tpm2->reserved, &passed);
 
 	if (tpm2->start_method < 1 || tpm2->start_method >= 12) {
 		passed = false;
@@ -106,7 +93,7 @@ static fwts_framework_minor_test tpm2_tests[] = {
 
 static fwts_framework_ops tpm2_ops = {
 	.description = "TPM2 Trusted Platform Module 2 test.",
-	.init        = tpm2_init,
+	.init        = TPM2_init,
 	.minor_tests = tpm2_tests
 };
 
