@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,19 +28,7 @@
 #include <ctype.h>
 
 static fwts_acpi_table_info *table;
-
-static int uefi_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "UEFI", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI UEFI table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-	return FWTS_OK;
-}
+acpi_table_init(UEFI, &table)
 
 /*
  *  UEFI ACPI DATA Table
@@ -70,7 +58,7 @@ static int uefi_test1(fwts_framework *fw)
 
 	fwts_log_info_verbatim(fw, "UEFI ACPI Data Table:");
 	fwts_log_info_verbatim(fw, "  Identifier: %s", guid);
-	fwts_log_info_verbatim(fw, "  DataOffset: 0x%4.4" PRIx16, uefi->dataoffset);
+	fwts_log_info_simp_int(fw, "  DataOffset: ", uefi->dataoffset);
 
 	/* Sanity check the dataoffset */
 	if (uefi->dataoffset > table->length) {
@@ -96,8 +84,8 @@ static int uefi_test1(fwts_framework *fw)
 				, uefi_smmcomm->boot.dataoffset);
 		}
 
-		fwts_log_info_verbatim(fw, "  SW SMI Number: 0x%8.8" PRIx32, uefi_smmcomm->sw_smi_number);
-		fwts_log_info_verbatim(fw, "  Buffer Ptr Address: 0x%16.16" PRIx64, uefi_smmcomm->buf_ptr_addr);
+		fwts_log_info_simp_int(fw, "  SW SMI Number: ", uefi_smmcomm->sw_smi_number);
+		fwts_log_info_simp_int(fw, "  Buffer Ptr Address: ", uefi_smmcomm->buf_ptr_addr);
 	} else {
 		/* dump the remaining data */
 		fwts_log_info_verbatim(fw, "  Data:");
@@ -123,7 +111,7 @@ static fwts_framework_minor_test uefi_tests[] = {
 
 static fwts_framework_ops uefi_ops = {
 	.description = "UEFI Data Table test.",
-	.init        = uefi_init,
+	.init        = UEFI_init,
 	.minor_tests = uefi_tests
 };
 
