@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,7 +18,7 @@
  */
 #include "fwts.h"
 
-#if defined(FWTS_HAS_ACPI)
+#if defined(FWTS_HAS_ACPI) && !(FWTS_ARCH_AARCH64)
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -30,20 +30,7 @@
 #include "fwts_acpi_object_eval.h"
 
 static fwts_acpi_table_info *table;
-
-static int waet_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "WAET", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI WAET table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(WAET, &table)
 
 /*
  *  WAET Windows ACPI Emulated Devices Table
@@ -61,12 +48,12 @@ static int waet_test1(fwts_framework *fw)
 	}
 
 	fwts_log_info_verbatim(fw, "WAET Table:");
-	fwts_log_info_verbatim(fw, "  Emulated Device Flags:    0x%8.8" PRIx32, waet->flags);
+	fwts_log_info_simp_int(fw, "  Emulated Device Flags:    ", waet->flags);
 	fwts_log_info_verbatim(fw, "    Bit [0] RTC Good:       %1" PRIu32, waet->flags & 1);
 	fwts_log_info_verbatim(fw, "    Bit [1] PM Timer Good:  %1" PRIu32, (waet->flags >> 1) & 1);
 	fwts_log_nl(fw);
 
-	fwts_acpi_reserved_bits_check(fw, "WAET", "Emulated Device Flags", waet->flags, sizeof(waet->flags), 2, 31, &passed);
+	fwts_acpi_reserved_bits_check("WAET", "Emulated Device Flags", waet->flags, 2, 31, &passed);
 
 done:
 	if (passed)
@@ -82,7 +69,7 @@ static fwts_framework_minor_test waet_tests[] = {
 
 static fwts_framework_ops waet_ops = {
 	.description = "WAET Windows ACPI Emulated Devices Table test.",
-	.init        = waet_init,
+	.init        = WAET_init,
 	.minor_tests = waet_tests
 };
 
