@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Canonical
+ * Copyright (C) 2015-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,7 +18,7 @@
  */
 #include "fwts.h"
 
-#if defined(FWTS_HAS_ACPI)
+#if defined(FWTS_HAS_ACPI) && !(FWTS_ARCH_AARCH64)
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -31,21 +31,7 @@
 #define ACPI_DUMP	(0)		/* WDAT entries are long, so don't dump, too verbose */
 
 static fwts_acpi_table_info *table;
-
-static int wdat_init(fwts_framework *fw)
-{
-
-	if (fwts_acpi_find_table(fw, "WDAT", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI WDAT table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(WDAT, &table)
 
 /*
  * ACPI WDAT (Watchdog Action Table)
@@ -116,7 +102,7 @@ static int wdat_test1(fwts_framework *fw)
 	 * this does sanity check that somebody has not set these
 	 * bits accidentally.  This is a LOW issue.
 	 */
-	fwts_acpi_reserved_bits_check(fw, "WDAT", "Watchdog Flags", wdat->watchdog_flags, sizeof(wdat->watchdog_flags), 1, 6, &passed);
+	fwts_acpi_reserved_bits_check("WDAT", "Watchdog Flags", wdat->watchdog_flags, 1, 6, &passed);
 
 	total_length = sizeof(fwts_acpi_table_wdat) +
 		(wdat->number_of_entries * sizeof(fwts_acpi_table_wdat_instr_entries));
@@ -213,7 +199,7 @@ static fwts_framework_minor_test wdat_tests[] = {
 
 static fwts_framework_ops wdat_ops = {
 	.description = "WDAT Microsoft Hardware Watchdog Action Table test.",
-	.init        = wdat_init,
+	.init        = WDAT_init,
 	.minor_tests = wdat_tests
 };
 
