@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -89,12 +89,23 @@ static fwts_wmi_known_guid fwts_wmi_known_guids[] = {
 	{ "97845ED0-4E6D-11DE-8A39-0800200C9A66", "eeepc-wmi",	"Asus" },
 	{ "95F24279-4D7B-4334-9387-ACCDC67EF61C", "hp-wmi",	"HP"   },
 	{ "5FB7F034-2C63-45e9-BE91-3D44E2C707E4", "hp-wmi",	"HP"   },
+	{ "ABBC0F5B-8EA1-11D1-A000-C90629100000", "huawei-wmi", "Huawei" },
+	{ "ABBC0F5C-8EA1-11D1-A000-C90629100000", "huawei-wmi", "Huawei" },
+	{ "39142400-C6A3-40fa-BADB-8A2652834100", "huawei-wmi", "Huawei" },
+	{ "59142400-C6A3-40fa-BADB-8A2652834100", "huawei-wmi", "Huawei" },
 	{ "26CAB2E5-5CF1-46AE-AAC3-4A12B6BA50E6", "ideapad-laptop", "Ideapad"   },
 	{ "56322276-8493-4CE8-A783-98C991274F5E", "ideapad-laptop", "Ideapad"   },
+	{ "44FADEB1-B204-40F2-8581-394BBDC1B651", "intel-wmi-sbl-fw-update", "Intel" },
+	{ "86CCFD48-205E-4A77-9C48-2021CBEDE341", "intel-wmi-thunderbolt", "Intel" },
+	{ "E4FB94F9-7F2B-4173-AD1A-CD1D95086248", "lg-laptop",	"LG"   },
+	{ "023B133E-49D1-4E10-B313-698220140DC2", "lg-laptop",	"LG"   },
+	{ "37BE1AC0-C3F2-4B1F-BFBE-8FDEAF2814D6", "lg-laptop",	"LG"   },
+	{ "911BAD44-7DF8-4FBB-9319-BABA1C4B293B", "lg-laptop",	"LG"   },
 	{ "551A1F84-FBDD-4125-91DB-3EA8F44F1D45", "msi-wmi",	"MSI"  },
 	{ "B6F3EEF2-3D2F-49DC-9DE3-85BCE18C62F2", "msi-wmi",	"MSI"  },
 	{ "5B3CC38A-40D9-7245-8AE6-1145B751BE3F", "msi-wmi",	"MSI"  },
 	{ "F6CB5C3C-9CAE-4EBD-B577-931EA32A2CC0", "mxm-wmi",	"MXM"  },
+	{ "ABBC0F6F-8EA1-11D1-00A0-C90629100000", "peaq-wmi",	"PEAQ"  },
 	{ "F7CC25EC-D20B-404C-8903-0ED4359C18AE", "surface3-wmi", "Surface3" },
 	{ "C364AC71-36DB-495A-8494-B439D472A505", "tc110-wmi",	"HP Compaq" },
 	{ "59142400-C6A3-40FA-BADB-8A2652834100", "toshiba_acpi", "Toshiba" },
