@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2020 Canonical
+ * Copyright (C) 2017-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,19 +28,7 @@
 #include <ctype.h>
 
 static fwts_acpi_table_info *table;
-
-static int wsmt_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "WSMT", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot read ACPI tables.");
-		return FWTS_ERROR;
-	}
-	if (table == NULL || (table && table->length == 0)) {
-		fwts_log_error(fw, "ACPI WSMT table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-	return FWTS_OK;
-}
+acpi_table_init(WSMT, &table)
 
 /*
  *  WSMT Windows Platform Binary Table
@@ -51,9 +39,9 @@ static int wsmt_test1(fwts_framework *fw)
 	bool passed = true;
 
 	fwts_log_info_verbatim(fw, "WSMT Windows SMM Security Mitigations Table:");
-	fwts_log_info_verbatim(fw, "  Protection Flags:      0x%8.8" PRIx32, wsmt->protection_flags);
+	fwts_log_info_simp_int(fw, "  Protection Flags:      ", wsmt->protection_flags);
 
-	fwts_acpi_reserved_bits_check(fw, "WSMT", "Protection Flags", wsmt->protection_flags, sizeof(wsmt->protection_flags), 3, 31, &passed);
+	fwts_acpi_reserved_bits_check("WSMT", "Protection Flags", wsmt->protection_flags, 3, 31, &passed);
 
 	if ((wsmt->protection_flags & 0x2) && !(wsmt->protection_flags & 0x1)) {
 		passed = false;
@@ -78,7 +66,7 @@ static fwts_framework_minor_test wsmt_tests[] = {
 
 static fwts_framework_ops wsmt_ops = {
 	.description = "WSMT Windows SMM Security Mitigations Table test.",
-	.init        = wsmt_init,
+	.init        = WSMT_init,
 	.minor_tests = wsmt_tests
 };
 
