@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,20 +24,7 @@
 #include <inttypes.h>
 
 static fwts_acpi_table_info *table;
-
-static int xenv_init(fwts_framework *fw)
-{
-	if (fwts_acpi_find_table(fw, "XENV", 0, &table) != FWTS_OK) {
-		fwts_log_error(fw, "Cannot load ACPI table");
-		return FWTS_ERROR;
-	}
-	if (table == NULL) {
-		fwts_log_error(fw, "ACPI XENV table does not exist, skipping test");
-		return FWTS_SKIP;
-	}
-
-	return FWTS_OK;
-}
+acpi_table_init(XENV, &table)
 
 /*
  * Sanity check XENV table, see:
@@ -56,22 +43,15 @@ static int xenv_test1(fwts_framework *fw)
 		return FWTS_ERROR;
 	}
 
-	if (xenv->header.revision != 1) {
-		passed = false;
-		fwts_failed(fw, LOG_LEVEL_HIGH,
-			"XENVBadRevision",
-			"XENV revision is incorrect, expecting 0x01, "
-			"instead got 0x%2.2" PRIx8,
-			xenv->header.revision);
-	}
+	fwts_acpi_revision_check("XENV", xenv->header.revision, 1, &passed);
 
 	fwts_log_info_verbatim(fw, "XENV Table:");
-	fwts_log_info_verbatim(fw, "  GNT Start Address:               0x%16.16" PRIx64, xenv->gnt_start);
-	fwts_log_info_verbatim(fw, "  GNT Size:                        0x%16.16" PRIx64, xenv->gnt_size);
-	fwts_log_info_verbatim(fw, "  Evtchn Intr:                     0x%8.8"   PRIx32, xenv->evtchn_intr);
-	fwts_log_info_verbatim(fw, "  Evtchn Intr Flags:               0x%2.2"   PRIx8,  xenv->evtchn_intr_flags);
+	fwts_log_info_simp_int(fw, "  GNT Start Address:               ", xenv->gnt_start);
+	fwts_log_info_simp_int(fw, "  GNT Size:                        ", xenv->gnt_size);
+	fwts_log_info_simp_int(fw, "  Evtchn Intr:                     ", xenv->evtchn_intr);
+	fwts_log_info_simp_int(fw, "  Evtchn Intr Flags:               ",  xenv->evtchn_intr_flags);
 
-	fwts_acpi_reserved_bits_check(fw, "XENV", "Evtchn Intr Flags", xenv->evtchn_intr_flags, sizeof(xenv->evtchn_intr_flags), 2, 7, &passed);
+	fwts_acpi_reserved_bits_check("XENV", "Evtchn Intr Flags", xenv->evtchn_intr_flags, 2, 7, &passed);
 
 	if (passed)
 		fwts_passed(fw, "No issues found in XENV table.");
@@ -86,7 +66,7 @@ static fwts_framework_minor_test xenv_tests[] = {
 
 static fwts_framework_ops xenv_check_ops = {
 	.description = "XENV Xen Environment Table tests.",
-	.init        = xenv_init,
+	.init        = XENV_init,
 	.minor_tests = xenv_tests
 };
 
