@@ -10,7 +10,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2018, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2021, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -594,16 +594,16 @@ typedef enum
  */
 typedef enum
 {
-    AML_FIELD_ATTRIB_QUICK          = 0x02,
-    AML_FIELD_ATTRIB_SEND_RCV       = 0x04,
-    AML_FIELD_ATTRIB_BYTE           = 0x06,
-    AML_FIELD_ATTRIB_WORD           = 0x08,
-    AML_FIELD_ATTRIB_BLOCK          = 0x0A,
-    AML_FIELD_ATTRIB_MULTIBYTE      = 0x0B,
-    AML_FIELD_ATTRIB_WORD_CALL      = 0x0C,
-    AML_FIELD_ATTRIB_BLOCK_CALL     = 0x0D,
-    AML_FIELD_ATTRIB_RAW_BYTES      = 0x0E,
-    AML_FIELD_ATTRIB_RAW_PROCESS    = 0x0F
+    AML_FIELD_ATTRIB_QUICK              = 0x02,
+    AML_FIELD_ATTRIB_SEND_RECEIVE       = 0x04,
+    AML_FIELD_ATTRIB_BYTE               = 0x06,
+    AML_FIELD_ATTRIB_WORD               = 0x08,
+    AML_FIELD_ATTRIB_BLOCK              = 0x0A,
+    AML_FIELD_ATTRIB_BYTES              = 0x0B,
+    AML_FIELD_ATTRIB_PROCESS_CALL       = 0x0C,
+    AML_FIELD_ATTRIB_BLOCK_PROCESS_CALL = 0x0D,
+    AML_FIELD_ATTRIB_RAW_BYTES          = 0x0E,
+    AML_FIELD_ATTRIB_RAW_PROCESS_BYTES  = 0x0F
 
 } AML_ACCESS_ATTRIBUTE;
 
