@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2006, Intel Corporation
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * This code was originally part of the Linux-ready Firmware Developer Kit
  *
@@ -51,8 +51,14 @@ static fwts_cpuinfo_x86 *fwts_cpuinfo;
 
 #define MTRR_DEF_TYPE_MSR	0x2FF
 #define AMD_SYS_CFG_MSR		0xC0010010
+#define AMD_TOM2_MSR		0xC001001D
+
+#define MTRR_ENABLE		0x800
+#define FIXED_MTRR_ENABLE	0x400
+
 
 static	uint64_t mtrr_default;
+static	uint64_t amd_tom2_addr;
 static	bool amd_Tom2ForceMemTypeWB = false;
 
 struct mtrr_entry {
@@ -195,6 +201,9 @@ static int get_default_mtrr(fwts_framework *fw)
 		if (fwts_cpu_readmsr(fw, 0, AMD_SYS_CFG_MSR, &amd_sys_conf) == FWTS_OK)
 			if (amd_sys_conf & 0x200000)
 				amd_Tom2ForceMemTypeWB = true;
+
+		if (fwts_cpu_readmsr(fw, 0, AMD_TOM2_MSR, &amd_tom2_addr) != FWTS_OK)
+			amd_tom2_addr = 0x100000000;	/* this should above 4GB */
 	}
 
 	if (fwts_cpu_readmsr(fw, 0, MTRR_DEF_TYPE_MSR, &mtrr_default) == FWTS_OK) {
@@ -229,12 +238,6 @@ static int cache_types(uint64_t start, uint64_t end)
 	struct mtrr_entry *entry;
 	int type = 0;
 
-	/* On AMD platforms, Tom2ForceMemTypeWB overwrites other memory types */
-	if (amd_Tom2ForceMemTypeWB && start >= 0x100000000) {
-		type = WRITE_BACK;
-		return type;
-	}
-
 	fwts_list_foreach(item, mtrr_list) {
 		entry = fwts_list_data(struct mtrr_entry*, item);
 
@@ -242,6 +245,10 @@ static int cache_types(uint64_t start, uint64_t end)
 			type |= entry->type;
 	}
 
+	/* On AMD platforms, Tom2ForceMemTypeWB overwrites MTRRdefType */
+	if (type == 0 && amd_Tom2ForceMemTypeWB && start >= 0x100000000 && start <= amd_tom2_addr)
+			return WRITE_BACK;
+
 	/*
 	 * now to see if there is any part of the range that isn't
 	 * covered by an mtrr, since it's UNCACHED if so
@@ -590,6 +597,36 @@ static int mtrr_deinit(fwts_framework *fw)
 	return FWTS_OK;
 }
 
+static int mtrr_test0(fwts_framework *fw)
+{
+	uint64_t mtrr_def_msr;
+
+	if (fwts_cpu_readmsr(fw, 0, MTRR_DEF_TYPE_MSR, &mtrr_def_msr) != FWTS_OK) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"MTRRMSRDefaultNotAvailable",
+			"MTRR_DEF_TYPE_MSR cannot be read from CPU.");
+		return FWTS_ERROR;
+	}
+
+	if (mtrr_def_msr & MTRR_ENABLE)
+		fwts_passed(fw, "MTRRs enabled flag is set in MTRR_DEF_TYPE MSR correctly.");
+	else
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"MTRRDisabled",
+			"MTRRs enabled flag is clear in MTRR_DEF_TYPE MSR and "
+			"all MTRRs are disabled ");
+
+	if (mtrr_def_msr & FIXED_MTRR_ENABLE)
+		fwts_passed(fw, "fixed MTRRs enabled flag is set in MTRR_DEF_TYPE MSR correctly.");
+	else
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"MTRRFixedRangeDisabled",
+			"Fixed MTRRs enabled flag is clear in MTRR_DEF_TYPE MSR and "
+			"all Fixed-range MTRRs are disabled ");
+
+	return FWTS_OK;
+}
+
 static int mtrr_test1(fwts_framework *fw)
 {
 	return validate_iomem(fw);
@@ -654,6 +691,7 @@ static int mtrr_test3(fwts_framework *fw)
 }
 
 static fwts_framework_minor_test mtrr_tests[] = {
+	{ mtrr_test0, "Validate MTRR default enabled." },
 	{ mtrr_test1, "Validate the kernel MTRR IOMEM setup." },
 	{ mtrr_test2, "Validate the MTRR setup across all processors." },
 	{ mtrr_test3, "Test for AMD MtrrFixDramModEn being cleared by the BIOS." },
