@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -18,14 +18,13 @@
  */
 #include "fwts.h"
 
-#ifdef FWTS_ARCH_INTEL
-
 #include <stdlib.h>
 #include <stdbool.h>
 #include <sys/types.h>
 #include <dirent.h>
 #include <ctype.h>
 #include <math.h>
+#include <bsd/string.h>
 
 #define CPU_FREQ_PATH	"/sys/devices/system/cpu"
 #define CPU_INFO_PATH	"/proc/cpuinfo"
@@ -79,9 +78,11 @@ static int maxfreq_test1(fwts_framework *fw)
 			cpus++;
 	}
 	if (!cpus) {
-		fwts_log_error(fw, "Cannot find any CPUs.");
 		fwts_list_free(cpuinfo, free);
-		return FWTS_ERROR;
+		fwts_skipped(fw,
+			"Cannot read CPU model names from %s, this generally "
+			"happens on ARM CPUs, skipping test.", CPU_INFO_PATH);
+		return FWTS_SKIP;
 	}
 
 	if ((cpufreq = calloc(cpus, sizeof(double))) == NULL) {
@@ -139,9 +140,9 @@ static int maxfreq_test1(fwts_framework *fw)
 		    strlen(entry->d_name) < 3)
 			continue;
 
-		snprintf(path, sizeof(path),
-			CPU_FREQ_PATH "/%s/cpufreq/scaling_available_frequencies",
-			entry->d_name);
+		strlcpy(path, CPU_FREQ_PATH, strlen(CPU_FREQ_PATH) + 1);
+		snprintf(path + strlen(CPU_FREQ_PATH), sizeof(path) - strlen(CPU_FREQ_PATH),
+			"/%s/cpufreq/scaling_available_frequencies", entry->d_name);
 
 		if ((data = fwts_get(path)) == NULL)
 			continue;
@@ -214,5 +215,3 @@ static fwts_framework_ops maxfreq_ops = {
 };
 
 FWTS_REGISTER("maxfreq", &maxfreq_ops, FWTS_TEST_ANYTIME, FWTS_FLAG_BATCH)
-
-#endif
