@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,7 +35,7 @@
 #include <limits.h>
 #include <fcntl.h>
 
-#define DMI_VERSION			(0x0330)
+#define DMI_VERSION			(0x0340)
 #define VERSION_MAJOR(v)		((v) >> 8)
 #define VERSION_MINOR(v)		((v) & 0xff)
 
@@ -67,6 +67,9 @@
 #define CHASSIS_MOBILE			0x04
 #define CHASSIS_SERVER			0x08
 
+#define dmi_ranges_uint8_check(fw, table, addr, field, hdr, offset, ranges) \
+	 _dmi_ranges_uint8_check(fw, table, addr, field, hdr, offset, ranges, sizeof(ranges))
+
 typedef struct {
 	const char *label;
 	const char *field;
@@ -450,12 +453,12 @@ static void dmi_dump_entry(fwts_framework *fw, fwts_smbios_entry *entry, fwts_sm
 	if (type == FWTS_SMBIOS) {
 		fwts_log_info_verbatim(fw, "SMBIOS Entry Point Structure:");
 		fwts_log_info_verbatim(fw, "  Anchor String          : %4.4s", entry->signature);
-		fwts_log_info_verbatim(fw, "  Checksum               : 0x%2.2x", entry->checksum);
-		fwts_log_info_verbatim(fw, "  Entry Point Length     : 0x%2.2x", entry->length);
-		fwts_log_info_verbatim(fw, "  Major Version          : 0x%2.2x", entry->major_version);
-		fwts_log_info_verbatim(fw, "  Minor Version          : 0x%2.2x", entry->minor_version);
-		fwts_log_info_verbatim(fw, "  Maximum Struct Size    : 0x%2.2x", entry->max_struct_size);
-		fwts_log_info_verbatim(fw, "  Entry Point Revision   : 0x%2.2x", entry->revision);
+		fwts_log_info_simp_int(fw, "  Checksum               : ", entry->checksum);
+		fwts_log_info_simp_int(fw, "  Entry Point Length     : ", entry->length);
+		fwts_log_info_simp_int(fw, "  Major Version          : ", entry->major_version);
+		fwts_log_info_simp_int(fw, "  Minor Version          : ", entry->minor_version);
+		fwts_log_info_simp_int(fw, "  Maximum Struct Size    : ", entry->max_struct_size);
+		fwts_log_info_simp_int(fw, "  Entry Point Revision   : ", entry->revision);
 		fwts_log_info_verbatim(fw, "  Formatted Area         : 0x%2.2x 0x%2.2x 0x%2.2x 0x%2.2x 0x%2.2x",
 			entry->formatted_area[0], entry->formatted_area[1],
 			entry->formatted_area[2], entry->formatted_area[3],
@@ -466,10 +469,10 @@ static void dmi_dump_entry(fwts_framework *fw, fwts_smbios_entry *entry, fwts_sm
 
 	/* Common to SMBIOS and SMBIOS_DMI_LEGACY */
 	fwts_log_info_verbatim(fw, "  Intermediate Anchor    : %5.5s", (char *)entry->anchor_string);
-	fwts_log_info_verbatim(fw, "  Intermediate Checksum  : 0x%2.2x", entry->intermediate_checksum);
-	fwts_log_info_verbatim(fw, "  Structure Table Length : 0x%4.4x", entry->struct_table_length);
-	fwts_log_info_verbatim(fw, "  Structure Table Address: 0x%8.8x", entry->struct_table_address);
-	fwts_log_info_verbatim(fw, "  # of SMBIOS Structures : 0x%4.4x", entry->number_smbios_structures);
+	fwts_log_info_simp_int(fw, "  Intermediate Checksum  : ", entry->intermediate_checksum);
+	fwts_log_info_simp_int(fw, "  Structure Table Length : ", entry->struct_table_length);
+	fwts_log_info_simp_int(fw, "  Structure Table Address: ", entry->struct_table_address);
+	fwts_log_info_simp_int(fw, "  # of SMBIOS Structures : ", entry->number_smbios_structures);
 	fwts_log_info_verbatim(fw, "  SMBIOS BCD Revision    : %2.2x", entry->smbios_bcd_revision);
 	if (entry->smbios_bcd_revision == 0)
 		fwts_log_info_verbatim(fw, "    BCD Revision 00 indicates compliance with specification stated in Major/Minor Version.");
@@ -480,15 +483,15 @@ static void dmi_dump_entry30(fwts_framework *fw, fwts_smbios30_entry *entry)
 
 	fwts_log_info_verbatim(fw, "SMBIOS30 Entry Point Structure:");
 	fwts_log_info_verbatim(fw, "  Anchor String          : %5.5s", entry->signature);
-	fwts_log_info_verbatim(fw, "  Checksum               : 0x%2.2" PRIx8, entry->checksum);
-	fwts_log_info_verbatim(fw, "  Entry Point Length     : 0x%2.2" PRIx8, entry->length);
-	fwts_log_info_verbatim(fw, "  Major Version          : 0x%2.2" PRIx8, entry->major_version);
-	fwts_log_info_verbatim(fw, "  Minor Version          : 0x%2.2" PRIx8, entry->minor_version);
-	fwts_log_info_verbatim(fw, "  Docrev                 : 0x%2.2" PRIx8, entry->docrev);
-	fwts_log_info_verbatim(fw, "  Entry Point Revision   : 0x%2.2" PRIx8, entry->revision);
-	fwts_log_info_verbatim(fw, "  Reserved               : 0x%2.2" PRIx8, entry->reserved);
-	fwts_log_info_verbatim(fw, "  Table maximum size     : 0x%8.8" PRIx32, entry->struct_table_max_size);
-	fwts_log_info_verbatim(fw, "  Table address          : 0x%16.16" PRIx64, entry->struct_table_address);
+	fwts_log_info_simp_int(fw, "  Checksum               : ", entry->checksum);
+	fwts_log_info_simp_int(fw, "  Entry Point Length     : ", entry->length);
+	fwts_log_info_simp_int(fw, "  Major Version          : ", entry->major_version);
+	fwts_log_info_simp_int(fw, "  Minor Version          : ", entry->minor_version);
+	fwts_log_info_simp_int(fw, "  Docrev                 : ", entry->docrev);
+	fwts_log_info_simp_int(fw, "  Entry Point Revision   : ", entry->revision);
+	fwts_log_info_simp_int(fw, "  Reserved               : ", entry->reserved);
+	fwts_log_info_simp_int(fw, "  Table maximum size     : ", entry->struct_table_max_size);
+	fwts_log_info_simp_int(fw, "  Table address          : ", entry->struct_table_address);
 
 }
 
@@ -915,7 +918,7 @@ static void dmi_reserved_uint8_check(fwts_framework *fw,
 	}
 }
 
-static void dmi_ranges_uint8_check(fwts_framework *fw,
+static void _dmi_ranges_uint8_check(fwts_framework *fw,
 	const char *table,
 	uint32_t addr,
 	const char *field,
@@ -1357,7 +1360,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			dmi_min_max_uint8_check(fw, table, addr, "Processor Type", hdr, 0x5, 0x1, 0x6);
 			dmi_str_check(fw, table, addr, "Processor Manufacturer", hdr, 0x7);
 			dmi_str_check(fw, table, addr, "Processor Version", hdr, 0x10);
-			dmi_min_max_uint8_check(fw, table, addr, "Upgrade", hdr, 0x19, 0x1, 0x3c);
+			dmi_min_max_uint8_check(fw, table, addr, "Upgrade", hdr, 0x19, 0x1, 0x3e);
 			if (hdr->length < 0x23)
 				break;
 			dmi_str_check(fw, table, addr, "Serial Number", hdr, 0x20);
@@ -1365,7 +1368,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			dmi_str_check(fw, table, addr, "Part Number", hdr, 0x22);
 			if (hdr->length < 0x28)
 				break;
-			dmi_reserved_bits_check(fw, table, addr, "Processor Characteristics", hdr, sizeof(uint16_t), 0x26, 9, 15);
+			dmi_reserved_bits_check(fw, table, addr, "Processor Characteristics", hdr, sizeof(uint16_t), 0x26, 10, 15);
 			if (hdr->length < 0x30)
 				break;
 			dmi_min_max_uint16_check(fw, table, addr, "Core Count 2", hdr, 0x2a, 0, 0xfffe);
@@ -1419,11 +1422,11 @@ static void dmicheck_entry(fwts_framework *fw,
 				break;
 			dmi_str_check(fw, table, addr, "Internal Reference Designator", hdr, 0x4);
 			fwts_dmi_value_range t8_ranges1[] = {{0, 0x23}, {0xa0, 0xa4}, {0xff, 0xff}};
-			dmi_ranges_uint8_check(fw, table, addr, "Internal Connector Type", hdr, 0x5, t8_ranges1, sizeof(t8_ranges1));
+			dmi_ranges_uint8_check(fw, table, addr, "Internal Connector Type", hdr, 0x5, t8_ranges1);
 			dmi_str_check(fw, table, addr, "External Reference Designator", hdr, 0x6);
-			dmi_ranges_uint8_check(fw, table, addr, "External Connector Type", hdr, 0x7, t8_ranges1, sizeof(t8_ranges1));
+			dmi_ranges_uint8_check(fw, table, addr, "External Connector Type", hdr, 0x7, t8_ranges1);
 			fwts_dmi_value_range t8_ranges2[] = {{0, 0x23}, {0xa0, 0xa1}, {0xff, 0xff}};
-			dmi_ranges_uint8_check(fw, table, addr, "Port Type", hdr, 0x8, t8_ranges2, sizeof(t8_ranges2));
+			dmi_ranges_uint8_check(fw, table, addr, "Port Type", hdr, 0x8, t8_ranges2);
 			break;
 
 		case 9: /* 7.10 */
@@ -1431,21 +1434,21 @@ static void dmicheck_entry(fwts_framework *fw,
 			if (hdr->length < 0x0c)
 				break;
 			dmi_str_check(fw, table, addr, "Slot Designation", hdr, 0x4);
-			fwts_dmi_value_range t9_ranges[] = {{1, 0x23}, {0x30, 0x30}, {0xa0, 0xbd}};
-			dmi_ranges_uint8_check(fw, table, addr, "Slot Type", hdr, 0x5, t9_ranges, sizeof(t9_ranges));
+			fwts_dmi_value_range t9_ranges[] = {{1, 0x28}, {0x30, 0x30}, {0xa0, 0xc6}};
+			dmi_ranges_uint8_check(fw, table, addr, "Slot Type", hdr, 0x5, t9_ranges);
 			dmi_min_max_uint8_check(fw, table, addr, "Slot Data Bus Width", hdr, 0x6, 0x1, 0xe);
 			dmi_min_max_uint8_check(fw, table, addr, "Current Usage", hdr, 0x7, 0x1, 0x5);
 			dmi_min_max_uint8_check(fw, table, addr, "Slot Length", hdr, 0x8, 0x1, 0x6);
 			if (hdr->length < 0x0d)
 				break;
 
-			dmi_reserved_bits_check(fw, table, addr, "Slot Characteristics 2", hdr, sizeof(uint8_t), 0x0c, 4, 7);
+			dmi_reserved_bits_check(fw, table, addr, "Slot Characteristics 2", hdr, sizeof(uint8_t), 0x0c, 7, 7);
 
 			if (hdr->length < 0x11)
 				break;
 			if (!((data[0x5] == 0x06) ||
-			      ((data[0x5] >= 0x0e) && (data[0x5] <= 0x23)) ||
-			      ((data[0x5] >= 0xa0) && (data[0x5] <= 0xb6)))) {
+			      ((data[0x5] >= 0x0e) && (data[0x5] <= 0x28)) ||
+			      ((data[0x5] >= 0xa0) && (data[0x5] <= 0xc6)))) {
 				if (GET_UINT16(data + 0xd) != 0xffff)
 					fwts_failed(fw, LOG_LEVEL_MEDIUM, DMI_VALUE_OUT_OF_RANGE,
 						"Invalid value 0x%4.4" PRIx16 " was used and 0xffff "
@@ -1529,12 +1532,12 @@ static void dmicheck_entry(fwts_framework *fw,
 			if (hdr->length < 0x14)
 				break;
 			fwts_dmi_value_range t15_ranges1[] = {{0, 0x4}, {0x80, 0xff}};
-			dmi_ranges_uint8_check(fw, table, addr, "Access Method", hdr, 0xa, t15_ranges1, sizeof(t15_ranges1));
+			dmi_ranges_uint8_check(fw, table, addr, "Access Method", hdr, 0xa, t15_ranges1);
 			dmi_reserved_bits_check(fw, table, addr, "Log Status", hdr, sizeof(uint8_t), 0xb, 2, 7);
 			if (hdr->length < 0x17)
 				break;
 			fwts_dmi_value_range t15_ranges2[] = {{0, 0x1}, {0x80, 0xff}};
-			dmi_ranges_uint8_check(fw, table, addr, "Log Header Format", hdr, 0x14, t15_ranges2, sizeof(t15_ranges2));
+			dmi_ranges_uint8_check(fw, table, addr, "Log Header Format", hdr, 0x14, t15_ranges2);
 			if (hdr->length < 0x17 + data[0x15] * data[0x16])
 				break;
 			if (data[0x16] >= 0x02) {
@@ -1571,7 +1574,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			if (hdr->length < 0x0f)
 				break;
 			fwts_dmi_value_range t16_ranges[] = {{0x1, 0xa}, {0xa0, 0xa4}};
-			dmi_ranges_uint8_check(fw, table, addr, "Location", hdr, 0x4, t16_ranges, sizeof(t16_ranges));
+			dmi_ranges_uint8_check(fw, table, addr, "Location", hdr, 0x4, t16_ranges);
 			dmi_min_max_uint8_check(fw, table, addr, "Use", hdr, 0x5, 0x1, 0x7);
 			dmi_min_max_uint8_check(fw, table, addr, "Error Corrrection Type", hdr, 0x6, 0x1, 0x7);
 			dmi_min_max_uint32_check(fw, table, addr, "Maximum Capacity", hdr, 0x7, 0, 0x80000000);
@@ -1594,7 +1597,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			dmi_min_max_uint8_check(fw, table, addr, "Form Factor", hdr, 0xe, 0x1, 0x10);
 			dmi_str_check(fw, table, addr, "Locator", hdr, 0x10);
 			dmi_str_check(fw, table, addr, "Bank Locator", hdr, 0x11);
-			dmi_min_max_uint8_check(fw, table, addr, "Memory Type", hdr, 0x12, 0x1, 0x21);
+			dmi_min_max_uint8_check(fw, table, addr, "Memory Type", hdr, 0x12, 0x1, 0x23);
 			if (hdr->length < 0x1b)
 				break;
 			dmi_str_check(fw, table, addr, "Manufacturer", hdr, 0x17);
@@ -1684,7 +1687,7 @@ static void dmicheck_entry(fwts_framework *fw,
 				break;
 			dmi_min_max_uint8_check(fw, table, addr, "Type", hdr, 0x4, 0x1, 0x9);
 			fwts_dmi_value_range t21_ranges[] = {{0x1, 0x8}, {0xa0, 0xa2}};
-			dmi_ranges_uint8_check(fw, table, addr, "Interface", hdr, 0x5, t21_ranges, sizeof(t21_ranges));
+			dmi_ranges_uint8_check(fw, table, addr, "Interface", hdr, 0x5, t21_ranges);
 			break;
 
 		case 22: /* 7.23 */
@@ -1829,7 +1832,7 @@ static void dmicheck_entry(fwts_framework *fw,
 			for (i = 4; i <= 9; i++)
 				dmi_reserved_uint8_check(fw, table, addr, "Reserved", hdr, i);
 			fwts_dmi_value_range t32_ranges[] = {{0, 0x8}, {0x80, 0xff}};
-			dmi_ranges_uint8_check(fw, table, addr, "Boot Status", hdr, 0xa, t32_ranges, sizeof(t32_ranges));
+			dmi_ranges_uint8_check(fw, table, addr, "Boot Status", hdr, 0xa, t32_ranges);
 			break;
 
 		case 33: /* 7.34 */
@@ -2230,6 +2233,9 @@ static int dmicheck_test3(fwts_framework *fw)
 		return FWTS_ERROR;
 	}
 
+	if (dmi_version_check(fw, version) != FWTS_OK)
+		return FWTS_SKIP;
+
 	table = dmi_table_smbios30(fw, &entry30);
 	if (table == NULL)
 		return FWTS_ERROR;
