@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -89,7 +89,9 @@
 #define FWTS_GAS_ADDR_SPACE_ID_PCC		(0x0a)
 #define FWTS_GAS_ADDR_SPACE_ID_FFH		(0x7f)
 
-#define FWTS_ACPI_VERSION_NEXT	(0x700)
+#define FWTS_ACPI_VERSION_NOW	(FWTS_ACPI_VERSION_64)
+#define FWTS_ACPI_VERSION_NEXT	(0x650)
+#define FWTS_ACPI_VERSION_64 	(0x640)
 #define FWTS_ACPI_VERSION_63 	(0x630)
 #define FWTS_ACPI_VERSION_62 	(0x620)
 #define FWTS_ACPI_VERSION_61	(0x610)
@@ -105,10 +107,8 @@
 #include "fwts_framework.h"
 #include "fwts_log.h"
 
-extern const char *fwts_acpi_fadt_preferred_pm_profile[];
+const char *fwts_acpi_fadt_preferred_pm_profile(const int profile);
 
-#define FWTS_ACPI_FADT_PREFERRED_PM_PROFILE(x)		\
-	((x) > 8) ? "Reserved" : fwts_acpi_fadt_preferred_pm_profile[x]
 #define FWTS_ACPI_FADT_FLAGS_HW_REDUCED_ACPI (1<<20)
 
 /*
@@ -117,9 +117,9 @@ extern const char *fwts_acpi_fadt_preferred_pm_profile[];
 typedef struct {
 	uint8_t 	address_space_id;
 	uint8_t		register_bit_width;
-        uint8_t 	register_bit_offset;
-        uint8_t 	access_width;
-        uint64_t 	address;
+	uint8_t 	register_bit_offset;
+	uint8_t 	access_width;
+	uint64_t 	address;
 } __attribute__ ((packed)) fwts_acpi_gas;
 
 /*
@@ -508,22 +508,23 @@ typedef struct {
 } __attribute__ ((packed)) fwts_acpi_table_madt;
 
 typedef enum {
-        FWTS_ACPI_MADT_LOCAL_APIC = 0,
-        FWTS_ACPI_MADT_IO_APIC,
-        FWTS_ACPI_MADT_INTERRUPT_OVERRIDE,
-        FWTS_ACPI_MADT_NMI_SOURCE,
-        FWTS_ACPI_MADT_LOCAL_APIC_NMI,
-        FWTS_ACPI_MADT_LOCAL_APIC_OVERRIDE,
-        FWTS_ACPI_MADT_IO_SAPIC,
-        FWTS_ACPI_MADT_LOCAL_SAPIC,
-        FWTS_ACPI_MADT_INTERRUPT_SOURCE,
-        FWTS_ACPI_MADT_LOCAL_X2APIC,
-        FWTS_ACPI_MADT_LOCAL_X2APIC_NMI,
+	FWTS_ACPI_MADT_LOCAL_APIC = 0,
+	FWTS_ACPI_MADT_IO_APIC,
+	FWTS_ACPI_MADT_INTERRUPT_OVERRIDE,
+	FWTS_ACPI_MADT_NMI_SOURCE,
+	FWTS_ACPI_MADT_LOCAL_APIC_NMI,
+	FWTS_ACPI_MADT_LOCAL_APIC_OVERRIDE,
+	FWTS_ACPI_MADT_IO_SAPIC,
+	FWTS_ACPI_MADT_LOCAL_SAPIC,
+	FWTS_ACPI_MADT_INTERRUPT_SOURCE,
+	FWTS_ACPI_MADT_LOCAL_X2APIC,
+	FWTS_ACPI_MADT_LOCAL_X2APIC_NMI,
 	FWTS_ACPI_MADT_GIC_C_CPU_INTERFACE,
 	FWTS_ACPI_MADT_GIC_D_GOC_DISTRIBUTOR,
 	FWTS_ACPI_MADT_GIC_V2M_MSI_FRAME,
 	FWTS_ACPI_MADT_GIC_R_REDISTRIBUTOR,
 	FWTS_ACPI_MADT_GIC_ITS,
+	FWTS_ACPI_MADT_MP_WAKEUP,
 	FWTS_ACPI_MADT_RESERVED, /* does not have defined structure */
 	FWTS_ACPI_MADT_OEM /* does not have defined structure */
 } fwts_acpi_madt_type;
@@ -676,6 +677,14 @@ typedef struct {
 	uint32_t	reserved2;
 } __attribute__ ((packed)) fwts_acpi_madt_gic_its;
 
+/* New in ACPI 6.4, Multiprocessor Wakeup structure, 5.2.12.19 */
+/* Type 16, FWTS_ACPI_MADT_MP_WAKEUP */
+typedef struct {
+	uint16_t	mail_box_version;
+	uint32_t	reserved;
+	uint64_t	mail_box_address;
+} __attribute__ ((packed)) fwts_acpi_madt_mp_wakeup;
+
 /*
  * ACPI TCPA (Trusted Computing Platform Alliance Capabilities Table)
  *   http://www.kuro5hin.org/story/2002/10/27/16622/530,
@@ -1226,6 +1235,7 @@ typedef struct {
 	uint64_t	address;
 	uint64_t	length;
 	uint64_t	memory_mapping;
+	uint64_t        spa_location_cookie;
 } __attribute__ ((packed)) fwts_acpi_table_nfit_system_memory;
 
 typedef struct {
@@ -1382,7 +1392,8 @@ typedef struct {
 	fwts_acpi_table_hmat_header	header;
 	uint8_t		flags;
 	uint8_t		data_type;
-	uint16_t	reserved1;
+	uint8_t         min_transfer_size;
+	uint8_t         reserved1;
 	uint32_t	num_initiator;
 	uint32_t	num_target;
 	uint32_t	reserved2;
@@ -1552,6 +1563,22 @@ typedef struct {
 	uint64_t	error_status_mask;
 } __attribute__ ((packed)) fwts_acpi_table_pcct_subspace_type_3_4;
 
+typedef struct {
+	fwts_acpi_table_pcct_subspace_header	header;
+	uint16_t	version;
+	uint64_t	base_address;
+	uint64_t	shared_memory_range_length;
+	fwts_acpi_gas	doorbell_register;
+	uint64_t	doorbell_preserve;
+	uint64_t	doorbell_write;
+	fwts_acpi_gas	cmd_complete_register;
+	uint64_t	cmd_complete_mask;
+	fwts_acpi_gas	error_status_register;
+	uint64_t	error_status_mask;
+	uint32_t	nominal_latency;
+	uint32_t	min_request_turnaround_time;
+} __attribute__ ((packed)) fwts_acpi_table_pcct_subspace_type_5;
+
 /*
  * ACPI SPCR (Serial Port Console Redirection Table)
  *  http://msdn.microsoft.com/en-us/library/windows/hardware/dn639132(v=vs.85).aspx
@@ -1587,7 +1614,7 @@ typedef struct {
 typedef struct {
 	fwts_acpi_table_header	header;
 	uint8_t		interface_type;
-	uint8_t		reserved1[3];
+	uint8_t		reserved[3];
 	fwts_acpi_gas	base_address;
 } __attribute__ ((packed)) fwts_acpi_table_dbgp;
 
@@ -1830,6 +1857,7 @@ typedef struct {
 } __attribute__ ((packed)) fwts_acpi_table_hest_generic_hardware_error_source_v2;
 
 void fwts_acpi_table_get_header(fwts_acpi_table_header *hdr, uint8_t *data);
+bool fwts_acpi_data_zero(const void *data, const size_t len);
 
 /*
  * ACPI CSTR (Core System Resources Table)
