@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2010-2020 Canonical
- * Some of this work - Copyright (C) 2016-2020 IBM
+ * Copyright (C) 2010-2021 Canonical
+ * Some of this work - Copyright (C) 2016-2021 IBM
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -27,6 +27,7 @@
 
 typedef struct fwts_framework fwts_framework;
 
+#include "fwts.h"
 #include "fwts_arch.h"
 #include "fwts_log.h"
 #include "fwts_list.h"
@@ -63,9 +64,7 @@ typedef enum {
 	FWTS_FLAG_TEST_COMPLIANCE_ACPI		= 0x00800000,
 	FWTS_FLAG_TEST_SBBR			= 0x01000000,
 	FWTS_FLAG_TEST_EBBR			= 0x02000000,
-	FWTS_FLAG_TEST_XBBR			= FWTS_FLAG_TEST_SBBR | FWTS_FLAG_TEST_EBBR,
-	FWTS_FLAG_DUMP_ACPI_FROM_SYSFS		= 0x08000000,
-
+	FWTS_FLAG_TEST_XBBR			= FWTS_FLAG_TEST_SBBR | FWTS_FLAG_TEST_EBBR
 } fwts_framework_flags;
 
 #define FWTS_FLAG_TEST_MASK		\
@@ -259,8 +258,6 @@ static inline int fwts_tests_passed(const fwts_framework *fw)
 	(flags & (FWTS_FLAG_INTERACTIVE | \
 		  FWTS_FLAG_INTERACTIVE_EXPERIMENTAL))
 
-#define FWTS_ARRAY_LEN(s) (sizeof(s)/sizeof(s[0]))
-
 /*
  * FWTS_ASSERT(test, message)
  *	compile time assertion that throws a division by zero
@@ -275,8 +272,7 @@ enum { FWTS_CONCAT_EXPAND(FWTS_ASSERT_ ## m ## _in_line_, __LINE__) = 1 / !!(e)
 
 #define FWTS_REGISTER_FEATURES(name, ops, priority, flags, features)	\
 /* Ensure name is not too long */					\
-FWTS_ASSERT(FWTS_ARRAY_LEN(name) < 16,					\
-	fwts_register_name_too_long);					\
+FWTS_ASSERT(FWTS_ARRAY_SIZE(name) < 16,	fwts_register_name_too_long);	\
 									\
 static void __test_init (void) __attribute__ ((constructor));		\
 									\
