@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,17 +30,25 @@
 
 #if defined(FWTS_HAS_ACPI)
 
-const char *fwts_acpi_fadt_preferred_pm_profile[] = {
-	"Unspecified",
-	"Desktop",
-	"Mobile",
-	"Workstation",
-	"Enterprise Server",
-	"SOHO Server",
-	"Appliance PC",
-	"Performance Server",
-	"Tablet",
-};
+const char *fwts_acpi_fadt_preferred_pm_profile(const int profile)
+{
+	static const char *pm_profiles[] = {
+		"Unspecified",
+		"Desktop",
+		"Mobile",
+		"Workstation",
+		"Enterprise Server",
+		"SOHO Server",
+		"Appliance PC",
+		"Performance Server",
+		"Tablet"
+	};
+
+	if ((profile < 0) || profile >= (int)(FWTS_ARRAY_SIZE(pm_profiles)))
+		return "Reserved";
+
+	return pm_profiles[profile];
+}
 
 /*
  *  fwts_acpi_table_get_header()
@@ -51,4 +59,15 @@ void fwts_acpi_table_get_header(fwts_acpi_table_header *hdr, uint8_t *data)
 	memcpy(hdr, data, sizeof(fwts_acpi_table_header));
 }
 
+bool fwts_acpi_data_zero(const void *data, const size_t len) {
+	uint8_t *ptr = (uint8_t *) data;
+	uint8_t i;
+
+	for (i = 0; i < len; i++)
+		if (*ptr++)
+			return false;
+
+	return true;
+}
+
 #endif
