@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -446,7 +446,8 @@ void fwts_acpi_object_evaluate_report_error(
 		break;
 	/* Unknown?! */
 	default:
-		fwts_failed(fw, LOG_LEVEL_MEDIUM, "AMLFailedToEvaluate", "Failed to evaluate '%s', got error code %d.", name, status);
+		fwts_failed(fw, LOG_LEVEL_MEDIUM, "AMLFailedToEvaluate",
+			"Failed to evaluate '%s', got error code %d.", name, status);
 		break;
 	}
 }
@@ -495,6 +496,86 @@ int fwts_method_check_type__(
 	return FWTS_OK;
 }
 
+/*
+ *  get_object_name()
+ *	get objname from full path nanme
+ *		ex. _BCL from _SB.PCI0.GFX0.LCD0._BCL
+ */
+static void get_object_name(const char *name, char* obj_name) {
+	/* obj_name must have length of 5 */
+	if (name != NULL && strlen(name) >= 4) {
+		memcpy(obj_name, name + strlen(name) - 4, 4);
+		obj_name[4] = '\0';
+	}
+}
+
+/* See references in actypes.h */
+static const char *acpi_object_names[] = {
+	"Any",
+	"Integer",
+	"String",
+	"Buffer",
+	"Package",
+	"Field Unit",
+	"Device",
+	"Event",
+	"Method",
+	"Mutex",
+	"Region",
+	"Power",
+	"Processor",
+	"Thermal",
+	"Buffer Field",
+	"DDB Handle",
+	"Debug Object",
+	"Region Field",
+	"Bank Field",
+	"Index Field",
+	"Reference",
+	"Alias",
+	"Method Alias",
+	"Notify",
+	"Address Handler",
+	"Resource",
+	"Resource Field",
+	"Scope"
+};
+
+/*
+ *  fwts_method_check_element_type()
+ *	check a element type of a sub-package
+ */
+int fwts_method_check_element_type(
+	fwts_framework *fw,
+	const char *name,
+	ACPI_OBJECT *obj,
+	uint32_t subpkg,
+	uint32_t element,
+	ACPI_OBJECT_TYPE type)
+{
+	if (obj->Package.Elements[element].Type != type) {
+		char obj_name[5] = "_XYZ";
+		char tmp[128];
+
+		get_object_name(name, obj_name);
+		snprintf(tmp, sizeof(tmp), "Method%sBadSubPackageReturnType", obj_name);
+
+		if (type > FWTS_ARRAY_SIZE(acpi_object_names) - 1) {
+			fwts_warning(fw, "Unknown ACPI object type detected");
+			return FWTS_ERROR;
+		}
+
+		fwts_failed(fw, LOG_LEVEL_HIGH, tmp,
+			"%s sub-package %" PRIu32 " element %" PRIu32 " is a %s, "
+			"expected a %s", name, subpkg, element,
+			acpi_object_names[obj->Package.Elements[element].Type],
+			acpi_object_names[type]);
+
+		return FWTS_ERROR;
+	}
+	return FWTS_OK;
+}
+
 /*
  *  Common types that can be returned. This is not a complete
  *  list but it does cover the types we expect to return from
@@ -602,13 +683,14 @@ int fwts_method_buffer_size(
 int fwts_method_package_count_min(
 	fwts_framework *fw,
 	const char *name,
-	const char *objname,
 	const ACPI_OBJECT *obj,
 	const uint32_t min)
 {
 	if (obj->Package.Count < min) {
+		char objname[5] = "_XYZ";
 		char tmp[128];
 
+		get_object_name(name, objname);
 		snprintf(tmp, sizeof(tmp), "Method%sElementCount", objname);
 		fwts_failed(fw, LOG_LEVEL_CRITICAL, tmp,
 			"%s should return package of at least %" PRIu32
@@ -627,13 +709,14 @@ int fwts_method_package_count_min(
 int fwts_method_package_count_equal(
 	fwts_framework *fw,
 	const char *name,
-	const char *objname,
 	const ACPI_OBJECT *obj,
 	const uint32_t count)
 {
 	if (obj->Package.Count != count) {
+		char objname[5] = "_XYZ";
 		char tmp[128];
 
+		get_object_name(name, objname);
 		snprintf(tmp, sizeof(tmp), "Method%sElementCount", objname);
 		fwts_failed(fw, LOG_LEVEL_CRITICAL, tmp,
 			"%s should return package of %" PRIu32
@@ -645,10 +728,36 @@ int fwts_method_package_count_equal(
 	return FWTS_OK;
 }
 
+/*
+ *  fwts_method_subpackage_count_equal()
+ *	check that an ACPI subpackage has exactly 'count' elements
+ */
+int fwts_method_subpackage_count_equal(
+	fwts_framework *fw,
+	const char *name,
+	const ACPI_OBJECT *obj,
+	const uint32_t sub,
+	const uint32_t count)
+{
+	if (obj->Package.Count != count) {
+		char objname[5] = "_XYZ";
+		char tmp[128];
+
+		get_object_name(name, objname);
+		snprintf(tmp, sizeof(tmp), "Method%sSubPackageElementCount", objname);
+		fwts_failed(fw, LOG_LEVEL_CRITICAL, tmp,
+			"%s sub-package %" PRIu32 " was expected to have "
+			"%" PRIu32 " element%s, got %" PRIu32 " element%s instead.",
+			name, sub, count, count == 1 ? "" : "s",
+			obj->Package.Count, obj->Package.Count == 1 ? "" : "s");
+		return FWTS_ERROR;
+	}
+	return FWTS_OK;
+}
+
 int fwts_method_package_elements_all_type(
 	fwts_framework *fw,
 	const char *name,
-	const char *objname,
 	const ACPI_OBJECT *obj,
 	const ACPI_OBJECT_TYPE type)
 {
@@ -658,6 +767,9 @@ int fwts_method_package_elements_all_type(
 
 	for (i = 0; i < obj->Package.Count; i++) {
 		if (!fwts_method_type_matches(obj->Package.Elements[i].Type, type)) {
+			char objname[5] = "_XYZ";
+
+			get_object_name(name, objname);
 			snprintf(tmp, sizeof(tmp), "Method%sElementType", objname);
 			fwts_failed(fw, LOG_LEVEL_CRITICAL, tmp,
 				"%s package element %" PRIu32 " was not the expected "
@@ -673,14 +785,13 @@ int fwts_method_package_elements_all_type(
 }
 
 /*
- *  fwts_method_package_elements_type()
+ *  fwts_method_package_elements_type__()
  *	sanity check fields in a package that all have
  *	the same type
  */
-int fwts_method_package_elements_type(
+int fwts_method_package_elements_type__(
 	fwts_framework *fw,
 	const char *name,
-	const char *objname,
 	const ACPI_OBJECT *obj,
 	const fwts_package_element *info,
 	const uint32_t count)
@@ -689,11 +800,14 @@ int fwts_method_package_elements_type(
 	bool failed = false;
 	char tmp[128];
 
-	if (obj->Package.Count != count)
+	if (fwts_method_package_count_equal(fw, name, obj, count) != FWTS_OK)
 		return FWTS_ERROR;
 
 	for (i = 0; i < obj->Package.Count; i++) {
 		if (!fwts_method_type_matches(obj->Package.Elements[i].Type, info[i].type)) {
+			char objname[5] = "_XYZ";
+
+			get_object_name(name, objname);
 			snprintf(tmp, sizeof(tmp), "Method%sElementType", objname);
 			fwts_failed(fw, LOG_LEVEL_CRITICAL, tmp,
 				"%s package element %" PRIu32 " (%s) was not the expected "
@@ -708,6 +822,31 @@ int fwts_method_package_elements_type(
 	return failed ? FWTS_ERROR: FWTS_OK;
 }
 
+int fwts_method_test_revision(
+	fwts_framework *fw,
+	const char *name,
+	const uint32_t cur_revision,
+	const uint32_t spec_revision)
+{
+	char method[5];
+	char tag[22];
+
+	if (strlen(name) < 4)
+		return FWTS_ERROR;
+
+	memcpy(method, name + strlen(name) - 4, 4);
+	method[4] = '\0';
+	snprintf(tag, 22, "Method%sBadRevision", method);
+
+	if (cur_revision != spec_revision) {
+		fwts_failed(fw, LOG_LEVEL_MEDIUM, tag,
+			"%s revision is not revision %" PRIu32 ".", name, spec_revision);
+		return FWTS_ERROR;
+	}
+
+	return FWTS_OK;
+}
+
 /*
  *  fwts_method_test_integer_return
  *	check if an integer object was returned
@@ -792,7 +931,8 @@ void fwts_method_test_NULL_return(
 	}
 
 	if (buf && buf->Length && buf->Pointer) {
-		fwts_failed(fw, LOG_LEVEL_MEDIUM, "MethodShouldReturnNothing", "%s returned values, but was expected to return nothing.", name);
+		fwts_failed(fw, LOG_LEVEL_MEDIUM, "MethodShouldReturnNothing",
+			"%s returned values, but was expected to return nothing.", name);
 		fwts_log_info(fw, "Object returned:");
 		fwts_acpi_object_dump(fw, obj);
 		fwts_advice(fw,
@@ -833,12 +973,12 @@ void fwts_method_test_all_reference_package_return(
 	ACPI_OBJECT *obj,
 	void *private)
 {
-	char *objname = (char *)private;
+	FWTS_UNUSED(private);
 
 	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_PACKAGE) != FWTS_OK)
 		return;
 
-	if (fwts_method_package_elements_all_type(fw, name, objname, obj, ACPI_TYPE_LOCAL_REFERENCE) != FWTS_OK)
+	if (fwts_method_package_elements_all_type(fw, name, obj, ACPI_TYPE_LOCAL_REFERENCE) != FWTS_OK)
 		return;
 
 	fwts_passed(fw,	"%s returned a sane package of %" PRIu32 " references.", name, obj->Package.Count);
@@ -913,22 +1053,18 @@ void fwts_method_test_package_integer_return(
 	ACPI_OBJECT *obj,
 	void *private)
 {
-	char method[5];
 	uint32_t *element_size = (uint32_t *) private;
 
 	if (strlen(name) < 4)
 		return;
 
-	memcpy(method, name + strlen(name) - 4, 4);
-	method[4] = '\0';
-
 	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_PACKAGE) != FWTS_OK)
 		return;
 
-	if (fwts_method_package_count_equal(fw, name, method, obj, *element_size) != FWTS_OK)
+	if (fwts_method_package_count_equal(fw, name, obj, *element_size) != FWTS_OK)
 		return;
 
-	if (fwts_method_package_elements_all_type(fw, name, method, obj, ACPI_TYPE_INTEGER) != FWTS_OK)
+	if (fwts_method_package_elements_all_type(fw, name, obj, ACPI_TYPE_INTEGER) != FWTS_OK)
 		return;
 
 	fwts_method_passed_sane(fw, name, "package");
@@ -1818,9 +1954,9 @@ void fwts_method_test_CRS_large_resource_items(
 		fwts_method_test_CRS_large_size(fw, name, objname, data, length, 17, 65535, passed);
 		if (!*passed)	/* Too short, abort */
 			break;
-		fwts_acpi_reserved_bits_check(fw, "_CRS", "Flags[low]", data[4], sizeof(data[4]), 1, 7, passed);
-		fwts_acpi_reserved_zero_check(fw, "_CRS", "Flags[high]", data[5], sizeof(data[5]), passed);
-		fwts_acpi_reserved_zero_check(fw, "_CRS", "Resource Source Index", data[11], sizeof(data[11]), passed);
+		fwts_acpi_reserved_bits_check("_CRS", "Flags[low]", data[4], 1, 7, passed);
+		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
+		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
 		break;
 	case 0xe: /* 6.4.3.8.2 Serial Bus Connection Descriptors */
 		fwts_method_test_CRS_large_size(fw, name, objname, data, length, 11, 65535, passed);
@@ -1831,8 +1967,8 @@ void fwts_method_test_CRS_large_resource_items(
 		if (!*passed)	/* Too short, abort */
 			break;
 
-		fwts_acpi_reserved_bits_check(fw, "_CRS", "Flags[low]", data[4], sizeof(data[4]), 2, 7, passed);
-		fwts_acpi_reserved_zero_check(fw, "_CRS", "Flags[high]", data[5], sizeof(data[5]), passed);
+		fwts_acpi_reserved_bits_check("_CRS", "Flags[low]", data[4], 2, 7, passed);
+		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
 
 		if (data[6] > 0xd && data[6] < 0x80) {
 			*passed = false;
@@ -1847,15 +1983,15 @@ void fwts_method_test_CRS_large_resource_items(
 				"section 6.4.3.10 of the ACPI spec.");
 		}
 
-		fwts_acpi_reserved_zero_check(fw, "_CRS", "Resource Source Index", data[13], sizeof(data[13]), passed);
+		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
 		break;
 	case 0x10: /* 6.4.3.11 Pin Group Descriptors */
 		fwts_method_test_CRS_large_size(fw, name, objname, data, length, 13, 65535, passed);
 		if (!*passed)	/* Too short, abort */
 			break;
 
-		fwts_acpi_reserved_bits_check(fw, "_CRS", "Flags[low]", data[4], sizeof(data[4]), 1, 7, passed);
-		fwts_acpi_reserved_zero_check(fw, "_CRS", "Flags[high]", data[5], sizeof(data[5]), passed);
+		fwts_acpi_reserved_bits_check("_CRS", "Flags[low]", data[4], 1, 7, passed);
+		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
 
 		break;
 	case 0x11: /* 6.4.3.12 Pin Group Function Descriptors */
@@ -1863,17 +1999,17 @@ void fwts_method_test_CRS_large_resource_items(
 		if (!*passed)	/* Too short, abort */
 			break;
 
-		fwts_acpi_reserved_bits_check(fw, "_CRS", "Flags[low]", data[4], sizeof(data[4]), 2, 7, passed);
-		fwts_acpi_reserved_zero_check(fw, "_CRS", "Flags[high]", data[5], sizeof(data[5]), passed);
-		fwts_acpi_reserved_zero_check(fw, "_CRS", "Resource Source Index", data[8], sizeof(data[8]), passed);
+		fwts_acpi_reserved_bits_check("_CRS", "Flags[low]", data[4], 2, 7, passed);
+		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
+		fwts_acpi_reserved_zero_check("_CRS", "Resource Source Index", data[8], passed);
 		break;
 	case 0x12: /* 6.4.3.13 Pin Group Configuration Descriptor */
 		fwts_method_test_CRS_large_size(fw, name, objname, data, length, 19, 65535, passed);
 		if (!*passed)	/* Too short, abort */
 			break;
 
-		fwts_acpi_reserved_bits_check(fw, "_CRS", "Flags[low]", data[4], sizeof(data[4]), 2, 7, passed);
-		fwts_acpi_reserved_zero_check(fw, "_CRS", "Flags[high]", data[5], sizeof(data[5]), passed);
+		fwts_acpi_reserved_bits_check("_CRS", "Flags[low]", data[4], 2, 7, passed);
+		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
 
 		if (data[6] > 0xd && data[6] < 0x80) {
 			*passed = false;
@@ -1888,7 +2024,7 @@ void fwts_method_test_CRS_large_resource_items(
 				"section 6.4.3.10 of the ACPI spec.");
 		}
 
-		fwts_acpi_reserved_zero_check(fw, "_CRS", "Resource Source Index", data[11], sizeof(data[11]), passed);
+		fwts_acpi_reserved_zero_check("_CRS", "Flags[high]", data[5], passed);
 		break;
 	default:
 		snprintf(tmp, sizeof(tmp), "Method%sUnkownLargeResourceItem", objname);
@@ -1989,7 +2125,7 @@ void fwts_method_test_CID_return(
 		fwts_method_valid_CID_Type(fw, name, obj);
 		break;
 	case ACPI_TYPE_PACKAGE:
-		if (fwts_method_package_count_min(fw, name, "_CID", obj, 1) != FWTS_OK)
+		if (fwts_method_package_count_min(fw, name, obj, 1) != FWTS_OK)
 			return;
 
 		for (i = 0; i < obj->Package.Count; i++){
@@ -2109,7 +2245,7 @@ void fwts_method_test_MLS_return(
 	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_PACKAGE) != FWTS_OK)
 		return;
 
-	if (fwts_method_package_elements_all_type(fw, name, "_MLS", obj, ACPI_TYPE_PACKAGE) != FWTS_OK)
+	if (fwts_method_package_elements_all_type(fw, name, obj, ACPI_TYPE_PACKAGE) != FWTS_OK)
 		return;
 
 	/* Could be one or more packages */
@@ -2168,7 +2304,7 @@ void fwts_method_test_PLD_return(
 		return;
 
 	/* All elements in the package must be buffers */
-	if (fwts_method_package_elements_all_type(fw, name, "_PLD", obj, ACPI_TYPE_BUFFER) != FWTS_OK)
+	if (fwts_method_package_elements_all_type(fw, name, obj, ACPI_TYPE_BUFFER) != FWTS_OK)
 		return;
 
 	fwts_method_passed_sane(fw, name, "package");
@@ -2294,20 +2430,705 @@ void fwts_method_test_BMD_return(
 	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_PACKAGE) != FWTS_OK)
 		return;
 
-	if (fwts_method_package_count_equal(fw, name, "_BMD", obj, 5) != FWTS_OK)
+	if (fwts_method_package_count_equal(fw, name, obj, 5) != FWTS_OK)
 		return;
 
-	if (fwts_method_package_elements_all_type(fw, name, "_BMD", obj, ACPI_TYPE_INTEGER) != FWTS_OK)
+	if (fwts_method_package_elements_all_type(fw, name, obj, ACPI_TYPE_INTEGER) != FWTS_OK)
 		return;
 
-	fwts_acpi_reserved_bits_check(fw, "_BMD", "Status Flags",
-		obj->Package.Elements[0].Integer.Value, sizeof(uint32_t), 5, 31, &failed);
+	fwts_acpi_reserved_bits_check("_BMD", "Status Flags",
+		obj->Package.Elements[0].Integer.Value, 7, 31, &failed);
 
-	fwts_acpi_reserved_bits_check(fw, "_BMD", "Capability Flags",
-		obj->Package.Elements[1].Integer.Value, sizeof(uint32_t), 5, 31, &failed);
+	fwts_acpi_reserved_bits_check("_BMD", "Capability Flags",
+		obj->Package.Elements[1].Integer.Value, 6, 31, &failed);
 
 	if (!failed)
 		fwts_method_passed_sane(fw, name, "package");
 }
 
+/*
+ * Section 9.20 NVDIMM Devices
+ */
+static void check_nvdimm_status(
+	fwts_framework *fw,
+	char *name,
+	uint16_t status,
+	bool *passed)
+{
+	if (status > 6) {
+		*passed = false;
+		fwts_failed(fw, LOG_LEVEL_MEDIUM,
+			"MethodBadStatus",
+			"%s: Expected Status to be 0..6, got %" PRIx16,
+			name, status);
+	}
+}
+
+static void check_nvdimm_extended_status(
+	fwts_framework *fw,
+	char *name,
+	uint16_t ext_status,
+	uint16_t expected,
+	bool *passed)
+{
+	if (ext_status != expected) {
+		*passed = false;
+		fwts_failed(fw, LOG_LEVEL_MEDIUM,
+			"MethodBadExtendedStatus",
+			"%s: Expected Extended Status to be %" PRIx16
+			", got %" PRIx16, name, expected, ext_status);
+	}
+}
+
+void fwts_method_test_NBS_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	bool passed = true;
+	nbs_return_t *ret;
+
+	FWTS_UNUSED(private);
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_BUFFER) != FWTS_OK)
+		return;
+
+	if (fwts_method_buffer_size(fw, name, obj, 64) != FWTS_OK)
+		passed = false;
+
+	ret = (nbs_return_t *) obj->Buffer.Pointer;
+	check_nvdimm_status(fw, name, ret->status, &passed);
+	check_nvdimm_extended_status(fw, name, ret->extended_status, 0, &passed);
+	fwts_acpi_reserved_bits_check("_NBS", "Validation Flags",
+		ret->validation_flags, 1, 15, &passed);
+
+	if (passed)
+		fwts_method_passed_sane(fw, name, "buffer");
+}
+
+void fwts_method_test_NCH_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	bool passed = true;
+	nch_return_t *ret;
+
+	FWTS_UNUSED(private);
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_BUFFER) != FWTS_OK)
+		return;
+
+	if (fwts_method_buffer_size(fw, name, obj, 64) != FWTS_OK)
+		passed = false;
+
+	ret = (nch_return_t *) obj->Buffer.Pointer;
+	check_nvdimm_status(fw, name, ret->status, &passed);
+	check_nvdimm_extended_status(fw, name, ret->extended_status, 0, &passed);
+	fwts_acpi_reserved_bits_check("_NCH", "Validation Flags",
+		ret->extended_status, 2, 15, &passed);
+
+	/* Health Status Flags [2..7], [11.15], [19..31] are reserved */
+	fwts_acpi_reserved_bits_check("_NCH", "Health Status Flags",
+		ret->health_status_flags, 2, 7, &passed);
+	fwts_acpi_reserved_bits_check("_NCH", "Health Status Flags",
+		ret->health_status_flags, 11, 15, &passed);
+	fwts_acpi_reserved_bits_check("_NCH", "Health Status Flags",
+		ret->health_status_flags, 19, 31, &passed);
+
+	fwts_acpi_reserved_bits_check("_NCH", "Health Status Attributes",
+		ret->health_status_attributes, 1, 31, &passed);
+
+	if (passed)
+		fwts_method_passed_sane(fw, name, "buffer");
+}
+
+void fwts_method_test_NIC_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	bool passed = true;
+	nic_return_t *ret;
+
+	FWTS_UNUSED(private);
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_BUFFER) != FWTS_OK)
+		return;
+
+	if (fwts_method_buffer_size(fw, name, obj, 64) != FWTS_OK)
+		passed = false;
+
+	ret = (nic_return_t *) obj->Buffer.Pointer;
+	check_nvdimm_status(fw, name, ret->status, &passed);
+	check_nvdimm_extended_status(fw, name, ret->extended_status, 0, &passed);
+
+	/* Health Error Injection Capabilities [2..7], [11.15], [19..31] are reserved */
+	fwts_acpi_reserved_bits_check("_NIC", "Health Error Injection Capabilities",
+		ret->health_error_injection, 2, 7, &passed);
+	fwts_acpi_reserved_bits_check("_NIC", "Health Error Injection Capabilities",
+		ret->health_error_injection, 11, 15, &passed);
+	fwts_acpi_reserved_bits_check("_NIC", "Health Error Injection Capabilities",
+		ret->health_error_injection, 19, 31, &passed);
+
+	fwts_acpi_reserved_bits_check("_NIC", "Health Status Attributes Capabilities",
+		ret->health_status_attributes, 1, 31, &passed);
+
+	if (passed)
+		fwts_method_passed_sane(fw, name, "buffer");
+}
+
+void fwts_method_test_NIH_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	bool passed = true;
+	nih_return_t *ret;
+
+	FWTS_UNUSED(private);
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_BUFFER) != FWTS_OK)
+		return;
+
+	if (fwts_method_buffer_size(fw, name, obj, 64) != FWTS_OK)
+		passed = false;
+
+	ret = (nih_return_t *) obj->Buffer.Pointer;
+	check_nvdimm_status(fw, name, ret->status, &passed);
+	check_nvdimm_extended_status(fw, name, ret->extended_status, 1, &passed);
+
+	if (passed)
+		fwts_method_passed_sane(fw, name, "buffer");
+}
+
+void fwts_method_test_NIG_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	bool passed = true;
+	nig_return_t *ret;
+
+	FWTS_UNUSED(private);
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_BUFFER) != FWTS_OK)
+		return;
+
+	if (fwts_method_buffer_size(fw, name, obj, 64) != FWTS_OK)
+		passed = false;
+
+	ret = (nig_return_t *) obj->Buffer.Pointer;
+	check_nvdimm_status(fw, name, ret->status, &passed);
+	check_nvdimm_extended_status(fw, name,  ret->extended_status, 0, &passed);
+	fwts_acpi_reserved_bits_check("_NIG", "Validation Flags",
+		ret->validation_flags, 2, 15, &passed);
+
+	/* Injected Health Status Errors [2..7], [11.15], [19..31] are reserved */
+	fwts_acpi_reserved_bits_check("_NIG", "Injected Health Status Errors",
+		ret->health_status_errors, 2, 7, &passed);
+	fwts_acpi_reserved_bits_check("_NIG", "Injected Health Status Errors",
+		ret->health_status_errors, 11, 15, &passed);
+	fwts_acpi_reserved_bits_check("_NIG", "Injected Health Status Errors",
+		ret->health_status_errors, 19, 31, &passed);
+
+	fwts_acpi_reserved_bits_check("_NIG", "Health Status Attributes of Injected Errors",
+		ret->health_status_attributes, 1, 31, &passed);
+
+	if (passed)
+		fwts_method_passed_sane(fw, name, "buffer");
+}
+
+void fwts_method_test_STA_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	bool passed = true;
+
+	FWTS_UNUSED(private);
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_INTEGER) != FWTS_OK)
+		return;
+
+	if ((obj->Integer.Value & 3) == 2) {
+		fwts_failed(fw, LOG_LEVEL_MEDIUM,
+			"Method_STAEnabledNotPresent",
+			"%s indicates that the device is enabled "
+			"but not present, which is impossible.", name);
+		passed = false;
+	}
+	fwts_acpi_reserved_bits_check("_STA", "Reserved Bits", obj->Integer.Value, 5, 31, &passed);
+
+	if (passed)
+		fwts_method_passed_sane_uint64(fw, name, obj->Integer.Value);
+}
+
+/*
+ *  Section 10.2 Control Method Batteries
+ */
+
+void fwts_method_test_BIF_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	bool failed = false;
+
+	static const fwts_package_element elements[] = {
+		{ ACPI_TYPE_INTEGER,	"Power Unit" },
+		{ ACPI_TYPE_INTEGER,	"Design Capacity" },
+		{ ACPI_TYPE_INTEGER,	"Last Full Charge Capacity" },
+		{ ACPI_TYPE_INTEGER,	"Battery Technology" },
+		{ ACPI_TYPE_INTEGER,	"Design Voltage" },
+		{ ACPI_TYPE_INTEGER,	"Design Capacity of Warning" },
+		{ ACPI_TYPE_INTEGER,	"Design Capactty of Low" },
+		{ ACPI_TYPE_INTEGER,	"Battery Capacity Granularity 1" },
+		{ ACPI_TYPE_INTEGER,	"Battery Capacity Granularity 2" },
+		{ ACPI_TYPE_STRING,	"Model Number" },
+		{ ACPI_TYPE_STRING,	"Serial Number" },
+		{ ACPI_TYPE_STRING,	"Battery Type" },
+		{ ACPI_TYPE_STRING,	"OEM Information" }
+	};
+
+	FWTS_UNUSED(private);
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_PACKAGE) != FWTS_OK)
+		return;
+
+	if (fwts_method_package_elements_type(fw, name, obj, elements) != FWTS_OK)
+		return;
+
+	/* Sanity check each field */
+	/* Power Unit */
+	if (obj->Package.Elements[0].Integer.Value > 0x00000002) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BIFBadUnits",
+			"%s: Expected Power Unit (Element 0) to be "
+			"0 (mWh) or 1 (mAh), got 0x%8.8" PRIx64 ".",
+			name, (uint64_t)obj->Package.Elements[0].Integer.Value);
+		failed = true;
+	}
+#ifdef FWTS_METHOD_PEDANDTIC
+	/*
+	 * Since this information may be evaluated by communicating with
+	 * the EC we skip these checks as we can't do this from userspace
+	 */
+	/* Design Capacity */
+	if (obj->Package.Elements[1].Integer.Value > 0x7fffffff) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BIFBadCapacity",
+			"%s: Design Capacity (Element 1) is "
+			"unknown: 0x%8.8" PRIx64 ".",
+			name, obj->Package.Elements[1].Integer.Value);
+		failed = true;
+	}
+	/* Last Full Charge Capacity */
+	if (obj->Package.Elements[2].Integer.Value > 0x7fffffff) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BIFChargeCapacity",
+			"%s: Last Full Charge Capacity (Element 2) "
+			"is unknown: 0x%8.8" PRIx64 ".",
+			name, obj->Package.Elements[2].Integer.Value);
+		failed = true;
+	}
+#endif
+	/* Battery Technology */
+	if (obj->Package.Elements[3].Integer.Value > 0x00000002) {
+		fwts_failed(fw, LOG_LEVEL_MEDIUM,
+			"Method_BIFBatTechUnit",
+			"%s: Expected Battery Technology Unit "
+			"(Element 3) to be 0 (Primary) or 1 "
+			"(Secondary), got 0x%8.8" PRIx64 ".",
+			name, (uint64_t)obj->Package.Elements[3].Integer.Value);
+		failed = true;
+	}
+#ifdef FWTS_METHOD_PEDANDTIC
+	/*
+	 * Since this information may be evaluated by communicating with
+	 * the EC we skip these checks as we can't do this from userspace
+	 */
+	/* Design Voltage */
+	if (obj->Package.Elements[4].Integer.Value > 0x7fffffff) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BIFDesignVoltage",
+			"%s: Design Voltage (Element 4) is "
+			"unknown: 0x%8.8" PRIx64 ".",
+			name, obj->Package.Elements[4].Integer.Value);
+		failed = true;
+	}
+	/* Design capacity warning */
+	if (obj->Package.Elements[5].Integer.Value > 0x7fffffff) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BIFDesignCapacityE5",
+			"%s: Design Capacity Warning (Element 5) "
+			"is unknown: 0x%8.8" PRIx64 ".",
+			name, obj->Package.Elements[5].Integer.Value);
+		failed = true;
+	}
+	/* Design capacity low */
+	if (obj->Package.Elements[6].Integer.Value > 0x7fffffff) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BIFDesignCapacityE6",
+			"%s: Design Capacity Warning (Element 6) "
+			"is unknown: 0x%8.8" PRIx64 ".",
+			name, obj->Package.Elements[6].Integer.Value);
+		failed = true;
+	}
+#endif
+	if (failed)
+		fwts_advice(fw,
+			"Battery %s package contains errors. It is "
+			"worth running the firmware test suite "
+			"interactive 'battery' test to see if this "
+			"is problematic.  This is a bug an needs to "
+			"be fixed.", name);
+	else
+		fwts_method_passed_sane(fw, name, "package");
+}
+
+void fwts_method_test_BIX_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	bool failed = false;
+	uint64_t revision = 0;
+
+	/* Revision 0 in ACPI 5.x */
+	static const fwts_package_element elements[] = {
+		{ ACPI_TYPE_INTEGER,	"Revision" },
+		{ ACPI_TYPE_INTEGER,	"Power Unit" },
+		{ ACPI_TYPE_INTEGER,	"Design Capacity" },
+		{ ACPI_TYPE_INTEGER,	"Last Full Charge Capacity" },
+		{ ACPI_TYPE_INTEGER,	"Battery Technology" },
+		{ ACPI_TYPE_INTEGER,	"Design Voltage" },
+		{ ACPI_TYPE_INTEGER,	"Design Capacity of Warning" },
+		{ ACPI_TYPE_INTEGER,	"Design Capacity of Low" },
+		{ ACPI_TYPE_INTEGER,	"Cycle Count" },
+		{ ACPI_TYPE_INTEGER,	"Measurement Accuracy" },
+		{ ACPI_TYPE_INTEGER,	"Max Sampling Time" },
+		{ ACPI_TYPE_INTEGER,	"Min Sampling Time" },
+		{ ACPI_TYPE_INTEGER,	"Max Averaging Interval" },
+		{ ACPI_TYPE_INTEGER,	"Min Averaging Interval" },
+		{ ACPI_TYPE_INTEGER,	"Battery Capacity Granularity 1" },
+		{ ACPI_TYPE_INTEGER,	"Battery Capacity Granularity 2" },
+		{ ACPI_TYPE_STRING,	"Model Number" },
+		{ ACPI_TYPE_STRING,	"Serial Number" },
+		{ ACPI_TYPE_STRING,	"Battery Type" },
+		{ ACPI_TYPE_STRING,	"OEM Information" }
+	};
+
+	/* Revision 1 in ACPI 6.x introduces swapping capability */
+	static const fwts_package_element elements_v1[] = {
+		{ ACPI_TYPE_INTEGER,	"Revision" },
+		{ ACPI_TYPE_INTEGER,	"Power Unit" },
+		{ ACPI_TYPE_INTEGER,	"Design Capacity" },
+		{ ACPI_TYPE_INTEGER,	"Last Full Charge Capacity" },
+		{ ACPI_TYPE_INTEGER,	"Battery Technology" },
+		{ ACPI_TYPE_INTEGER,	"Design Voltage" },
+		{ ACPI_TYPE_INTEGER,	"Design Capacity of Warning" },
+		{ ACPI_TYPE_INTEGER,	"Design Capacity of Low" },
+		{ ACPI_TYPE_INTEGER,	"Cycle Count" },
+		{ ACPI_TYPE_INTEGER,	"Measurement Accuracy" },
+		{ ACPI_TYPE_INTEGER,	"Max Sampling Time" },
+		{ ACPI_TYPE_INTEGER,	"Min Sampling Time" },
+		{ ACPI_TYPE_INTEGER,	"Max Averaging Interval" },
+		{ ACPI_TYPE_INTEGER,	"Min Averaging Interval" },
+		{ ACPI_TYPE_INTEGER,	"Battery Capacity Granularity 1" },
+		{ ACPI_TYPE_INTEGER,	"Battery Capacity Granularity 2" },
+		{ ACPI_TYPE_STRING,	"Model Number" },
+		{ ACPI_TYPE_STRING,	"Serial Number" },
+		{ ACPI_TYPE_STRING,	"Battery Type" },
+		{ ACPI_TYPE_STRING,	"OEM Information" },
+		{ ACPI_TYPE_INTEGER,	"Battery Swapping Capability" }
+	};
+
+	FWTS_UNUSED(private);
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_PACKAGE) != FWTS_OK)
+		return;
+
+	if (obj->Package.Count > 1 && obj->Package.Elements[0].Type == ACPI_TYPE_INTEGER)
+		revision = obj->Package.Elements[0].Integer.Value;
+
+	switch (revision) {
+	case 0:
+		if (fwts_method_package_elements_type(fw, name, obj, elements) != FWTS_OK)
+			return;
+		break;
+	case 1:
+		if (fwts_method_package_elements_type(fw, name, obj, elements_v1) != FWTS_OK)
+			return;
+		break;
+	default:
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BIXRevision",
+			"%s: Expected %s (Element 0) to be "
+			"0 or 1, got 0x%8.8" PRIx64 ".",
+			name, elements_v1[0].name,
+			(uint64_t)obj->Package.Elements[0].Integer.Value);
+		return;
+	}
+
+	/* Sanity check each field */
+	/* Power Unit */
+	if (obj->Package.Elements[1].Integer.Value > 0x00000002) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BIXPowerUnit",
+			"%s: Expected %s (Element 1) to be "
+			"0 (mWh) or 1 (mAh), got 0x%8.8" PRIx64 ".",
+			name, elements[1].name,
+			(uint64_t)obj->Package.Elements[1].Integer.Value);
+		failed = true;
+	}
+#ifdef FWTS_METHOD_PEDANDTIC
+	/*
+	 * Since this information may be evaluated by communicating with
+	 * the EC we skip these checks as we can't do this from userspace
+	 */
+	/* Design Capacity */
+	if (obj->Package.Elements[2].Integer.Value > 0x7fffffff) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BIXDesignCapacity",
+			"%s: %s (Element 2) is "
+			"unknown: 0x%8.8" PRIx64 ".",
+			name, elements[2].name,
+			obj->Package.Elements[2].Integer.Value);
+		failed = true;
+	}
+	/* Last Full Charge Capacity */
+	if (obj->Package.Elements[3].Integer.Value > 0x7fffffff) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BIXFullChargeCapacity",
+			"%s: %s (Element 3) "
+			"is unknown: 0x%8.8" PRIx64 ".",
+			name, elements[3].name,
+			obj->Package.Elements[3].Integer.Value);
+		failed = true;
+	}
+#endif
+	/* Battery Technology */
+	if (obj->Package.Elements[4].Integer.Value > 0x00000002) {
+		fwts_failed(fw, LOG_LEVEL_MEDIUM,
+			"Method_BIXBatteryTechUnit",
+			"%s: %s "
+			"(Element 4) to be 0 (Primary) or 1 "
+			"(Secondary), got 0x%8.8" PRIx64 ".",
+			name, elements[4].name,
+			(uint64_t)obj->Package.Elements[4].Integer.Value);
+		failed = true;
+	}
+#ifdef FWTS_METHOD_PEDANDTIC
+	/*
+	 * Since this information may be evaluated by communicating with
+	 * the EC we skip these checks as we can't do this from userspace
+	 */
+	/* Design Voltage */
+	if (obj->Package.Elements[5].Integer.Value > 0x7fffffff) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BIXDesignVoltage",
+			"%s: %s (Element 5) is unknown: "
+			"0x%8.8" PRIx64 ".",
+			name, elements[5].name,
+			obj->Package.Elements[5].Integer.Value);
+		failed = true;
+	}
+	/* Design capacity warning */
+	if (obj->Package.Elements[6].Integer.Value > 0x7fffffff) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BIXDesignCapacityE6",
+			"%s: %s (Element 6) "
+			"is unknown: 0x%8.8" PRIx64 ".",
+			name, elements[6].name,
+			obj->Package.Elements[6].Integer.Value);
+		failed = true;
+	}
+	/* Design capacity low */
+	if (obj->Package.Elements[7].Integer.Value > 0x7fffffff) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BIXDesignCapacityE7",
+			"%s: %s (Element 7) "
+			"is unknown: 0x%8.8" PRIx64 ".",
+			name, elements[7].name,
+			obj->Package.Elements[7].Integer.Value);
+		failed = true;
+	}
+	/* Cycle Count: value = 0 ~ 0xFFFFFFFE or 0xFFFFFFFF (unknown) */
+
+	/* Measurement Accuracy */
+	if (obj->Package.Elements[9].Integer.Value > 100000) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BIXMeasurementAccuracy",
+			"%s: %s (Element 9) "
+			"is unknown: 0x%8.8" PRIx64 ".",
+			name, elements[9].name,
+			obj->Package.Elements[9].Integer.Value);
+		failed = true;
+	}
+
+#endif
+
+	/* Swapping Capability */
+	if (revision == 1 && obj->Package.Elements[20].Integer.Value > 2) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BIXSwappingCapability",
+			"%s: %s (Element 20) "
+			"is unknown: 0x%8.8" PRIx64 ".",
+			name, elements_v1[20].name,
+			obj->Package.Elements[20].Integer.Value);
+		failed = true;
+	}
+
+	if (failed)
+		fwts_advice(fw,
+			"Battery %s package contains errors. It is "
+			"worth running the firmware test suite "
+			"interactive 'battery' test to see if this "
+			"is problematic.  This is a bug an needs to "
+			"be fixed.", name);
+	else
+		fwts_method_passed_sane(fw, name, "package");
+}
+
+void fwts_method_test_BST_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	bool failed = false;
+
+	static const fwts_package_element elements[] = {
+		{ ACPI_TYPE_INTEGER,	"Battery State" },
+		{ ACPI_TYPE_INTEGER,	"Battery Rate" },
+		{ ACPI_TYPE_INTEGER,	"Battery Remaining Capacity" },
+		{ ACPI_TYPE_INTEGER,	"Battery Present Voltage" },
+	};
+
+	FWTS_UNUSED(private);
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_PACKAGE) != FWTS_OK)
+		return;
+
+	if (fwts_method_package_elements_type(fw, name, obj, elements) != FWTS_OK)
+		return;
+
+	/* Sanity check each field */
+	/* Battery State */
+	fwts_acpi_reserved_bits_check("_BST", "Battery State",
+			obj->Package.Elements[0].Integer.Value, 3, 31, &failed);
+	/* Ensure bits 0 (discharging) and 1 (charging) are not both set, see 10.2.2.6 */
+	if (((obj->Package.Elements[0].Integer.Value) & 3) == 3) {
+		fwts_failed(fw, LOG_LEVEL_CRITICAL,
+			"Method_BSTBadState",
+			"%s: Battery State (Element 0) is "
+			"indicating both charging and discharginng "
+			"which is not allowed. Got value 0x%8.8" PRIx64 ".",
+			name, (uint64_t)obj->Package.Elements[0].Integer.Value);
+		failed = true;
+	}
+	/* Battery Present Rate - cannot check, pulled from EC */
+	/* Battery Remaining Capacity - cannot check, pulled from EC */
+	/* Battery Present Voltage - cannot check, pulled from EC */
+	if (failed)
+		fwts_advice(fw,
+			"Battery %s package contains errors. It is "
+			"worth running the firmware test suite "
+			"interactive 'battery' test to see if this "
+			"is problematic.  This is a bug an needs to "
+			"be fixed.", name);
+		else
+			fwts_method_passed_sane(fw, name, "package");
+}
+
+void fwts_method_test_BPC_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	bool passed = true;
+
+	static const fwts_package_element elements[] = {
+		{ ACPI_TYPE_INTEGER,	"Revision," },
+		{ ACPI_TYPE_INTEGER,	"Power Threshold Support" },
+		{ ACPI_TYPE_INTEGER,	"Max Instantaneous Peak Power Threshold" },
+		{ ACPI_TYPE_INTEGER,	"Max Sustainable Peak Power Threshold" }
+	};
+
+	FWTS_UNUSED(private);
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_PACKAGE) != FWTS_OK)
+		return;
+
+	if (fwts_method_package_elements_type(fw, name, obj, elements) != FWTS_OK)
+		return;
+
+	if (fwts_method_test_revision(fw, name, obj->Package.Elements[0].Integer.Value, 1) != FWTS_OK)
+		passed = false;
+
+	fwts_acpi_reserved_bits_check("_BPC", "Power Threshold Support Capability",
+		obj->Package.Elements[1].Integer.Value, 2, 31, &passed);
+
+	if (!passed)
+		fwts_advice(fw,
+			"Battery %s package contains errors.", name);
+		else
+			fwts_method_passed_sane(fw, name, "package");
+}
+
+void fwts_method_test_BPS_return(
+	fwts_framework *fw,
+	char *name,
+	ACPI_BUFFER *buf,
+	ACPI_OBJECT *obj,
+	void *private)
+{
+	bool passed = true;
+
+	static const fwts_package_element elements[] = {
+		{ ACPI_TYPE_INTEGER,	"Revision," },
+		{ ACPI_TYPE_INTEGER,	"Instantaneous Peak Power Level" },
+		{ ACPI_TYPE_INTEGER,	"Instantaneous Peak Power Period" },
+		{ ACPI_TYPE_INTEGER,	"Sustainable Peak Power Level" },
+		{ ACPI_TYPE_INTEGER,	"Sustainable Peak Power Period" },
+	};
+
+	FWTS_UNUSED(private);
+
+	if (fwts_method_check_type(fw, name, buf, ACPI_TYPE_PACKAGE) != FWTS_OK)
+		return;
+
+	if (fwts_method_package_elements_type(fw, name, obj, elements) != FWTS_OK)
+		return;
+
+	if (fwts_method_test_revision(fw, name, obj->Package.Elements[0].Integer.Value, 1) != FWTS_OK)
+		passed = false;
+
+	if (!passed)
+		fwts_advice(fw,
+			"Battery %s package contains errors.", name);
+		else
+			fwts_method_passed_sane(fw, name, "package");
+}
+
 #endif
