@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -54,6 +54,23 @@ typedef enum {
 
 static acpi_table_load_state acpi_tables_loaded = ACPI_TABLES_NOT_LOADED;
 
+/*
+ *  acpi_table_generic_init()
+ *  	Generic ACPI table init function
+ */
+int acpi_table_generic_init(fwts_framework *fw, char *name, fwts_acpi_table_info **table)
+{
+	if (fwts_acpi_find_table(fw, name, 0, table) != FWTS_OK) {
+		fwts_log_error(fw, "Cannot read ACPI tables.");
+		return FWTS_ERROR;
+	}
+	if (*table == NULL || (*table)->length == 0) {
+		fwts_log_error(fw, "ACPI %s table does not exist, skipping test", name);
+		return FWTS_SKIP;
+	}
+	return FWTS_OK;
+}
+
 /*
  *  fwts_acpi_find_rsdp_efi()
  *  	Get RSDP address from EFI if possible
@@ -283,10 +300,23 @@ int fwts_acpi_free_tables(void)
  *  fwts_acpi_is_reduced_hardware()
  *	Check the ACPI tables for HW_REDUCED_ACPI bit in flag field.
  */
-fwts_bool fwts_acpi_is_reduced_hardware(const fwts_acpi_table_fadt *fadt)
+fwts_bool fwts_acpi_is_reduced_hardware(fwts_framework *fw)
 {
+	fwts_acpi_table_info *table;
+	const fwts_acpi_table_fadt *fadt;
+
+	if (fwts_acpi_find_table(fw, "FACP", 0, &table) != FWTS_OK) {
+		fwts_log_error(fw, "Cannot read ACPI table FACP.");
+		return FWTS_BOOL_ERROR;
+	}
+	if (table == NULL) {
+		fwts_log_error(fw, "ACPI table FACP does not exist!");
+		return FWTS_BOOL_ERROR;
+	}
+	fadt = (const fwts_acpi_table_fadt *) table->data;
+
 	if ((fadt->header.revision >= 5) &&
-			(fadt->header.length >= 116)&&
+			(fadt->header.length >= 116) &&
 			(fadt->flags & FWTS_ACPI_FADT_FLAGS_HW_REDUCED_ACPI)) {
 		return FWTS_TRUE;
 	}
@@ -402,7 +432,7 @@ PRAGMA_PACK_WARN_OFF
 PRAGMA_POP
 	if (result != FWTS_OK) {
 		if ((result == FWTS_NULL_POINTER) &&
-				fwts_acpi_is_reduced_hardware(fadt)) {
+				(fwts_acpi_is_reduced_hardware(fw) == FWTS_TRUE)) {
 			fwts_log_info(fw, "Ignore the missing FACS. "
 					"It is optional in hardware-reduced mode");
 		} else {
@@ -1113,7 +1143,7 @@ static int fwts_acpi_load_tables_fixup(fwts_framework *fw)
 
 		(void)memcpy(xsdt->header.signature, "XSDT", 4);
 		xsdt->header.length = size;
-		xsdt->header.revision = 2;
+		xsdt->header.revision = 1;
 		(void)memcpy(xsdt->header.oem_id, "FWTSID", 6);
 		(void)memcpy(xsdt->header.oem_tbl_id, oem_tbl_id, 8);
 		xsdt->header.oem_revision = 1;
@@ -1214,23 +1244,13 @@ int fwts_acpi_load_tables(fwts_framework *fw)
 		ret = fwts_acpi_load_tables_from_acpidump(fw);
 		require_fixup = true;
 	} else if (fwts_check_root_euid(fw, true) == FWTS_OK) {
-		if (!(fw->flags & FWTS_FLAG_DUMP_ACPI_FROM_SYSFS)) {
-			ret = fwts_acpi_load_tables_from_firmware(fw);
+		ret = fwts_acpi_load_tables_from_sysfs(fw);
 
-			/* Load from memory failed (e.g. no /dev/mem), so try sysfs */
-			if (ret != FWTS_OK) {
-				ret = fwts_acpi_load_tables_from_sysfs(fw);
-				require_fixup = true;
-			}
-		} else {
-			/* Load from sysfs */
-			ret = fwts_acpi_load_tables_from_sysfs(fw);
-			if (ret != FWTS_OK) {
-				/* Load from sysfs failed, try from mem(e.g. /dev/mem) */
-				ret = fwts_acpi_load_tables_from_firmware(fw);
-			} else
-				require_fixup = true;
-		}
+		/* Load from sysfs failed (e.g. no /sys/firmware/acpi/tables), so try memory */
+		if (ret != FWTS_OK)
+			ret = fwts_acpi_load_tables_from_firmware(fw);
+		else
+			require_fixup = true;
 	} else {
 		ret = FWTS_ERROR_NO_PRIV;
 	}
@@ -1404,10 +1424,10 @@ bool fwts_acpi_obj_find(fwts_framework *fw, const char *obj_name)
 }
 
 /*
- *  fwts_acpi_reserved_zero_check()
+ *  fwts_acpi_reserved_zero_check_()
  *  verify whether the reserved field is zero
  */
-void fwts_acpi_reserved_zero_check(
+void fwts_acpi_reserved_zero_check_(
 	fwts_framework *fw,
 	const char *table,
 	const char *field,
@@ -1480,10 +1500,36 @@ void fwts_acpi_reserved_zero_array_check(
 }
 
 /*
- *  fwts_acpi_reserved_bits_check()
+ *  fwts_acpi_fixed_value_check()
+ *  verify whether a field matches the designed fixed value
+ */
+void fwts_acpi_fixed_value_check(
+	fwts_framework *fw,
+	fwts_log_level level,
+	const char *table,
+	const char *field,
+	uint8_t actual,
+	uint8_t must_be,
+	bool *passed)
+{
+	char label[20];
+
+	strncpy(label, table, 4);	/* ACPI table name is 4 char long */
+	strncpy(label + 4, "BadFieldValue", sizeof(label) - 4);
+
+	if (actual != must_be) {
+		fwts_failed(fw, level, label,
+			"%4.4s %s field must be %" PRIu8 ", got %" PRIu8 " instead.",
+			table, field, must_be, actual);
+		*passed = false;
+	}
+}
+
+/*
+ *  fwts_acpi_reserved_bits_check_()
  *  verify whether the reserved bits are zero
  */
-void fwts_acpi_reserved_bits_check(
+void fwts_acpi_reserved_bits_check_(
 	fwts_framework *fw,
 	const char *table,
 	const char *field,
@@ -1557,6 +1603,94 @@ void fwts_acpi_reserved_type_check(
 	}
 }
 
+/*
+ *  Space Id defined for Generic Address Structure (GAS)
+ *  See Table 5.1: Generic Address Structure (GAS) in ACPI spec
+ *  Also see fwts_acpi.h
+ */
+static const char *gas_space_id_names[] = {
+	"System Memory (0x0)",
+	"System I/O (0x1)",
+	"PCI Configuration (0x2)",
+	"Embedded Controller (0x3)",
+	"SMBus (0x4)",
+	"SystemCMOS (0x5)",
+	"PciBarTarget (0x6)",
+	"IPMI (0x7)",
+	"General PurposeIO (0x8)",
+	"GenericSerialBus (0x9)",
+	"Platform Communications Channel (0xa)",
+	"Functional Fixed Hardware (0x7f)",
+};
+
+static const char *get_space_id_name(uint8_t id) {
+	if (id <= 0x0a)
+		return gas_space_id_names[id];
+	else if (id == 0x7f)
+		return gas_space_id_names[0x0b];
+	else
+		return NULL;
+}
+
+/*
+ *  fwts_acpi_space_id_check()
+ *  check whether gas space id matches
+ */
+void fwts_acpi_space_id_check(
+	fwts_framework *fw,
+	const char *table,
+	const char *field,
+	bool *passed,
+	uint8_t actual,
+	uint8_t num_type,
+	...)
+{
+	bool matched = false;
+	char must_be_id[255];
+	uint16_t length = 0;
+	uint8_t i, must_be;
+	char label[25];
+	va_list ap;
+
+	strncpy(label, table, 4);	/* ACPI table name is 4 char long */
+	strncpy(label + 4, "BadAddressSpaceId", sizeof(label) - 4);
+	memset(must_be_id, 0, sizeof(must_be_id));
+
+	va_start(ap, num_type);
+	for (i = 0; i < num_type; i++) {
+		const char *id_name;
+
+		must_be = va_arg(ap, int);
+		if (actual == must_be) {
+			matched = true;
+			break;
+		}
+
+		id_name = get_space_id_name(must_be);
+		if (!id_name)
+			continue;
+
+		length += strlen(id_name);
+		if (length >= sizeof(must_be_id))
+			continue;
+
+		strncat(must_be_id, id_name, strlen(id_name));
+		if (i < num_type - 2)
+			strncat(must_be_id, ", ", 3);
+		else if (i == num_type - 2)
+			strncat(must_be_id, " or ", 5);
+	}
+
+	if (!matched) {
+		fwts_failed(fw, LOG_LEVEL_HIGH, label,
+			"%4.4s %s Space ID must be one of %s, got %s instead.",
+			table, field, must_be_id, get_space_id_name(actual));
+		*passed = false;
+	}
+
+	 va_end(ap);
+}
+
 /*
  *  fwts_acpi_table_length_check()
  *  verify whether table length is sane
@@ -1613,6 +1747,7 @@ uint32_t fwts_get_acpi_version(fwts_framework *fw)
 {
 	fwts_acpi_table_fadt *fadt;
 	fwts_acpi_table_info *table;
+	uint8_t minor;
 
 	if (acpi_version != 0)
 		return acpi_version;
@@ -1628,7 +1763,8 @@ uint32_t fwts_get_acpi_version(fwts_framework *fw)
 	}
 
 	fadt = (fwts_acpi_table_fadt *) table->data;
-	acpi_version = (fadt->header.revision << 8) + (fadt->minor_version << 4);
+	minor = ((fadt->minor_version & 0xF) << 4) + ((fadt->minor_version & 0xF0) >> 4);
+	acpi_version = (fadt->header.revision << 8) + minor;
 
 	/* check FACP returns an invalid value */
 	if (acpi_version > FWTS_ACPI_VERSION_NEXT ||
