@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2020 Canonical
+ * Copyright (C) 2012-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -172,7 +172,7 @@ int fwts_lib_efi_runtime_open(void)
 	if (!efi_dev_name)
 		return -1;
 
-	return open(efi_dev_name, O_WRONLY | O_RDWR);
+	return open(efi_dev_name, O_RDWR);
 }
 
 /*
