@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2010-2020 Canonical
- * Some of this work - Copyright (C) 2016-2020 IBM
+ * Copyright (C) 2010-2021 Canonical
+ * Some of this work - Copyright (C) 2016-2021 IBM
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -139,17 +139,16 @@ static fwts_option fwts_framework_options[] = {
 	{ "ifv",		"",   0, "Run tests in firmware-vendor modes." },
 	{ "clog",		"",   1, "Specify a coreboot logfile dump" },
 	{ "ebbr",		"",   0, "Run ARM EBBR tests." },
-	{ "dump-acpi-from-sysfs","",  0, "Specify dumping acpi table log default from sysfs." },
 	{ NULL, NULL, 0, NULL }
 };
 
 static fwts_list fwts_framework_test_list = FWTS_LIST_INIT;
 
 static const char *fwts_copyright[] = {
-	"Some of this work - Copyright (c) 1999 - 2020, Intel Corp. All rights reserved.",
-	"Some of this work - Copyright (c) 2010 - 2020, Canonical.",
-	"Some of this work - Copyright (c) 2016 - 2020, IBM.",
-	"Some of this work - Copyright (c) 2017 - 2020, ARM Ltd.",
+	"Some of this work - Copyright (c) 1999 - 2021, Intel Corp. All rights reserved.",
+	"Some of this work - Copyright (c) 2010 - 2021, Canonical.",
+	"Some of this work - Copyright (c) 2016 - 2021, IBM.",
+	"Some of this work - Copyright (c) 2017 - 2021, ARM Ltd.",
 	NULL
 };
 
@@ -1337,8 +1336,13 @@ int fwts_framework_options_handler(fwts_framework *fw, int argc, char * const ar
 				return FWTS_ERROR;
 			break;
 		case 46: /* --sbbr */
+#if defined(FWTS_ARCH_AARCH64)
 			fw->flags |= FWTS_FLAG_TEST_SBBR;
 			break;
+#else
+			fprintf(stderr, "option not available on this architecture\n");
+			return FWTS_ERROR;
+#endif
 		case 47: /* --ifv */
 			fw->flags |= FWTS_FLAG_FIRMWARE_VENDOR;
 			break;
@@ -1346,11 +1350,13 @@ int fwts_framework_options_handler(fwts_framework *fw, int argc, char * const ar
 			fwts_framework_strdup(&fw->clog, optarg);
 			break;
 		case 49: /* --ebbr */
+#if defined(FWTS_ARCH_AARCH64)
 			fw->flags |= FWTS_FLAG_TEST_EBBR;
 			break;
-		case 50: /* --dump-acpi-from-sysfs */
-			fw->flags |= FWTS_FLAG_DUMP_ACPI_FROM_SYSFS;
-			break;
+#else
+			fprintf(stderr, "option not available on this architecture\n");
+			return FWTS_ERROR;
+#endif
 		}
 		break;
 	case 'a': /* --all */
