@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2020 Canonical
+ * Copyright (C) 2010-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -755,6 +755,59 @@ static char *str_indent(char *str, int indent)
 	return str_append(str, buf);
 }
 
+/*
+ *  char_escape()
+ *	convert escape char to the unescaped char to
+ *	be prefixed by \\.  If not an escape char, return 0
+ */
+static inline int char_escape(const int ch)
+{
+	switch (ch) {
+	case '"':
+		return '"';
+	case '\b':
+		return 'b';
+	case '\f':
+		return 'f';
+	case '\n':
+		return 'n';
+	case '\r':
+		return 'r';
+	case '\t':
+		return 't';
+	default:
+		break;
+	}
+	return 0;
+}
+
+static char *str_escape(char *oldstr)
+{
+	char *oldptr, *newstr, *newptr;
+	ssize_t n;
+
+	for (n = 0, oldptr = oldstr; *oldptr; oldptr++, n++)
+		if (char_escape(*oldptr))
+			n++;
+
+	newstr = malloc(n + 1);
+	if (!newstr)
+		return NULL;
+
+	for (oldptr = oldstr, newptr = newstr; *oldptr; oldptr++) {
+		const int esc = char_escape(*oldptr);
+
+		if (esc) {
+			*(newptr++) = '\\';
+			*(newptr++) = esc;
+		} else {
+			*(newptr++) = *oldptr;
+		}
+	}
+	*newptr = '\0';
+	return newstr;
+}
+
 /*
  *  json_object_to_json_string_indent()
  *	turn a simplified fwts json object into a C string, returns
@@ -766,6 +819,7 @@ static char *json_object_to_json_string_indent(json_object *obj, int indent)
 	int i;
 	json_object **obj_ptr;
 	char *str = NULL;
+	char *tmp;
 	char buf[64];
 
 	if (!obj)
@@ -775,9 +829,6 @@ static char *json_object_to_json_string_indent(json_object *obj, int indent)
 		str = str_indent(str, indent);
 		if (!str)
 			return NULL;
-		str = str_append(str, "{\n");
-		if (!str)
-			return NULL;
 	}
 
         if (obj->key) {
@@ -797,15 +848,33 @@ static char *json_object_to_json_string_indent(json_object *obj, int indent)
 
 	switch (obj->type) {
 	case type_array:
-		str = str_append(str, "[\n");
+		str = str_append(str, "\n");
+		if (!str)
+			return NULL;
+		str = str_indent(str, indent);
+		if (!str)
+			return NULL;
+		str = str_append(str, "[");
 		if (!str)
 			return NULL;
 
 		obj_ptr = (json_object **)obj->u.ptr;
 		if (obj_ptr) {
 			for (i = 0; i < obj->length; i++) {
-				char *obj_str = json_object_to_json_string_indent(obj_ptr[i], indent + 1);
+				char *obj_str;
 
+				if (i) {
+					str = str_append(str, "\n");
+					if (!str)
+						return NULL;
+					str = str_indent(str, indent + 1);
+					if (!str)
+						return NULL;
+					str = str_append(str, ",");
+					if (!str)
+						return NULL;
+				}
+				obj_str = json_object_to_json_string_indent(obj_ptr[i], indent + 1);
 				if (!obj_str) {
 					free(str);
 					return NULL;
@@ -821,17 +890,30 @@ static char *json_object_to_json_string_indent(json_object *obj, int indent)
 		str = str_indent(str, indent);
 		if (!str)
 			return NULL;
-		str = str_append(str, "]\n");
+		str = str_append(str, "]");
 		if (!str)
 			return NULL;
 		break;
 
 	case type_object:
+		str = str_append(str, "\n");
+		if (!str)
+			return NULL;
+		str = str_indent(str, indent);
+		if (!str)
+			return NULL;
+		str = str_append(str, "{");
+		if (!str)
+			return NULL;
 		obj_ptr = (json_object **)obj->u.ptr;
 		if (obj_ptr) {
 			for (i = 0; i < obj->length; i++) {
-				char *obj_str = json_object_to_json_string_indent(obj_ptr[i], indent + 1);
+				char *obj_str;
 
+				str = str_append(str, (i == 0) ? "\n" : ",\n");
+				if (!str)
+					return NULL;
+				obj_str = json_object_to_json_string_indent(obj_ptr[i], indent + 1);
 				if (!obj_str) {
 					free(str);
 					return NULL;
@@ -841,6 +923,13 @@ static char *json_object_to_json_string_indent(json_object *obj, int indent)
 					return NULL;
 			}
 		}
+		str = str_append(str, "\n");
+		if (!str)
+			return NULL;
+		str = str_indent(str, indent);
+		if (!str)
+			return NULL;
+		str = str_append(str, "}");
 		if (!str)
 			return NULL;
 		break;
@@ -849,22 +938,28 @@ static char *json_object_to_json_string_indent(json_object *obj, int indent)
 		str = str_append(str, "\"");
 		if (!str)
 			return NULL;
-		str = str_append(str, (char *)obj->u.ptr);
+		tmp = str_escape((char *)obj->u.ptr);
+		if (!tmp) {
+			free(str);
+			return NULL;
+		}
+		str = str_append(str, tmp);
+		free(tmp);
 		if (!str)
 			return NULL;
-		str = str_append(str, "\",\n");
+		str = str_append(str, "\"");
 		if (!str)
 			return NULL;
 		break;
 
 	case type_null:
-		str = str_append(str, "(null)\n");
+		str = str_append(str, "(null)");
 		if (!str)
 			return NULL;
 		break;
 
 	case type_int:
-		snprintf(buf, sizeof(buf), "%d,\n", obj->u.intval);
+		snprintf(buf, sizeof(buf), "%d", obj->u.intval);
 		str = str_append(str, buf);
 		if (!str)
 			return NULL;
@@ -877,9 +972,6 @@ static char *json_object_to_json_string_indent(json_object *obj, int indent)
 		str = str_indent(str, indent);
 		if (!str)
 			return NULL;
-		str = str_append(str, "},\n");
-		if (!str)
-			return NULL;
 	}
 	return str;
 }
