@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2010-2020 Canonical
- * Copyright (C) 2017-2020 ARM Ltd
+ * Copyright (C) 2010-2021 Canonical
+ * Copyright (C) 2017-2021 ARM Ltd
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -16,7 +16,8 @@
  */
 #include "fwts.h"
 
-#if defined(FWTS_HAS_ACPI)
+#if defined(FWTS_HAS_ACPI) && (FWTS_ARCH_AARCH64)
+
 #include "acpi.h"
 #include "accommon.h"
 #include "acnamesp.h"
