@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2010-2020 Canonical
- * Copyright (C) 2017-2020 ARM Ltd
+ * Copyright (C) 2010-2021 Canonical
+ * Copyright (C) 2017-2021 ARM Ltd
  * Portions of this code original from the Linux-ready Firmware Developer Kit
  *
  * This program is free software; you can redistribute it and/or
@@ -20,7 +20,7 @@
  */
 #include "fwts.h"
 
-#if defined(FWTS_HAS_ACPI)
+#if defined(FWTS_HAS_ACPI) && (FWTS_ARCH_AARCH64)
 
 #include "fwts_acpi_object_eval.h"
 
@@ -92,12 +92,13 @@ static int fadt_sbbr_reduced_hw_test2(fwts_framework *fw)
 	static const fwts_acpi_gas null_gas;
 	uint32_t flag_mask;
 
-	rhw = fwts_acpi_is_reduced_hardware(fadt);
-	if (rhw == 0)
+	rhw = fwts_acpi_is_reduced_hardware(fw);
+	if (rhw == FWTS_FALSE)
 		fwts_failed(fw, LOG_LEVEL_CRITICAL, "fadt_reduced_hw:", "FADT indicates ACPI is not in reduced hardware mode.");
-	else
+	else if(rhw == FWTS_TRUE)
 		fwts_passed(fw, "FADT indicates ACPI is in reduced hardware mode.");
-
+	else
+		fwts_failed(fw, LOG_LEVEL_HIGH, "fadt_reduced_hw:", "ACPI table reads error.");
 
 	if (!rhw)
 		return FWTS_OK;
@@ -377,11 +378,11 @@ static int fadt_sbbr_profile_test3(fwts_framework *fw)
 
 	fwts_log_info(fw, "FADT Preferred PM Profile: %hhu (%s)",
 		fadt->preferred_pm_profile,
-		FWTS_ACPI_FADT_PREFERRED_PM_PROFILE(fadt->preferred_pm_profile));
+		fwts_acpi_fadt_preferred_pm_profile(fadt->preferred_pm_profile));
 
 	if ((fadt->preferred_pm_profile == SBBR_ENT_SERVER)  ||
-	(fadt->preferred_pm_profile == SBBR_SOHO_SERVER) ||
-	(fadt->preferred_pm_profile == SBBR_PERF_SERVER))
+            (fadt->preferred_pm_profile == SBBR_SOHO_SERVER) ||
+            (fadt->preferred_pm_profile == SBBR_PERF_SERVER))
 		fwts_passed(fw, "FADT has a recommended server PM profile.");
 	else
 		fwts_failed(fw, LOG_LEVEL_MEDIUM, "fadt_profile:", "FADT preferred PM profile is not recommended.");
