@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2012-2020 Canonical
+ * Copyright (C) 2012-2021 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -64,6 +64,9 @@ static uint16_t variablenametest[] = {'T', 'e', 's', 't', 'v', 'a', 'r', '\0'};
 static uint16_t variablenametest2[] = {'T', 'e', 's', 't', 'v', 'a', 'r', ' ', '\0'};
 static uint16_t variablenametest3[] = {'T', 'e', 's', 't', 'v', 'a', '\0'};
 
+static bool have_rtsupported;
+static uint32_t runtimeservicessupported;
+
 static void uefirtvariable_env_cleanup(void)
 {
 	struct efi_setvariable setvariable;
@@ -100,6 +103,9 @@ static int uefirtvariable_init(fwts_framework *fw)
 
 	uefirtvariable_env_cleanup();
 
+	fwts_uefi_rt_support_status_get(fd, &have_rtsupported,
+			&runtimeservicessupported);
+
 	return FWTS_OK;
 }
 
@@ -2020,9 +2026,6 @@ static int uefirtvariable_test9(fwts_framework *fw)
 {
 	long ioret;
 
-	bool getvar_supported;
-	uint32_t var_runtimeservicessupported;
-
 	struct efi_getvariable getvariable;
 	struct efi_setvariable setvariable;
 	struct efi_getnextvariablename getnextvariablename;
@@ -2041,15 +2044,10 @@ static int uefirtvariable_test9(fwts_framework *fw)
 	uint64_t getdatasize = sizeof(testdata);
 	uint32_t attr;
 
-	fwts_uefi_rt_support_status_get(fd, &getvar_supported,
-			&var_runtimeservicessupported);
-
-	if (!getvar_supported || (var_runtimeservicessupported == 0xFFFF)) {
+	if (!have_rtsupported) {
 		fwts_skipped(fw, "Cannot get the RuntimeServicesSupported "
-				"variable, maybe the runtime service "
-				"GetVariable is not supported or "
-				"RuntimeServicesSupported not provided by "
-				"firmware.");
+				 "mask from the kernel. This IOCTL was "
+				 "introduced in Linux v5.11.");
 		return FWTS_SKIP;
 	}
 
@@ -2063,11 +2061,10 @@ static int uefirtvariable_test9(fwts_framework *fw)
 	ioret = ioctl(fd, EFI_RUNTIME_SET_VARIABLE, &setvariable);
 	if (ioret == -1) {
 		if (status == EFI_UNSUPPORTED) {
-			if ((var_runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE)
-				|| (var_runtimeservicessupported == 0)) {
+			if (runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE) {
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetVariable",
 					"Get the Setvariable runtime service supported "
-					"via RuntimeServicesSupported variable. "
+					"via RuntimeServicesSupported mask. "
 					"But actually is not supported by firmware.");
 			} else {
 				fwts_passed(fw, "UEFI SetVariable runtime service "
@@ -2078,14 +2075,13 @@ static int uefirtvariable_test9(fwts_framework *fw)
 				fwts_skipped(fw, "Unknown error occurred, skip test.");
 				return FWTS_SKIP;
 			}
-			if ((var_runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE) ||
-				(var_runtimeservicessupported == 0)) {
+			if (runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE) {
 				fwts_passed(fw, "UEFI SetVariable runtime service "
 					"supported status test passed.");
 			} else {
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetVariable",
 					"Get the SetVariable runtime service unsupported "
-					"via RuntimeServicesSupported variable. "
+					"via RuntimeServicesSupported mask. "
 					"But actually is supported by firmware.");
 			}
 		}
@@ -2094,14 +2090,13 @@ static int uefirtvariable_test9(fwts_framework *fw)
 			fwts_skipped(fw, "Unknown error occurred, skip test.");
 			return FWTS_SKIP;
 		}
-		if ((var_runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE) ||
-			(var_runtimeservicessupported == 0)) {
+		if (runtimeservicessupported & EFI_RT_SUPPORTED_SET_VARIABLE) {
 			fwts_passed(fw, "UEFI SetVariable runtime service "
 				"supported status test passed.");
 		} else {
 			fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeSetVariable",
 				"Get the SetVariable runtime service unsupported "
-				"via RuntimeServicesSupported variable. "
+				"via RuntimeServicesSupported mask. "
 				"But actually is supported by firmware.");
 		}
 	}
@@ -2116,11 +2111,10 @@ static int uefirtvariable_test9(fwts_framework *fw)
 	ioret = ioctl(fd, EFI_RUNTIME_GET_VARIABLE, &getvariable);
 	if (ioret == -1) {
 		if (status == EFI_UNSUPPORTED) {
-			if ((var_runtimeservicessupported & EFI_RT_SUPPORTED_GET_VARIABLE)
-				|| (var_runtimeservicessupported == 0)) {
+			if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_VARIABLE) {
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetVariable",
 					"Get the GetVariable runtime service supported "
-					"via RuntimeServicesSupported variable. "
+					"via RuntimeServicesSupported mask. "
 					"But actually is not supported by firmware.");
 			} else {
 				fwts_passed(fw, "UEFI GetVariable runtime service "
@@ -2131,14 +2125,13 @@ static int uefirtvariable_test9(fwts_framework *fw)
 				fwts_skipped(fw, "Unknown error occurred, skip test.");
 				return FWTS_SKIP;
 			}
-			if ((var_runtimeservicessupported & EFI_RT_SUPPORTED_GET_VARIABLE) ||
-				(var_runtimeservicessupported == 0)) {
+			if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_VARIABLE) {
 				fwts_passed(fw, "UEFI GetVariable runtime service "
 					"supported status test passed.");
 			} else {
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetVariable",
 					"Get the GetVariable runtime service unsupported "
-					"via RuntimeServicesSupported variable. "
+					"via RuntimeServicesSupported mask. "
 					"But actually is supported by firmware.");
 			}
 		}
@@ -2147,14 +2140,13 @@ static int uefirtvariable_test9(fwts_framework *fw)
 			fwts_skipped(fw, "Unknown error occurred, skip test.");
 			return FWTS_SKIP;
 		}
-		if ((var_runtimeservicessupported & EFI_RT_SUPPORTED_GET_VARIABLE) ||
-			(var_runtimeservicessupported == 0)) {
+		if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_VARIABLE) {
 			fwts_passed(fw, "UEFI GetVariable runtime service "
 				"supported status test passed.");
 		} else {
 			fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetVariable",
 				"Get the GetVariable runtime service unsupported "
-				"via RuntimeServicesSupported variable. "
+				"via RuntimeServicesSupported mask. "
 				"But actually is supported by firmware.");
 		}
 	}
@@ -2179,11 +2171,10 @@ static int uefirtvariable_test9(fwts_framework *fw)
 	ioret = ioctl(fd, EFI_RUNTIME_GET_NEXTVARIABLENAME, &getnextvariablename);
 	if (ioret == -1) {
 		if (status == EFI_UNSUPPORTED) {
-			if ((var_runtimeservicessupported & EFI_RT_SUPPORTED_GET_NEXT_VARIABLE_NAME)
-				|| (var_runtimeservicessupported == 0)) {
+			if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_NEXT_VARIABLE_NAME) {
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetNextVarName",
 					"Get the GetNextVarName runtime service supported "
-					"via RuntimeServicesSupported variable. "
+					"via RuntimeServicesSupported mask. "
 					"But actually is not supported by firmware.");
 			} else {
 				fwts_passed(fw, "UEFI GetNextVarName runtime service "
@@ -2194,14 +2185,13 @@ static int uefirtvariable_test9(fwts_framework *fw)
 				fwts_skipped(fw, "Unknown error occurred, skip test.");
 				return FWTS_SKIP;
 			}
-			if ((var_runtimeservicessupported & EFI_RT_SUPPORTED_GET_NEXT_VARIABLE_NAME)
-				|| (var_runtimeservicessupported == 0)) {
+			if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_NEXT_VARIABLE_NAME) {
 				fwts_passed(fw, "UEFI GetNextVarName runtime service "
 					"supported status test passed.");
 			} else {
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetNextVarName",
 					"Get the GetNextVarName runtime service unsupported "
-					"via RuntimeServicesSupported variable. "
+					"via RuntimeServicesSupported mask. "
 					"But actually is supported by firmware.");
 			}
 		}
@@ -2210,14 +2200,13 @@ static int uefirtvariable_test9(fwts_framework *fw)
 			fwts_skipped(fw, "Unknown error occurred, skip test.");
 			return FWTS_SKIP;
 		}
-		if ((var_runtimeservicessupported & EFI_RT_SUPPORTED_GET_NEXT_VARIABLE_NAME)
-			|| (var_runtimeservicessupported == 0)) {
+		if (runtimeservicessupported & EFI_RT_SUPPORTED_GET_NEXT_VARIABLE_NAME) {
 			fwts_passed(fw, "UEFI GetNextVarName runtime service "
 				"supported status test passed.");
 		} else {
 			fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeGetNextVarName",
 				"Get the GetNextVarName runtime service unsupported "
-				"via RuntimeServicesSupported variable. "
+				"via RuntimeServicesSupported mask. "
 				"But actually is supported by firmware.");
 		}
 	}
@@ -2232,11 +2221,10 @@ static int uefirtvariable_test9(fwts_framework *fw)
 	ioret = ioctl(fd, EFI_RUNTIME_QUERY_VARIABLEINFO, &queryvariableinfo);
 	if (ioret == -1) {
 		if (status == EFI_UNSUPPORTED) {
-			if ((var_runtimeservicessupported & EFI_RT_SUPPORTED_QUERY_VARIABLE_INFO)
-				|| (var_runtimeservicessupported == 0)) {
+			if (runtimeservicessupported & EFI_RT_SUPPORTED_QUERY_VARIABLE_INFO) {
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeQueryVarInfo",
 					"Get the QueryVarInfo runtime service supported "
-					"via RuntimeServicesSupported variable. "
+					"via RuntimeServicesSupported mask. "
 					"But actually is not supported by firmware.");
 			} else {
 				fwts_passed(fw, "UEFI QueryVarInfo runtime service "
@@ -2247,14 +2235,13 @@ static int uefirtvariable_test9(fwts_framework *fw)
 				fwts_skipped(fw, "Unknown error occurred, skip test.");
 				return FWTS_SKIP;
 			}
-			if ((var_runtimeservicessupported & EFI_RT_SUPPORTED_QUERY_VARIABLE_INFO)
-				|| (var_runtimeservicessupported == 0)) {
+			if (runtimeservicessupported & EFI_RT_SUPPORTED_QUERY_VARIABLE_INFO) {
 				fwts_passed(fw, "UEFI QueryVarInfo runtime service "
 					"supported status test passed.");
 			} else {
 				fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeQueryVarInfo",
 					"Get the QueryVarInfo runtime service unsupported "
-					"via RuntimeServicesSupported variable. "
+					"via RuntimeServicesSupported mask. "
 					"But actually is supported by firmware.");
 			}
 		}
@@ -2263,14 +2250,13 @@ static int uefirtvariable_test9(fwts_framework *fw)
 			fwts_skipped(fw, "Unknown error occurred, skip test.");
 			return FWTS_SKIP;
 		}
-		if ((var_runtimeservicessupported & EFI_RT_SUPPORTED_QUERY_VARIABLE_INFO)
-			|| (var_runtimeservicessupported == 0)) {
+		if (runtimeservicessupported & EFI_RT_SUPPORTED_QUERY_VARIABLE_INFO) {
 			fwts_passed(fw, "UEFI QueryVarInfo runtime service "
 				"supported status test passed.");
 		} else {
 			fwts_failed(fw, LOG_LEVEL_HIGH, "UEFIRuntimeQueryVarInfo",
 				"Get the QueryVarInfo runtime service unsupported "
-				"via RuntimeServicesSupported variable. "
+				"via RuntimeServicesSupported mask. "
 				"But actually is supported by firmware.");
 		}
 	}
